function [ta,xa,ya,ax,ay] = FN_accel(Inparm,t,x,y,ux,uy)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_accel
%   Berekent x- en y-posities en versnellingen uit snelheden
%   versie 1
%   19-5-05
%
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   Inparm: structure met invoergegevens; alleen de tijdstap
%           dt wordt gebruikt
%   t:  tijdvector
%   x:  vector met x-coordinaten t.o.v.stelsel
%   y:  vector met y-coordinaten t.o.v.
%   ux: vector met dx/dt
%   uy: vector met dy/dt
%
% uitvoer:
%   ta:  tijdvector versnellingen
%   xa:  vector met x-coordinaten versnellingen
%   ya:  vector met y-coordinaten versnellingen
%   ax: vector met dux/dt 
%   ay: vector met duy/dt
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% bepaal versnellingen:
dt  = diff(t);
dux = diff(ux);
duy = diff(uy);

% bereken versnellingen:
nsamp = length(dt);
eps1 = 0.5*Inparm.dt;
for i=1:nsamp
    if dt(i)>eps1
        ax(i) = dux(i)/dt(i);
        ay(i) = duy(i)/dt(i);
    else
        ax(i) = 0;
        ay(i) = 0;
    end    
end

% bepaal tijden en coordinaten:
nsamp   = length(ax);
for i=1:nsamp
    ta(i) = 0.5*(t(i)+t(i+1));
    xa(i) = 0.5*(x(i)+x(i+1));
    ya(i) = 0.5*(y(i)+y(i+1));
end    
%t = t';
%x = x';
%y = y';

% einde FN_accel