function [Inparm,error] = FN_inparmv
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_inparmv
%   ask input parameters for scripts Vels
%   version 1
%   7-Jun-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% hulpbestand: inparmv.txt
%
% invoerbestand (kan ook uit uitvoer .txt-bestand van Vels
%   worden gehaald): 
%   .txt-bestand met de volgende inhoud;
%   de ingevulde waarden moeten worden vervangen
%
%   time step used:                   0.0200
%   pos of origin [pixels]:         68  448
%   lower right position [pixels]: 627  461
%   upper left  position [pixels]:  71  205
%   lower right position [m]:        1    0
%   upper left  position [m]:        0    0
%   lower right position of construction [m]:  0.45  0.05
%   upper left  position of construction [m]:  0.05  0.18
%
% uitvoer:
%	Inparm:	structure met invoerparameters
%       dt:     tijdstap
%       pos0:   pos. oorsprong in pixels
%       pos1:   pos. rechtsonder in pixels
%       pos2:   pos. linksboven in pixels
%       new1:   pos. rechtsonder in m
%       new2:   pos. linksboven in m
%       x1:     punt constructie rechtsonder in pixels
%       x2:     punt constructie linksboven in pixels
%
%

%% Initialize parameters:
error       = 0;

% time step:
Inparm.dt       = 0.02;
    
% coordinates of nodges in pixes:
Inparm.pos0     = [0  560]; % position of origin in pixels
Inparm.pos1     = [560 560]; % lower right point 
Inparm.pos2     = [0  0]; % upper left point 

% coordinates in m:
%   Inparm.new0     = [0 0];   % defined as origin
Inparm.new1     = [0.50 0];
Inparm.new2     = [0    0.20];
    
% coordinates of construction in pixels:
%Inparm.x1       = [500 500];    % lower right point 
%Inparm.x2       = [50  50];    % upper left point 

% coordinates of construction in m:
Inparm.x1       = [0.47 0.05];    % lower right point 
Inparm.x2       = [0.05 0.32];    % upper left point 

%% open input file:
filetext = 'File containing parameters of data file';
[filenaam, padnaam] = FN_chsfile(filetext);

% user wants to continue:
if filenaam~=0
    infile = [padnaam filenaam];
    FID = fopen(infile,'r');

    % read first 8 lines:
    i=1;
    while feof(FID)==0 & i<=8
        lijn{i} = fgets(FID);
        i = i+1;
    end    

    if i<8
        error = 301;
        h = msgbox('Parameter file must have 8 lines','Vels');
        uiwait(h);
    else
        tekst   = char(lijn{1});
        len     = length(tekst);
        br 		= findstr(tekst,':');
        Inparm.dt   = str2num(tekst(br(1)+1:len));
        Inparm.pos0 = readpos(lijn{2});
        Inparm.pos1 = readpos(lijn{3});
        Inparm.pos2 = readpos(lijn{4});
        Inparm.new1 = readpos(lijn{5});
        Inparm.new2 = readpos(lijn{6});
        Inparm.x1   = readpos(lijn{7});
        Inparm.x2   = readpos(lijn{8});
    end    
    fclose(FID);
    
% gebruiker heeft op Cancel gedrukt:    
else
    error = 101;
end    

% Einde FN_inparmv

function pos = readpos(regel)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% lees positie uit regel
% 7-6-05
% invoer:
%   regel:  cell met tekst, moet : bevatten gevolgd door twee getallen
%
% uitvoer:
%   pos:    vector met de waarde van de getallen in regel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tekst   = char(regel);
len     = length(tekst);
br 		= findstr(tekst,':');
pos     = sscanf(tekst(br(1)+1:len),'%g %g');
pos     = pos';

% einde readpos