function [Inparm,error] = FN_inparmv2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_inparmv2
%   ask input parameters for scripts Vels
%   version 2: coordinates of axes and constuction added in 
%       main program
%   9-Jun-05
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoerbestand (kan ook uit uitvoer .txt-bestand van Vels
%   worden gehaald): 
%   .txt-bestand met de volgende inhoud;
%   de ingevulde waarden moeten worden vervangen
%
%   time step used:                     0.0200
%   pos of origin [pixels]:              68  448
%   rightmost point of X-axes [pixels]: 627  461
%   uppermost point of Y-axes [pixels]:  71  205
%
% uitvoer:
%	Inparm:	structure met invoerparameters
%       dt:     tijdstap
%       pos0:   pos. oorsprong in pixels
%       pos1:   pos. meest rechtse punt X-as in pixels
%       pos2:   pos. bovenste punt Y-as in pixels
%
%

%% Initialize parameters:
error       = 0;

% time step:
Inparm.dt       = 0.02;
    
% coordinates of nodges in pixes:
Inparm.pos0     = [0  560]; % position of origin in pixels
Inparm.pos1     = [560 560]; % lower right point 
Inparm.pos2     = [0  0]; % upper left point 

%% open input file:
filetext = 'File containing parameters of data file';
[filenaam, padnaam] = FN_chsfile(filetext);

% user wants to continue:
if filenaam~=0
    infile = [padnaam filenaam];
    FID = fopen(infile,'r');

    % read first 4 lines:
    i=1;
    while feof(FID)==0 & i<=6
        lijn{i} = fgets(FID);
        i = i+1;
    end    

    if i<=4
        error = 301;
        h = msgbox('Parameter file must have 4 lines','Vels');
        uiwait(h);
    else
        tekst   = char(lijn{1});
        len     = length(tekst);
        br 		= findstr(tekst,':');
        lenbr   = length(br);
        if lenbr>0
            Inparm.dt   = str2num(tekst(br(lenbr)+1:len));
            Inparm.pos0 = readpos(lijn{2});
            Inparm.pos1 = readpos(lijn{3});
            Inparm.pos2 = readpos(lijn{4});
            if Inparm.pos0(1)<0|Inparm.pos1(1)<0|Inparm.pos2(1)<0
                error=301;
            end    
        else    
            error = 301;
            h = ...
msgbox('Line in parameter file must have at least one : as a break symbol',...
                'Vels');
            uiwait(h);
        end    
    end    
    fclose(FID);
    
% gebruiker heeft op Cancel gedrukt:    
else
    error = 101;
end    

% Einde FN_inparmv2

function pos = readpos(regel)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% lees positie uit regel
% 9-6-05
% invoer:
%   regel:  cell met tekst, moet : bevatten gevolgd door twee getallen
%
% uitvoer:
%   pos:    vector met de waarde van de getallen in regel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tekst   = char(regel);
len     = length(tekst);
br 		= findstr(tekst,':');
lenbr   = length(br);
if lenbr>0
    pos     = sscanf(tekst(br(lenbr)+1:len),'%g %g');
    pos     = pos';
else
    pos=[-1 -1];
    h = ...
msgbox('Line in parameter file must have at least one : as a break symbol',...
                'Vels');
    uiwait(h);
end
% einde readpos