function [Inparm,err1] = FN_inparmv3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_inparmv3
%   ask input parameters for scripts Vels
%   version 3: all input from .txt-file, more :'s allowed in text 
%   13-Jun-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoerbestand (kan ook uit uitvoer .txt-bestand van Vels
%   worden gehaald): 
%   .txt-bestand met de volgende inhoud;
%   de ingevulde waarden moeten worden vervangen
%
%   time step used:                        0.0200
%   pos of origin [pixels]:              68  448
%   rightmost point of X-axes [pixels]:  627  461
%   uppermost point of Y-axes [pixels]:   71  205
%   rightmost point of X-axes [m]:        0.500   0.000
%   uppermost point of Y-axes [m]:        0.000   0.200
%   lower right endpoint of construction [m]:   0.560   0.000
%   upper left  endpoint of construction [m]:   0.000   0.295
%
% uitvoer:
%	Inparm:	structure met invoerparameters
%       dt:     tijdstap
%       pos0:   pos. oorsprong in pixels
%       pos1:   pos. meest rechtse punt X-as in pixels
%       pos2:   pos. bovenste punt Y-as in pixels
%       new1:   positie meest rechtse punt X-as in m t.o.v. oorsprong
%       new2:   positie bovenste punt Y-as in m t.o.v. oorsprong
%       x1:     positie eindpunt constructie rechtsonder in m t.o.v. oorspr
%       x2:     positie eindpunt constructie linksboven in m t.o.v. oorspr
%   err1:   foutaanduiding; 0: geen fouten, 101: gebruiker heeft op
%               calcel gedrukt, 301: fout in invoerbestand
%
%

%% Initialize parameters:
err1       = 0;

% time step:
Inparm.dt       = 0.02;
    
% coordinates of nodges in pixes:
Inparm.pos0     = [0  560]; % position of origin in pixels
Inparm.pos1     = [560 560]; % lower right point 
Inparm.pos2     = [0  0]; % upper left point 

% coordinates in m:
%   Inparm.new0     = [0 0];   % defined as origin
Inparm.new1     = [0.50 0];
Inparm.new2     = [0    0.20];
    
% coordinates of construction in m:
Inparm.x1       = [0.560 0];    % lower right point 
Inparm.x2       = [0 0.295];    % upper left point 

%% open input file:
filetext = 'File containing parameters of data file';
[filenaam, padnaam] = FN_chsfile(filetext);

% user wants to continue:
if filenaam~=0
    infile = [padnaam filenaam];
    FID = fopen(infile,'r');

    % read first 8 lines:
    i=1;
    while feof(FID)==0 & i<=8
        lijn{i} = fgets(FID);
        i = i+1;
    end    

    if i<=8
        err1 = 301;
        h = msgbox('Parameter file must have 4 lines','Vels');
        uiwait(h);
    else
        tekst   = char(lijn{1});
        len     = length(tekst);
        br 		= findstr(tekst,':');
        lenbr   = length(br);
        if lenbr>0
            Inparm.dt   = str2num(tekst(br(lenbr)+1:len));
            errpos = zeros(1,7);
            [Inparm.pos0,errpos(1)] = readpos(lijn{2});
            [Inparm.pos1,errpos(2)] = readpos(lijn{3});
            [Inparm.pos2,errpos(3)] = readpos(lijn{4});
            [Inparm.new1,errpos(4)] = readpos(lijn{5});
            [Inparm.new2,errpos(5)] = readpos(lijn{6});
            [Inparm.x1,errpos(6)]   = readpos(lijn{7});
            [Inparm.x2,errpos(7)]   = readpos(lijn{8});
            errsum = sum(errpos);
            if errsum>0.5
                err1 = 301;
            end    
        
        % fout in eerste regel:    
        else    
            err1 = 301;
            h = ...
msgbox('Line in parameter file must have at least one : as a break symbol',...
                'Vels');
            uiwait(h);
        end    
    end    
    fclose(FID);
    
% gebruiker heeft op Cancel gedrukt:    
else
    err1 = 101;
end    

% Einde FN_inparmv2

function [pos,err] = readpos(regel)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% lees positie uit regel
% 9-6-05
% invoer:
%   regel:  cell met tekst, moet : bevatten gevolgd door twee getallen
%
% uitvoer:
%   pos:    vector met de waarde van de getallen in regel
%   err:    0: geen fouten, 301: fout in regel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tekst   = char(regel);
len     = length(tekst);
br 		= findstr(tekst,':');
lenbr   = length(br);
err     = 0;
if lenbr>0
    pos     = sscanf(tekst(br(lenbr)+1:len),'%g %g');
    pos     = pos';
else
    err=301;
    pos = [-1 -1];
    h = ...
msgbox('Line in parameter file must have at least one : as a break symbol',...
                'Vels');
    uiwait(h);
end
% einde readpos