function [At1,ucL,ucn,acL,acn] = FN_trans4(Inparm,At,ux,uy,ax,ay)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_trans4
%   Berekent snelheids- en versnellingscomponenten t.o.v. een 
%   gegeven constructie
%   versie 2, cd constructie in m
%   7-6-05
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   Inparm: structure met invoerparameters:
%      dt:     tijdstap
%      pos0:   positie (nieuwe) oorsprong in pixels
%      pos1:   positie eindpunt rechtsonder in pixels
%      pos2:   positie eindpunt linksboven in pixels
%      new1:   positie eindpunt rechtsonder in m t.o.v. oorsprong
%      new2:   positie eindpunt linksboven in m t.o.v. oorsprong
%      x1:     positie eindpunt constructie rechtsonder in m t.o.v. oorspr
%      x2:     positie eindpunt constructie linksboven in m t.o.v. oorspr
%   At: transformatiematrix van pixels naar m
%   ux: vector met x-component snelheden
%   uy: vector met y-component snelheden
%   ax: vector met x-component versnellingen
%   ay: vector met y-component versnellingen
%   
%
% uitvoer:
%   At1:    transformatiematrix
%   ucL:    vector met snelheidscomponenten in richting van constr.
%   uyn:    vector met snelheidscomponenten loodrecht op constr.
%   acL:    vector met versnellingscomponenten in richting van constr.
%   uyn:    vector met versnellingscomponenten loodrecht op constr.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% bepaal transformatiematrix:
% richtingscoeff: 
% m = (y2-y1)/(x2-x1) met [x1 y1] en [x2 y2] de posities van
% de constructie in m.
% de transformatievergelijkingen zijn
% (zie webpagina Vlm, Laboratory, Support, scanxy):
% m=tg(alpha),
% x' = x cos(alpha) + y sin(alpha)
% y' = y cos(alpha) - x sin(alpha)
% uitgedrukt in m: 
%   cos(alpha) = 1/sqrt(1+m^2), sin(alpha) = m/sqrt(1+m^2)
% In de matrix [ux;uy] staan de (ux,uy)-vectoren in kolommen, dus
% At1 = [1/sqrt(1+m^2)  m/sqrt(1+m^2); -m/sqrt(1+m^2) 1/sqrt(1+m^2)]

% posities constructie in m:
pos_teen = Inparm.x1;
pos_top  = Inparm.x2;
m       = (pos_top(2)-pos_teen(2))/(pos_top(1)-pos_teen(1));
cosa    = 1/(sqrt(1+m^2));
sina    = m*cosa;
At1     = [cosa  sina; -sina  cosa];

% testuitvoer:
%[uitfile uitpad] = FN_chsoutf4('.txt','testbestand');
%fnaam = [uitpad uitfile];
%FID5 = fopen(fnaam,'w');
%d = datestr(now);
%fprintf(FID5,'Matlab test: transformatie ux en uy\r\n');
%fprintf(FID5,'%s\r\n\r\n',d);
%fprintf(FID5,'coordinates of construction in m\r\n:');
%fprintf(FID5,'lower right point: %8.3f %8.3f\r\n',pos_teen);
%fprintf(FID5,'upper left  point: %8.3f %8.3f\r\n',pos_top);
%fprintf(FID5,'slope:             %8.3f\r\n',m);
%fclose(FID5);

% bepaal componenten t.o.v. de constructie:
uc  = At1*[ux;uy];  % ux en uy zijn rijvectoren met samples, 
                    % [ux(i);uy(i)] zijn hier kolommen
ucL = uc(1,:);
ucn = uc(2,:);

ac  = At1*[ax;ay]; 
acL = ac(1,:);
acn = ac(2,:);

% einde FN_trans4