function uitfile=FN_uit8(in_name,Inparm,A,ind,At,At1,nf,nf1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_uit8
%   Zet invoergegens en elkele tussenresultaten van prog. Vels in
%   uitvoerbestand
%   1e uitvoer, versie 7 en 8
%   8-6-05, posities constructies in m
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   in_name: naam invoerbestand
%   Inparm: structure met invoerparameters:
%       dt:     tijdstap
%       pos0:   positie x=0, y=0 in pixels
%       pos1:   positie meest rechtse punt X-as in pixels
%       pos2:   positie bovenste punt Y-as in pixels
%       new1:   positie meest rechtse punt X-as in m t.o.v. oorsprong
%       new2:   positie bovenste punt Y-as in m t.o.v. oorsprong
%       x1:     positie eindpunt constructie rechtsonder in m t.o.v. oorspr
%       x2:     positie eindpunt constructie linksboven in m t.o.v. oorspr
%   A:      matrix met meetdata:
%           kol. 1: tijdnummer, dt opvragen via scherm
%           kol. 2: monsternummer
%           kol. 3: x-coordinaat
%           kol. 4: y-coordinaat
%   ind:    vector met indices weggelaten punten
%   At:     transf.matrix naar opgegeven assen
%   At1:    transf.matrix van assen naar constructie
%   nf:     aantal punten waarover de posities zijn gemiddeld
%   nf1:    aantal punten waarover in bepaling versnellingen 
%           over de snelheden is gemiddeld
%
% Uitvoer:
%   uitfile: naam uitvoerbestand (incl. pad)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

uitfile = '';
% uitvoerbestand:
tekst = 'file to write output data';
[uitnaam, uitpad] = FN_chsoutf4('.txt',tekst);
if uitnaam~=0
    uitfile = [uitpad uitnaam];
    FID6    = fopen(uitfile,'w');
    fprintf(FID6,'Vels version 7\r\n\r\n');
    fprintf(FID6,'Input file: %s\r\n', in_name);
    d1 = datestr(now);
    fprintf(FID6,'%s\r\n\r\n',d1);
    dt = 0.02;
    fprintf(FID6,'time step used:                    %10.4f\r\n',Inparm.dt);
    fprintf(FID6,'pos of origin [pixels]:            %4.0f %4.0f\r\n',...
        Inparm.pos0);
    fprintf(FID6,'rightmost point of X-axes [pixels]: %4.0f %4.0f\r\n',...
        Inparm.pos1);
    fprintf(FID6,'uppermost point of Y-axes [pixels]: %4.0f %4.0f\r\n',...
        Inparm.pos2);
    fprintf(FID6,'rightmost point of X-axes [m]:      %7.3f %7.3f\r\n', ...
        Inparm.new1);
    fprintf(FID6,'uppermost point of Y-axes [m]:      %7.3f %7.3f\r\n',...
        Inparm.new2);
    fprintf(FID6,'lower right endpoint of construction [m]: ');
    fprintf(FID6,'%7.3f %7.3f\r\n',Inparm.x1);
    fprintf(FID6,'upper left  endpoint of construction [m]: ');
    fprintf(FID6,'%7.3f %7.3f\r\n',Inparm.x2);
    
    fprintf(FID6,...
        '\r\n\r\nTransformation matrix from measurements to axes:\r\n');
    fprintf(FID6,'%10.4e %10.4e\r\n',At);
    fprintf(FID6,...
        '\r\n\r\nTransformation matrix from axes to construction:\r\n');
    fprintf(FID6,'%10.4e %10.4e\r\n',At1);
    
    fprintf(FID6,'\r\nVelocities calculated from positions, ');
    fprintf(FID6,'averaged over %d points\r\n',nf);
    fprintf(FID6,'\r\nAccelerations calculated from velocities, \r\n');
    fprintf(FID6,'averaged over %d points\r\n',nf1);
    nsamp   = size(A,1);
    fprintf(FID6,'\r\nInput matrix (*: point discarded):\r\n');
    fprintf(FID6,'  t    n    x    y\r\n');
    k=1;
    for i=1:nsamp
        fprintf(FID6,'%4.0f %4.0f %4.0f %4.0f',A(i,:));
        if i==ind(k)
            fprintf(FID6,' *\r\n');
            k = k+1;
        else
            fprintf(FID6,' \r\n');
        end    
    end

    fclose(FID6);    
    
end

% einde FN_uit6