function [ind,t,x,y,ux,uy] = FN_vels4(A,Inparm,At);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_vels4
%   Berekent x- en y-posities en snelheden uit matrix A
%   versie 4: slaat indices weggelaten punten van A op 
%   12-5-05
%
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%
%   A:  meetgegevens
%   kol. 1: tijdnummer, dt opvragen via scherm
%   kol. 2: monsternummer
%   kol. 3: x-coordinaat
%   kol. 4: y-coordinaat
%   Inparm: structure met invoerparameters:
%       dt:     tijdstap
%       pos0:   positie (nieuwe) oorsprong in pixels
%       pos1:   positie eindpunt rechtsonder in pixels
%       pos2:   positie eindpunt linksboven in pixels
%       new1:   positie eindpunt rechtsonder in m t.o.v. oorsprong
%       new2:   positie eindpunt linksboven in m t.o.v. oorsprong
%   At: transformatiematrix pixels naam meters t.o.v. gegeven oorsprong
%
% uitvoer:
%   ind: indices weggelaten punten
%   t:  tijdvector
%   x:  vector met x-coordinaten t.o.v.stelsel
%   y:  vector met y-coordinaten t.o.v.
%   ux: vector met dx/dt
%   uy: vector met dy/dt
%
% Sommige x- en y-waarden liggen buiten het bereik
% Waarden met x<thresh | y<thresh worden
% weggelaten (hier: thresh = 100)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

thresh  = 100;
nsamp   = size(A,1);
A1      = A;
ind     = zeros(nsamp);

% bepaal tijd:
% dt = input('tijdstap (s)?  ');
dt      = Inparm.dt;
A1(:,1) = dt*A(:,1);

% verwijder buiten het gebied liggende punten:
% opm.: kan misschien sneller door ind met een Matlabfunctie te
% bepalen, en alle ind in 1 keer uit A te verwijderen; evt. later
j = 1; k = 1;
for i=1:nsamp
    if A1(j,3)<thresh | A1(j,4)<thresh
        A1(j,:) = [];
        ind(k)  = (i);
        k       = k+1;
    else
        j = j+1;
    end    
end


% y omkeren:
nsamp1  = size(A1,1);
e       = ones(nsamp1,1);
%A1(:,4) = 600*e - A1(:,4);

% coord in pixels t.o.v. oorsprong:
A1(:,3) = A1(:,3) - Inparm.pos0(1)*e;
A1(:,4) = A1(:,4) - Inparm.pos0(2)*e;

% bereken nieuwe coordinaten:
B = At*[A1(:,3) A1(:,4)]';
%B(:,1:10)
B = B';
%B(1:10,:)

%[uitfile uitpad] = FN_chsoutf4('.txt','testbestand');
%fnaam = [uitpad uitfile];
%FID5 = fopen(fnaam,'w');
%d = datestr(now);
%fprintf(FID5,'Matlab test: transformatie x en y\r\n');
%fprintf(FID5,'%s\r\n\r\n',d);
%fprintf(FID5,'     old           new\r\n');

%for i=1:10
%    fprintf(FID5,'%4d %4d %5.2f %5.2f\r\n',A(i,3), A(i,4),B(i,1), B(i,2));
%end
%fclose(FID5);

% bepaal snelheden:
v   = diff(B);
dt  = diff(A1(:,1));

% bereken snelheden:
nsamp = size(v,1);
eps1 = 0.5*Inparm.dt;
for i=1:nsamp
    if dt(i)>eps1
        ux(i) = v(i,1)/dt(i);
        uy(i) = v(i,2)/dt(i);
    else
        ux(i) = 0;
        uy(i) = 0;
    end    
end

% gaat fout bij v(j,1)=0
%ux      = v(:,3)./v(:,1);
%uy      = v(:,4)./v(:,1);

% bepaal tijden en coordinaten:
nsamp   = length(ux);
for i=1:nsamp
    t(i) = 0.5*(A1(i,1)+A1(i+1,1));
    x(i) = 0.5*(B(i,1)+B(i+1,1));
    y(i) = 0.5*(B(i,2)+B(i+1,2));
end    
%t = t';
%x = x';
%y = y';

% einde FN_vels3