function [A2,Fan,fn,nanal,error] = FN_harmo14(in_name,A1,Inparm,Scanparm)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_harmo_av
%   calculate scaled values and harmonics per column of a 2D matrix A
%   version av: used by Mov_av
%   5-Apr-05
%
%
%
%               H. Klaasman
%   version av: used by Mov_av
%   versie 14: aangepast aan algemene opzet (naamgving;
%       invoer parameters en dataselectie gescheiden)
%   versie 13: monsternummers aangepast; zoeken van nul-
%   doorgangen gewijzigd; begrenzing aantal harmonischen:
%   SFN_harm9->SFN_harm10
%   versie 11 van FN_harmo, uitvoer naar scherm via msgbox,
%   nuldoorgangen, FFT, ophoging van N tot 20 pnt per periode
%
%function [Fan,fn,nanal] = FN_harmo13(FID1,in_name,A,Inparm);
% @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
% @ Methode: nuldoorgangen, FFT, ophoging van N tot npmin
% @ (lokale variabele, npmin=20)
% @ bemonsteringen per periode, 1 harmonische
% @ hulpf.:  SFN_zeros, SFN_harm9
% @ versie 11: zonder afdruk
% @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

% De kolommen van A1 moeten een regelmatige golf met 1 of meer
% harmonischen bevatten. De periode van de 1e kolom van A
% wordt bepaald. Het aantal gebruikte punten wordt bepaald
% uit nuldoorgangen aan het begin en het eind van de meetreeks
% (A1-mean(A1)). Dit aantal wordt verdubbeld tot de gevonden 
% f constant is.
%				        H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%	FID1:   identificatie uitvoerbestand (voor testuitvoer)
%   in_name: naam van de invoerfile (nodig voor FN_plot9)
% 	A1:	invoermatrix, wordt per kolom geanalyseerd
%   Inparm: parameters to be typed by user
%       dt:     time step in measurements s (used before: tijdstap)
%       nharm:  number of harmonics to be printed
%       h:      water depth in m (used before: waterdiepte)
%               samp1: first sample to be analysed (replaced by
%                       Scanparm.t1)
%               samp2:  last sample to be analysed (replaced by
%                       Scanparm.t2)
%       ncols:  number of chanels to be processed (here:2)
%	    col:	rowvector with column numbers channels
%               (used before: col1 (col one), col2)
%       x:      rowvector with X-coordinates (used before: X1, X2)
%       sc:     rowvector with scale factor measurement values to m
%               (used before: sch1, sch2)
%   Scanparm:   structure with information about samples asked by user:
%       t1:     begin time asked (begin time used: Ts(1))
%       t2:     end time asked (end time used: Ts(length(Ts)))
%       step:   sample step with respect to the measurements
%       dt:     time step in the sampled data (vector Ts)

%
% uitvoer:
%   A2:     matrix with scaled values
%	Fan:	matrix met fft-componenten * 2/N * Inparm.schaal
%			    voor Inparm.nharm harmonischen
%           Fan(i,j): i-de harmonische voor j-de kolom van A 
%	fn:		matrix met frequenties voor Inparm.nharm harmonischen
%           van A (zelfde indicering als Fan).
%%%%%%%%%%%%	dt:		tijdstap na herbemonstering
%	nanal:	aantal punten gebruikt voor fft na herbemonstering
%   error:  0: geen fouten, 101: te lage bemonstering,
%           301: gevraagd kanaal bestaat niet
%           302: 1e harmonische op kanalen verschilt 

Fan     = [];
fn      = [];
nanal   = 0;
error = 0;

% aftrek gemiddelde om de periode te kunnen bepalen:
% bij verdere ontwikkeling van FN_harmo:
% gebruik bij ruis een symmetrisch laagdoorlaatfilter (testen)
[nsamp,nchan] = size(A1);
amean	= mean(A1);
e		= ones(nsamp,1);
A2		= A1 - e*amean;

% schalen naar m:
schaal  = e*Inparm.sc;  % uitproberen: sc moet rijvector zijn
A2      = schaal.*A2;
dt      = Scanparm.dt;  % was Inparm, met nieuwe opzet: Scanparm
f1      = 0;
deltaf  = 1;
eps     = 1e-3;
itmax   = 5;

% wijzing in Nmax op 25-1-01: als nsamp>Nmax gebeurt er niets, en dat is niet de
% bedoeling. Of het met deze wijziging goed gaat met nog worden getest, Hkl, 25-1-01
%Nmax   = 30000;
Nmax    = max(nsamp,30000);
N       = nsamp;
npmin   = 20;
%fprintf(FID1,'\r\nResults of FN_harmo9\r\n');
   
% bepaal nuldoorgangen
[i1,i2] = SFN_zeros3(A2);

% A2(i1,1) en A2(i2,1) hebben een verschillend teken,
% A2(i2+1,1) heeft het teken van A2(i1,1)

N       = i2 - i1 +1;
% fprintf(FID1,'N = %d\r\n',N);

% bepaal de gevraagde harmonischen met N punten:
nharm   = Inparm.nharm;
%[Fan,fn]  = SFN_harm9(FID1,nharm,A2,N,dt);
[Fan,fn]  = SFN_harm10(nharm,A2,N,dt);
   
% aantal bemonsteringen per periode:
f = mean(fn(1,:)');
nper = 1/(fn(1)*dt);
% fprintf(FID1,'\r\nNumber of samples per period: %8.2f\r\n', nper);
if nper<npmin
 	nprod = ceil(npmin/nper);
    error = 101;
    %	fprintf(FID1,'\r\n********************************************************\r\n');
    %	fprintf(FID1,'* Warning:                                             *\r\n');
    %   fprintf(FID1,'*  If the number of samples per period is less than 20 *\r\n');
    %   fprintf(FID1,'*  the phase may be inaccurate                         *\r\n');
    %   fprintf(FID1,'********************************************************\r\n');
    regel1 = sprintf('If the number of samples per period is less than 20\n');
    regel2 = sprintf('the phase may be inaccurate');                       
    tekst   = [regel1 regel2];
    h       = msgbox(tekst);
    uiwait(h);
    % herbemonstering als het aantal punten niet te groot
    if nprod*nsamp <= Nmax
    %	fprintf(FID1,'\nresampling by factor: %d\n', nprod);
      	A3      = resample(A2,nprod,1);
        A2      = A3;
        dt      = dt/nprod;
        [nsamp,nchan] = size(A2);
     
        % bepaal nuldoorgangen
     	[i1,i2] = SFN_zeros3(A2);
       	N       = i2 - i1 +1;
     %	fprintf(FID1,'N = %d\n',N);

   		% bepaal nharm harmonischen met N punten:
   		[Fan,fn]  = SFN_harm10(nharm,A2,N,dt);

   end   % N<=Nmax
   
end		% nper<npmin

nanal = N;
% 1e harmonische moet op beide kanalen gelijk zijn:
df      = abs(fn(1,1)-fn(1,2));
deltaf  = 1/(N*Inparm.dt);
if df>5*deltaf
    error = 102;
end

% einde FN_harmo5t

function [Fan,fn] = SFN_harm10(nharm,A,N,dt)
%function [Fan,fn] = SFN_harm9(FID1,nharm,A,N,dt);
% SFN_harm10 berekent nharm harmonischen uit N punten van array A.
% versie 10: alleen beschikbare harmonischen worden bepaald
% 26-5-03
% invoer:
%	FID1:	identificatie uitvoerbestand
%   nharm:  gewenst aantal harmonischen
% 	A:		array met te bewerken waarden per kolom
%   N:		aantal voor de FFT te gebruiken punten
%	dt:		tijdstap
%
% uitvoer:
%	Fan:	Fan(i,j) is de i-de harmonische van de j-de kolom van A
%	fn:		frequenties harmonischen uit de eerste kolom van A
%
%					H. Klaasman 

[nsamp,nchan] = size(A);
T       = N*dt;
df      = 1/T;

% bepaal fft voor N:
B = fft(A,N);
[Nf,nc] = size(B);

% voor schaling B moet worden vermenigvuldigd met 2/N 
fact = 2/N;
B = fact*B;

% bepaal het maximum van de helft van de eerste kolom van B:
Nf2 = ceil(Nf/2);
fr  = 0:df:(Nf2-1)*df;
c   = abs(B(1:Nf2,:));
c(1,:)  = 0;
[c1,i1] = max(c);

% Bepaal aantal aanwezige harmonischen binnen FFT-gebied:
i_first     = max(i1);
ntot        = floor(Nf2/i_first);
nharm1      = min(nharm,ntot);
if nharm1<nharm
    tekst1 = sprintf('Warning: number of harmonic components asked\r\n');
    tekst2 = sprintf('exceeds components available in FFT\r\n');
    tekst   = [tekst1 tekst2];
    h1       = msgbox(tekst);
    uiwait(h1);
 end    

% bepaal de spectrale componenten (zie Users Guide p.6-31);
Fan(1,1)    = B(i1(1),1);
Fan(1,2)    = B(i1(2),2);
fn(1,1)     = fr(i1(1));
fn(1,2)     = fr(i1(2));

for j=2:nharm1
    ij      = j*(i1-1)+1;       % 0-de component zit op index 1
    [c2,i2] = max(c(ij-2:ij+2));
    i2      = i2+ij-3;
    Fan(j,1)    = B(i2(1),1);
    Fan(j,2)    = B(i2(2),2);
    fn(j,1)     = fr(i2(1));
    fn(j,2)     = fr(i2(2));
end    


% afdruk harmonischen:
%fprintf(FID1,'\r\nResults of SFN_harm10:\r\n');
%fprintf(FID1,'\r\nnumber of samples: %d\r\n', N);
%C   = Fan.';
%amp = abs(Fan);
%a   = real(Fan);
%b   =-imag(Fan);	% algemeen voor FT: c(i) = a(i) - i*b(i)		
%phi = angle(Fan);	
%for i=1:2
%    fprintf(FID1,'\r\nposition %d\r\n',i);
%    fprintf(FID1,'  i         f            a            b            c            phi\r\n');%
%    for j=1:nharm
%        fprintf(FID1,'%4.0f %12.6f %12.6f %12.6f %12.6f %12.6f\r\n',...
%          j,fn(j,i),a(j,i),b(j,i),amp(j,i),phi(j,i));
%    end
%end    
  

% testuitvoer
%C = B.';
%amp = abs(C);
%a = real(C);
%b =-imag(C);	% algemeen voor FT: c(i) = a(i) - i*b(i)		
%phi = angle(C);	
%for i=1:2
%    fprintf(FID1,'\r\nposition %d\r\n',i);
%    fprintf(FID1,'  i         f            a            b            c            phi\r\n');
%    for k=1:nharm
%        i2 = k*(i1(1)-1)+1;	% 0-de term op index 1
%        for j=i2-5:i2+5
%                fprintf(FID1,'%4.0f %12.6f %12.6f %12.6f %12.6f %12.6f\r\n',...
%                j,fr(j),a(i,j),b(i,j),amp(i,j),phi(i,j));
%        end
%    end
%end    

% einde SFN_harm10