function [Inparm,error] = FN_inparm2(scr_num,nchan)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_inparm2
%   ask input parameters for all scripts
%   version 2, using Options
%   28-Feb-05, change \tmp-files, 4-Apr-05
%   change text: time step in org. data file, 18-Apr-05
%   change: 26-May-05: eps->eps1
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% hulpbestanden:
% 	voor elke script wordt een apart hulpbestand in tmp gezet
%   (als alles in 1 hulpbestand zou zitten zou de gebruiker 
%   steeds opnieuw moeten bedenken wat zijn waarden bij de vorige
%   run waren)
%
% invoer:
%   scr_num:    scriptnummer (zie switch in deze script)
%   nchan:      aantal ingelezen kanalen (nodig voor Lvmview)
% uitvoer:
%   Voor de velden van de uitvoerparameter Inparm worden zoveel
%   mogelijk universele namen gebruikt.
%   Welke velden een waarde krijgen hangt af ven de applicatie
%   (alternatief: het gebruik van handles !!)
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: als bij Decomp, zie onder col)
%       dt:     tijdstap
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_min:  ondergrens te berekenen freq-gebied
%       f_max:  bovengrens te berekenen freq.gebied (-1: autom.)
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       nharm:  aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten (xp: xpos, n.a.v. Decomp v.14 en ouder)
%       hxp:    dieptes op plaatsen van de golfhoogtemeters (wordt berekend
%               uit overige invoerparameters, alleen Decomp)
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%       x:      rijvector met x-coordinaten waarvoor het diepteprofiel is
%               gegeven (nu: alleen Decomp)
%       h:      dieptes in diepteprofiel (nu: alleen Decomp)
%	error:	0: doorgaan, 101: stoppen
%				H. Klaasman

% te gebuiken instellingen voor dialoogschermen;
V = version;
v1=str2num(V(1:1));
if v1<6.9
% versie 6.5 (evt. 6?):
    Options = 'on'; % alternatief, werkt goed in Matlab 6.5 (Rel.13)
else    
% versie 7: WindowStyle op normal om dialoogscherm klein te kunnen
%           maken en Help te vragen
    Options.WindowStyle='normal';  
    Options.Resizable='on';
end    

% Lees gegevens, afhankelijk van gewenste applicatie
switch scr_num
    case 1
        % Asc2wav
        [Inparm,error] = SFN_inparmA2w(Options);
    case 2    
        % Bekijkb
        [Inparm,error] = SFN_inparmB(Options);
    case 3
        % Lvmview
        ch_sel = 1;
        [Inparm,error] = SFN_inparmL(nchan,ch_sel,Options);
    case 4
        % Pwspect
        [Inparm,error] = SFN_inparmPws(Options);
    case 5
        % Refreg
        [Inparm,error] = SFN_inparmR(Options);
    case 6
        % Spect
        [Inparm,error] = SFN_inparmS(Options);
    case 7
        % Decomp
        [Inparm,error] = SFN_inparmD(Options);
    case 8
        % Lvmsp
        ch_sel=0;
        [Inparm,error] = SFN_inparmL(nchan,ch_sel,Options);
    otherwise
        error = 310;
end % switch scr_num

% einde FN_inparm

function [Inparm,error] = SFN_inparmA2w(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmA2w
%   vraagt invoerparameters voor programma Asc2wav.
%   27-1-05, changed: 18-Apr-05 (text only)

%% Geef parameters een beginwaarde:
error       =    0;  
start  		=    0;
Inparm.dt 	= 0.02;
Inparm.hm  	= 0.6;
Inparm.colt = 0; % vaste waarde, wordt in Asc2wav (nog) niet gebruikt
                 % ev. toevoegen
Inparm.ncols= 1;    % was 2, 22-4-04
Inparm.col	= [2];      % was [2 3], 22-4-04
Inparm.xp	= [0];      % was [0 0.25], 22-4-04
Inparm.sc  	= [0.025];  % was [0.025 0.025], 22-4-04
Def   = {'0.01','0.6','1'};

%% Lees actuele parameterwaarden:
if exist('.\Tmp')==0
	mkdir('.\Tmp');
end
FID=fopen('.\Tmp\inparma2w.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      		lijn=fgetl(FID);
      		Def{i}=char(lijn);
		i = i+1;
	end
	fclose(FID);
end   

%Inparmmenu = uide('Menuedit');
%Menuedit(Inparm1);
Prompt1 = {'time step in org. data file','water depth in m', ...
	  'number of columns to be analysed'};
Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt1,Title,1,Def,Options);

if length(Inparm1)>0
	start=1;
        
    %lees kolomnummers en x-coords:
	ncols = str2num(Inparm1{3});
	dx = 0.25;
	Prompt2 = {'column number', 'x-cd in m', ...
            'scale factor measurements values to desired values'};
    i=1;
    while i<=ncols & start>0.5
        	nr      = num2str(i);
           	infile1 = ['.\Tmp\in' nr '.txt'];
           	FID1    = fopen(infile1,'r');
           	if FID1>=0
       			lijn    = fgetl(FID1);
               	Def1{1}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{2}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{3}  = char(lijn);
      			fclose(FID1);
        	else   
		        Def1{1}	= char(num2str(i+1));
		        x	    = (i-1)*dx;
		        Def1{2}	= char(num2str(x));
                y       = 0.025;
		        Def1{3}	= char(num2str(y));
            end
    		
            % laatste parameter ('on') veranderd in Options
            % in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
            Inparm2 = inputdlg(Prompt2,Title,1,Def1,Options);
            if length(Inparm2)>0 
    		    Inparm.col(i)  = str2num(Inparm2{1});  
		        Inparm.xp(i)	    = str2num(Inparm2{2});
                Inparm.sc(i)     = str2num(Inparm2{3});
        		FID1=fopen(infile1,'w');
		        fprintf(FID1,'%g\r\n',Inparm.col(i));
    		    fprintf(FID1,'%g\r\n',Inparm.xp(i));
                fprintf(FID1,'%g\r\n',Inparm.sc(i));
                fclose(FID1);
            else
                start = 0;
                error = 101;
            end    
            i = i+1;
	end  
    if start>0.5
    	Inparm.dt       = str2num(Inparm1{1});
    	Inparm.hm        = str2num(Inparm1{2});
    	Inparm.ncols    = ncols;

    	%% schrijf nieuwe waarden in hulpbestand: 
    	FID=fopen('.\Tmp\inparma2w.txt','w');
    	fprintf(FID,'%g\r\n',Inparm.dt);
    	fprintf(FID,'%g\r\n',Inparm.hm);
    	fprintf(FID,'%g\r\n',Inparm.ncols);
    	fclose(FID);
    end % start >0.5   
else
	error=101;
end

% Einde SFN_inparmA2w

function [Inparm,error] = SFN_inparmB(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmB
%   vraagt invoerparameters voor programma Lvmview.
%   27-1-05, aanp. Matlab 6.5, 16-2-05,
%				H. Klaasman

%% Geef parameters een beginwaarde:
start           = 0;
error           = 0;
% De volgende parameters worden niet opgevraagd:
Inparm.dt       = 0.02;  % wordt bepaald aan de hand van het gebruikte 
                         % golfschot
Inparm.colt     = 0;
Inparm.ncols    = 1;
Inparm.col(1)   = 1;

% De volgende parameters worden opgevraagd:
Inparm.wavb     = 'h';
Inparm.units    = 'V';
Def   = {'h','V'};

%% Lees actuele parameterwaarden:
if exist('.\Tmp')==0
	mkdir('.\Tmp');
end

FID=fopen('.\Tmp\inparmb.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      lijn=fgetl(FID);
      Def{i}=char(lijn);
	  i = i+1;
	end
	fclose(FID);
end   

Prompt = {'type of wave board (h hydraulic, e electrical)',...
      'units (val value, n normed value, V Voltage, m amplitude of board in m)'};
Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt,Title,1,Def,Options);

if length(Inparm1)>0
		start=1;
        Inparm.wavb     = Inparm1{1};
        Inparm.units    = Inparm1{2};

		%% schrijf nieuwe waarden in hulpbestand: 
		FID=fopen('.\Tmp\inparmb.txt','w');
		fprintf(FID,'%s\r\n',Inparm.wavb);
		fprintf(FID,'%s\r\n',Inparm.units);
   		fclose(FID);
else
   		error=101;
end

% bepaal de tijdstap:
if Inparm.wavb=='e'
    Inparm.dt = 0.04;
else
    Inparm.dt = 0.02;
end    
% Einde SFN_inparmB

function [Inparm,error] = SFN_inparmL(nchan,ch_sel,Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmL
%   vraagt invoerparameters voor functie FN_lvmplot en Lvmsp
%   27-1-05, tekst aangepast, 18-4-05
%
%
% hulpbestand:
% 	inparmL.txt
% invoer:
%   nchan:  aantal ingelezen kanalen
%   ch_sel: 0: geen kanalen selecteren, 1: kanalen selecteren
% uitvoer:
%	Inparm:	structure met invoerparameters
%				H. Klaasman

%% Geef parameters een beginwaarde:
start       = 0;
error       = 0;
Inparm.dt   = 0.02;
Inparm.colt = 1;
Inparm.col	= 1:nchan;  % gewijzigd, was [2 3], Hkl, 28-5-02
Def   = {'0.02','1'};

%% Lees actuele parameterwaarden:
if exist('.\Tmp')==0
	mkdir('.\Tmp');
end

FID=fopen('.\Tmp\inparmL.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      lijn=fgetl(FID);
      Def{i}=char(lijn);
	  i = i+1;
	end
	fclose(FID);
end   

Prompt = {'time step in original data file (s)', ...
    'column number of channel containing the time (0: none)'};

Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt,Title,1,Def,Options);
if length(Inparm1)>0
	start=1;
	       
    Inparm.dt   = str2num(Inparm1{1});
    Inparm.colt = str2num(Inparm1{2});
        
    %lees kanaal(=kolom)nummers:
    if ch_sel==1
    
        % het kanaal met de tijd krijgt in de selectielijst de tekst 'tm',
        % de overige krijgen het nummer:
		for i=1:nchan
			if i==Inparm.colt
				S{i} = 'tm';
			else
	            		S{i} = num2str(i);
			end		
		end

        % selectielijst om kanalen te kiezen:
		Name = 'channels';
		[Selection,ok] = listdlg('ListString',S,'Name',Name);
		if ok==1
			Inparm.col      = Selection;
        else
       		start=0;    % ok==0
            error=101;
        end    
    end    
      
    %% schrijf nieuwe waarden in hulpbestand: 
    FID=fopen('.\Tmp\inparmL.txt','w');
    fprintf(FID,'%g\r\n',Inparm.dt);
    fprintf(FID,'%g\r\n',Inparm.colt);
    fclose(FID);
        
else
    error=101;    % Inparm leeg, 'cancel'
end    

% Einde SFN_inparmL

function [Inparm,error] = SFN_inparmPws(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmPws
%   ask for input parameters to be used by Pwspect.
%   27-1-05, changed: 18-Apr-05 (text only)
%
%
%					H.Klaasman
% hulpbestand:
% 	inparmpws.txt

%% Geef parameters een beginwaarde:
error       = 0;
eps1         = 1e-6;
Inparm.dt   = 0.02;         % tijdstap
Inparm.fres = 0.02;         % gewenste resolute in spectrum
Inparm.f_max= 2;            % bovengrens te berekenen frequenties
Inparm.colt = 1;            % kolom met tijden
Inparm.ncols= 1;            % aantal te verwerken kolommen
                            % gewijzigd van 2 in 1, 22-4-04
Inparm.col  = [2];          % kolommen met golfhoogtemeters
                            % was [2 3], 22-4-04
Inparm.sc   = [0.025];      % schaalfactoren meetw. golfhoogtemeters
                            % was [0.025 0.025], 22-4-04

Def   = {'0.02','0.02','2','1','2'};

%% Lees actuele parameterwaarden:
if exist('.\Tmp')==0
	mkdir('.\Tmp');
end
FID=fopen('.\Tmp\inparmpws.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      		lijn=fgetl(FID);
      		Def{i}=char(lijn);
		i = i+1;
	end
	fclose(FID);
end   

Prompt1 = {'time step in org. data file (s)', ...
    'desired frequency step (Hz)', ...
    'max freq in graph (Hz)', ... 
    'column with times', ...
	'number of columns to be analysed'};
Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt1,Title,1,Def,Options);

if length(Inparm1)>0
	start=1;
        
    %lees kolomnummers en schaalfactoren:
	ncols = str2num(Inparm1{5});
	Prompt2 = {'column number', ...
            'scale factor measurement values to m'};
    i=1;
    while i<=ncols & start>0.5
        	nr      = num2str(i);
           	infile1 = ['.\Tmp\inpsw' nr '.txt'];
           	FID1    = fopen(infile1,'r');
           	if FID1>=0
       			lijn    = fgetl(FID1);
               	Def1{1}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{2}  = char(lijn);
      			fclose(FID1);
        	else   
		        Def1{1}	= char(num2str(i+1));
                y       = 0.025;
		        Def1{2}	= char(num2str(y));
            end

            % laatste parameter ('on') veranderd in Options
            % in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
            Inparm2 = inputdlg(Prompt2,Title,1,Def1,Options);
            if length(Inparm2)>0 
    		    Inparm.col(i)= str2num(Inparm2{1});  
                Inparm.sc(i) = str2num(Inparm2{2});
        		FID1=fopen(infile1,'w');
		        fprintf(FID1,'%g\r\n',Inparm.col(i));
                fprintf(FID1,'%g\r\n',Inparm.sc(i));
                fclose(FID1);
            else
                start = 0;
                error = 101;
            end    
            i = i+1;
	end  
    if start>0.5
    	Inparm.dt       = str2num(Inparm1{1});
    	Inparm.fres     = str2num(Inparm1{2});
    	Inparm.f_max    = str2num(Inparm1{3});
      	Inparm.colt		= str2num(Inparm1{4});
    	Inparm.ncols    = ncols;

		%% schrijf nieuwe waarden in hulpbestand: 
		FID=fopen('.\Tmp\inparmpws.txt','w');
		fprintf(FID,'%g\r\n',Inparm.dt);
		fprintf(FID,'%g\r\n',Inparm.fres);
		fprintf(FID,'%g\r\n',Inparm.f_max);
		fprintf(FID,'%g\r\n',Inparm.colt);
        fprintf(FID,'%g\r\n',Inparm.ncols);
   		fclose(FID);
    end    
else
   		start=0;
        error = 101;
end

% Einde SFN_inparmPws

function [Inparm,error] = SFN_inparmR(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmR
%   vraagt invoerparameters voor Refreg13 en later aan de 
%   gebruiker.
%   4-Apr-05, changed: 18-Apr-05 (text only)
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% hulpbestand:
% 	inparmr.txt

%% Geef parameters een beginwaarde:
start = 1;
error = 0;
Inparm.dt       = 0.02;
Inparm.nharm    = 5;
Inparm.hm       = 0.6;
Inparm.colt     = 0;
Inparm.col      = [2,3];
Inparm.xp       = [0,0.4];  % was pos, moet volgens mij xp zijn,
                            % Hkl, 19-1-05
Inparm.sc       = [0.025,0.025];
Def1   = {'0.01','5','0.6'};

%% Lees actuele parameterwaarden:
FID=fopen('.\Tmp\inparmr.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      lijn=fgetl(FID);
      Def1{i}=char(lijn);
      i = i+1;
	end
	fclose(FID);
end   

Prompt1 = {'timestep in org. data file',...
    'number of harmonic components to be printed',...
    'average waterdepth in m'};
Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt1,Title,1,Def1,Options);
%doorgaan:
if length(Inparm1)>0

    %lees kolomnummers en x-coords:
	ncols = 2;
	dx    = 0.4;
	Prompt2 = {'column number', 'x-cd in m', ...
            'scale factor measurements values to m'};
    i=1;
    while i<=ncols & start>0.5
        	nr      = num2str(i);
           	infile1 = ['.\Tmp\inr' nr '.txt'];
           	FID1    = fopen(infile1,'r');
           	if FID1>=0
       			lijn    = fgetl(FID1);
               	Def1{1}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{2}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{3}  = char(lijn);
      			fclose(FID1);
        	else   
		        Def1{1}	= char(num2str(i+1));
		        x	    = (i-1)*dx;
		        Def1{2}	= char(num2str(x));
                y       = 0.04;
		        Def1{3}	= char(num2str(y));
            end
            
            % laatste parameter ('on') veranderd in Options
            % in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
            Inparm2 = inputdlg(Prompt2,Title,1,Def1,Options);
            if length(Inparm2)>0 
    		    Inparm.col(i)  = str2num(Inparm2{1});  
		        Inparm.xp(i)	    = str2num(Inparm2{2});
                Inparm.sc(i)     = str2num(Inparm2{3});
        		FID1=fopen(infile1,'w');
		        fprintf(FID1,'%g\r\n',Inparm.col(i));
    		    fprintf(FID1,'%g\r\n',Inparm.xp(i));
                fprintf(FID1,'%g\r\n',Inparm.sc(i));
                fclose(FID1);
            else
                start = 0;
                error = 101;
            end    
            i = i+1;
	end  
    if start>0.5
    	Inparm.dt       = str2num(Inparm1{1});
    	Inparm.nharm    = str2num(Inparm1{2});
		Inparm.hm        = str2num(Inparm1{3});

		%% schrijf nieuwe waarden in hulpbestand: 
		FID=fopen('.\Tmp\inparmr.txt','w');
		fprintf(FID,'%g\r\n',Inparm.dt);
		fprintf(FID,'%g\r\n',Inparm.nharm);
		fprintf(FID,'%g\r\n',Inparm.hm);
        fclose(FID);
    end
% lengte Inparm1=0:
else
	start=0;
    error = 101;
end
    

% Einde SFN_inparmR

function [Inparm,error] = SFN_inparmS(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmS 
%   ask for input parameters to be used by Spect
%   27-1-05, changed: 18-Apr-05 (text only)
%					H.Klaasman
% help file:
% 	inparms.txt

%% Geef parameters een beginwaarde:
start = 0;
error = 0;
Inparm.dt       = 0.02;
Inparm.thresh   = 0.005;
Inparm.colt     = 0;
Inparm.ncols    = 1;
Inparm.col      = [2];
Inparm.sc       = [0.025];
Inparm.unit     = ['m'];

Def   = {'0.01','0.005','1'};

%% Lees actuele parameterwaarden:
FID=fopen('.\Tmp\inparms.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      lijn=fgetl(FID);
      Def{i}=char(lijn);
      i = i+1;
	end
	fclose(FID);
end   

Prompt = {'time step in org. data file', ...
    'threshold in spect, plot part >thresh*max of amp', ...
    'number of columns to be analysed'};
Title = 'Parameters';
% laatste parameter ('on') veranderd in Options
% in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
Inparm1 = inputdlg(Prompt,Title,1,Def,Options);

if length(Inparm1)>0
	start=1;

    %lees kolomnummers en schaalfactoren:
	ncols = str2num(Inparm1{3});
	Prompt2 = {'column number', ...
            'scale factor measurement values to units', ...
            'units'};
    i=1;
    while i<=ncols & start>0.5
        	nr      = num2str(i);
           	infile1 = ['.\Tmp\ins' nr '.txt'];
           	FID1    = fopen(infile1,'r');
           	if FID1>=0
       			lijn     = fgetl(FID1);
               	Def1{1}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{2}  = char(lijn);
               	lijn     = fgetl(FID1);
               	Def1{3}  = char(lijn);
      			fclose(FID1);
        	else   
		        Def1{1}	= char(num2str(i+1));
                y       = 0.025;
		        Def1{2}	= char(num2str(y));
		        Def1{3}	= 'm';
            end
            
            % laatste parameter ('on') veranderd in Options
            % in combinatie met Matlab 7 (rel. 14), Hkl, 27-1-05
    		Inparm2 = inputdlg(Prompt2,Title,1,Def1,Options);  
            if length(Inparm2)>0 
    		    Inparm.col(i)   = str2num(Inparm2{1});  
                Inparm.sc(i)    = str2num(Inparm2{2});
                Inparm.unit(i)  = Inparm2{3};
        		FID1=fopen(infile1,'w');
		        fprintf(FID1,'%g\r\n',Inparm.col(i));
                fprintf(FID1,'%g\r\n',Inparm.sc(i));
                fprintf(FID1,'%s\r\n',Inparm.unit(i));
                fclose(FID1);
            else
                start = 0;
                error = 101;
            end    
            i = i+1;
	end
    
    if start>0.5
       	Inparm.dt       = str2num(Inparm1{1});
        Inparm.thresh   = str2num(Inparm1{2});
        Inparm.ncols    = ncols;

        %% schrijf nieuwe waarden in hulpbestand: 
		FID=fopen('.\Tmp\inparms.txt','w');
		fprintf(FID,'%g\r\n',Inparm.dt);
        fprintf(FID,'%g\r\n',Inparm.thresh);
        fprintf(FID,'%g\r\n',Inparm.ncols);
   		fclose(FID);
    end
% length(Inparm1)==0
else
   		error=101;
end

% Einde SFN_inparms

function [Inparm,error] = SFN_inparmD(Options)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_inparmD
%   read time step, peakperiod and wanted freq. step, frequency range,
%   threshold, and data concerning wave gauges in a data file.
%   version 5: subfunction of FN_inparm
%   Jan 27, 2005
%
%   version 5: subfunction of FN_inparm
%   version 4: detection end of file and blank lines added
%   version 3: f-resol./Tp added
%   version 2: peakperiod, f_min, and f_max added
%   version 1a: scale factor measured values to m added
% input file: 
%   line 1:     time step in org. data file(s) (as text)
%   line 2:     time step
%   line 3:     peakperiod (s), f-resol/Tp, f_min (Hz), f_max( Hz), thresh (<=1)
%               (as text)
%   line 4:     peak period, frequency resolution/Tp , f_min, f_max, 
%               calculation range: f_min, f_max 
%               (if f_max=-1: 2 wave gauges: f_min-f_max calculatied from distances,
%               more wave gauges: f_min=0.02, f_max=2.5) 
%               threshold noise level in variance spectrum (E>=thresh*sum(E)/N)
%               numbers separated by commas.
%   line 5:     number of column containing times (0 if no times have been registrated) (as text)
%   line 6:     number of column containing times
%   line 7:     column  position (m)  scale fact to m (as text) 
%	next lines for each wave gauge:
%               column number, position, scale factor to m
%               separated by commas. 
%
% output parameters:
%   Inparm: structure containing parameters:
%       dt:     time step in org. data file
%       fres:   frequency-resolution wanted in variance spectrum
%       f_min:  underbound of frequencies to be calculated
%       f_max:  bovengrens te berekenen frequenties
%       thresh:  drempelwaarde ruisniveau variantiespectrum t.o.v. piekwaarde
%       colt:   nummer kolom met tijden
%	    Cols:	rijvector met nummers van de kolommen met golfhoogtemeters
%       xp:     rijvector met posities van de golfhoogtemeters in m
%       sc:     rijvector met schaalfactor meetwaarden naar m
%   error:  error indication: 0: no errors, 101: user clicked on Cancel,
%           301: error in input file
%
%												H. Klaasman

%% Initialize parameters:
error       = 0;
eps1         = 1e-6;
Inparm.dt   = 0.02;         % tijdstap
Tp          = 1.5;          % schatting piekperiode
sp_fact     = 0.035;        % gewenste frq.-resolutie is sp_fact/Tp
Inparm.fres = sp_fact/Tp;
Inparm.f_min = 0.45;        % ondergrens te berekenen frequenties
Inparm.f_max = 1.75;        % bovengrens te berekenen frequenties
Inparm.thresh = 0.001;       % drempel ruisniveau variantiespectrum t.o.v. piek
Inparm.colt = 1;            % kolom met tijden
Inparm.col  = [2 3];        % kolommen met golfhoogtemeters
Inparm.xp   = [0 1];        % posities golfhoogtemeters  
Inparm.sc   = [0.025 0.025];% schaalfactoren meetw. golfhoogtemeters
                            % naar meters
Inparm.x    = Inparm.xp;    % positievector
Inparm.h    = [0.6 0.6];    % diepteprofiel

%% open input file:
filetext = 'File containing parameters of data file';
[filenaam, padnaam] = FN_chsfile(filetext);

% user wants to continue:
if filenaam~=0
    infile = [padnaam filenaam];
    FID = fopen(infile,'r');

    % read first 7 lines:
    i=1;
    while feof(FID)==0 & i<=7
        lijn{i} = fgets(FID);
        i = i+1;
    end    

    if i<5
        error = 301;
        h = msgbox('Error in file containing parameters datafile','Decomp');
        uiwait(h);
    else
        Inparm.dt   = str2num(lijn{2});
        Inparm.colt = str2num(lijn{6});
        br 		    = findstr(lijn{4},',');
        if length(br)<4
            error = 301;
            h = msgbox('comma missing in parameter file','Decomp');
            uiwait(h);
        else    
            ln		    = length(lijn{4});  
            Tp          = str2num(lijn{4}(1:br(1)-1));
            sp_fact     = str2num(lijn{4}(br(1)+1:br(2)-1));
            Inparm.f_min= str2num(lijn{4}(br(2)+1:br(3)-1));
            Inparm.f_max= str2num(lijn{4}(br(3)+1:br(4)-1));
            Inparm.thresh= str2num(lijn{4}(br(4)+1:ln));
            Inparm.fres = sp_fact/Tp;
            if Inparm.dt<eps1
                Inparm.dt = 1;
            end
            if Inparm.fres<eps1
                Inparm.fres = 1;
            end
            if Inparm.f_min<eps1
                Inparm.f_min = 0.05;
            end    

            %%%%read parameters:
            i=1;
            lijn1 = fgets(FID);
            cont_rd = 1; % variable to enable stop of reading loop            
            while length(lijn1)>2 && cont_rd==1
                 br 		        = findstr(lijn1,',');
                 if length(br)<2
                    cont_rd=0
                    if length(br)>0    
                        error = 301;
                        h = msgbox('comma missing in parameter file','Decomp');
                        uiwait(h);
                    end    
                 else    
                    ln		        = length(lijn1);  
           	        Inparm.col(i)   = str2num(lijn1(1:br(1)-1));
                    Inparm.xp(i)    = str2num(lijn1(br(1)+1:br(2)-1));
                    Inparm.sc(i)    = str2num(lijn1(br(2)+1:ln));
                    i = i+1;
                    if feof(FID)==0
       	                lijn1	        = fgets(FID);
                    else
                        lijn1 = '';
                    end;    
                end
            end   
        end    
    end
    fclose(FID);
    
    % lees diepteprofiel:
    [x,h,error]   = FN_get_x_h2;         % water depths
    Inparm.x = x;
    Inparm.h = h;

    if error<1
            
       % hxp : water depth at locations of the wave gauges
       Inparm.hxp = interp1(x,h,Inparm.xp); 
    end   

% gebruiker heeft op Cancel gedrukt:    
else
    error = 101;
end    

% Einde SFN_inparmD

