function FN_outparmr19(scr_num,in_naam,Inparm,Scanparm,Outparm,error)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_outparmr19
%   General function to print input and output parameters
%   version only used with Refreg19 (only header adapted)
%   5-Apr-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer
%   scr_num:   nummer gebruikte script (zie FN_inparm)
%   in_naam:naam invoerbestand
%       hm:     gemiddelde waterdiepte in m (later: als bij Decomp, zie onder col)
%       dt:     tijdstap
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       nh:     aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten (xp: xpos, n.a.v. Decomp v.14 en ouder)
%       hxp:    dieptes op plaatsen van de golfhoogtemeters (wordt berekend
%               uit overige invoerparameters, alleen Decomp)
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%       x:      rijvector met x-coordinaten waarvoor het diepteprofiel is
%               gegeven (nu: alleen Decomp)
%       h:      dieptes in diepteprofiel (nu: alleen Decomp)
%
%   Scanparm:   structure gegevens over met gekozen samples: (uitv. v.
%               FN_selectnw2)
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%
%   Outparm:    structure met uitvoerparameters;
%               inhoud afhankelijk van uitgevoerde berekening
%   error:      de waarde 101 geeft een foumelding bij Refreg: 
%               te grof bemonsterd

                       

% Uitvoerbestand met resultaat:
[uitnaam, uitpad] = FN_chsoutf4('.txt','Output file (Statistic results)');
Header = {'Asc2wav','Bekijkb','Lvmview', ...
          'Pwspect v.3, calculation of variance spectra', ...
  'Refreg ver 19, refl of regular wave, substr. moving average', ...
          'Spect','Decomp v.15, calculation of reflection'};

if uitnaam~=0
    uitfile = [uitpad uitnaam];
    FID5    = fopen(uitfile,'w');
    fprintf(FID5,'Program %s\r\n',char(Header{scr_num}));
    d = datestr(now);
    fprintf(FID5,'%s\r\n\r\n',d);
    

    fprintf(FID5,'*************Input values******************\r\n');
    fprintf(FID5,'Input file: %s\r\n',in_naam);
    fprintf(FID5,'Time step in input file:     %8.4f s\r\n',Inparm.dt);
    fprintf(FID5,'\r\n\r\nTime interval asked:');
    fprintf(FID5,'                    %10.4f, %10.4f\r\n', ...
        Scanparm.tin1, Scanparm.tin2);
    fprintf(FID5,'Time interval used: ');
    fprintf(FID5,'                    %10.4f, %10.4f\r\n', ...
       Scanparm.tuit1, Scanparm.tuit2);
    fprintf(FID5,'Time step used:     ');
    fprintf(FID5,'                    %10.4f s', Scanparm.dt);
    fprintf(FID5,'\r\n\r\nNumber of samples used:');
    fprintf(FID5,'                   %6d\r\n', Outparm.N);
    
    fprintf(FID5,'\r\nChannels used:\r\n');
    fprintf(FID5,'\r\ncols:          ');
    fprintf(FID5,'%10d',Inparm.col);
    if isfield(Inparm,'xp')
        fprintf(FID5,'\r\npos (m):       ');
        fprintf(FID5,'%10.2f',Inparm.xp);
    end    
    if isfield(Inparm,'sc')
        fprintf(FID5,'\r\nscale to m:    ');
        fprintf(FID5,'%10.4f',Inparm.sc);
    end    
    if isfield(Inparm,'hm')
        fprintf(FID5,'\r\n\r\naverage waterdepth (m):   %10.4f',Inparm.hm);
    end
    if isfield(Inparm,'hxp')
        fprintf(FID5,'\r\nwaterdepth (m):');
        fprintf(FID5,'%10.2f',Inparm.hxp);
    end

    if isfield(Inparm,'x')
        fprintf(FID5,'\r\n\r\nDepth profile:\r\n');
        fprintf(FID5,'\r\nx_pos (m):      ');
        fprintf(FID5,'%10.2f',Inparm.x);
    end
    if isfield(Inparm,'h')
        fprintf(FID5,'\r\nwaterdepth (m): ');
        fprintf(FID5,'%10.2f',Inparm.h);
    end

    % functie-afhankelijke uitvoer:
    fprintf(FID5,'\r\n*********************************************\r\n\r\n');
    
    switch scr_num
    case 1
        % Asc2wav
    case 2    
        % Bekijkb
    case 3
        % Lvmview
    case 4
        % Pwspect
        SFN_outparmPw(FID5,Inparm,Outparm);
    case 5
        % Refreg
        SFN_outparmR(FID5,Inparm,Outparm,error);
    case 6
        % Spect
    case 7
        % Decomp
        SFN_outparmD(FID5,Inparm,Outparm);
    otherwise
        % do nothing
    end % switch scr_num
    
    fclose(FID5);
    open(uitfile);

end % uitvoerbestand gevraagd    

% einde FN_outparm

function SFN_outparmPw(FID5,Inparm,Outparm);
% uitvoer Pwspect, 8-12-04

fprintf(FID5,'*****************Method********************\r\n');
fprintf(FID5,'Spectra calculated as sum over frequency bands\r\n\r\n');
fprintf(FID5,'Frequency step used: ');
fprintf(FID5,'                    %12.6f Hz\r\n', Outparm.df);
fprintf(FID5,'Frequency resolution in average spectrum\r\n');
fprintf(FID5,'                     ');
fprintf(FID5,'                    %9.3f Hz\r\n', Outparm.fres);
 
fprintf(FID5,'\r\n\r\n*********Values calculated fom time signal********\r\n');
fprintf(FID5,'\r\nmoments of time signal and of var. density spectrum at wave gauges:\r\n');
teksth  = sprintf('   ch%d     ',Inparm.col);
fprintf(FID5,'                                       %s\r\n',teksth);
tekst   = sprintf('%10.4f  ',Outparm.M1); 
fprintf(FID5,'mean (m):                              %s\r\n',tekst);
tekst   = sprintf('%10.4e  ',Outparm.var); 
fprintf(FID5,'var (m^2):                             %s\r\n',tekst);
tekst   = sprintf('%10.5f  ',Outparm.Hm0t); 
fprintf(FID5,'Hm0 (m)                                %s\r\n',tekst);

% einde SFN_outparmPw

function SFN_outparmR(FID5,Inparm,Outparm,error);
% uitvoer Refreg, 8-12-04

if error==101;
    fprintf(FID5,'\r\n********************************************************\r\n');
  	fprintf(FID5,'* Warning:                                             *\r\n');
    fprintf(FID5,'*  If the number of samples per period is less than 20 *\r\n');
    fprintf(FID5,'*  the phase may be inaccurate                         *\r\n');
    fprintf(FID5,'********************************************************\r\n');
end    

% afdruk harmonischen:
fn  = Outparm.fn;
Fan = Outparm.Fan;
N   = Outparm.N;

[nharm,nchana] = size(Fan);
fprintf(FID5,'\r\nResults of SFN_harm9:\r\n');
fprintf(FID5,'\r\nnumber of samples: %d\r\n', N);
if nharm<Inparm.nharm
        fprintf(FID5,'\r\n**************************************\r\n');
    	fprintf(FID5,'* Warning:                           *\r\n');
        fprintf(FID5,'*  Only %d harmonic components found *\r\n',nharm);
        fprintf(FID5,'**************************************\r\n');
end    
amp = abs(Fan);
a   = real(Fan);
b   =-imag(Fan);	% algemeen voor FT: c(i) = a(i) - i*b(i)		
phi = angle(Fan);	
for i=1:2
    fprintf(FID5,'\r\nposition %d\r\n',i);
    fprintf(FID5,'  i         f            a            b            c            phi\r\n');
    for j=1:nharm
        fprintf(FID5,'%4.0f %12.6f %12.6f %12.6f %12.6f %12.6f\r\n',...
          j,fn(j,i),a(j,i),b(j,i),amp(j,i),phi(j,i));
    end
end    

fprintf(FID5,'\r\nreflection coefficient calculated with velocity 0:\r\n');
dx = Inparm.xp(2)-Inparm.xp(1);
fprintf(FID5,'distance of wave gauges      : %9.3f m\r\n', dx);
for i=1:2
    fprintf(FID5,'\r\nposition %d\r\n',i);
    fprintf(FID5,'\r\nPosition                 :  %9.3f m\r\n', Inparm.xp(i));
    fprintf(FID5,'period of 1st harmonic       : %10.4f s\r\n', Outparm.T);
    fprintf(FID5,'wave length                  : %10.4f m\r\n', Outparm.L);
    fprintf(FID5,'A-component of harmonic      : %10.4f\r\n', Outparm.a(1,i));
	fprintf(FID5,'B-component of harmonic      : %10.4f\r\n', Outparm.b(1,i));
    fprintf(FID5,'amplitude of harmonic        : %10.4f m\r\n', Outparm.c(1,i));
end   

fprintf(FID5,'\r\namplitude of incoming wave   : %10.4f m\r\n', Outparm.ai);
fprintf(FID5,'amplitude of reflected wave  : %10.4f m\r\n', Outparm.ar);
fprintf(FID5,'reflection coefficient       : %10.4f\r\n', Outparm.fr);
fprintf(FID5,'\r\nphase of incoming wave       : %8.2f deg\r\n', Outparm.phi_i);
fprintf(FID5,'phase of reflected wave      : %8.2f deg\r\n', Outparm.phi_r);
fprintf(FID5,'\r\ndeterminant                 : %10.4f\r\n', Outparm.det);
fprintf(FID5,'\r\nPhases have been calculated with respect to a position ');
fprintf(FID5,'halfway the two wave gauges;');
fprintf(FID5,'\r\nt=0 at the first sample of the measurements');
if Outparm.det < 1
    afst = Outparm.L/4;
    tekst1 = sprintf('Warning: det<1\n'); 
    tekst2 = sprintf('distance of wave gauges recommended: %6.2g m',afst);
    tekst    = [tekst1 tekst2];
    h        = msgbox(tekst);
    uiwait(h);
    fprintf(FID5,'\r\n************************************************\r\n');
    fprintf(FID5,'* Warning: det<1                                   \r\n'); 
    fprintf(FID5,'* distance of wave gauges recommended: %6.2g m        \r\n',afst);
    fprintf(FID5,'*************************************************\r\n');
end
fprintf(FID5,'\r\n\r\n************************************************\r\n');
    fprintf(FID5,'* Warning:                                        \r\n'); 
    fprintf(FID5,'* if a trend is found in the measurements,      \r\n');
    fprintf(FID5,'* the wave number k will change with the time,  \r\n');
    fprintf(FID5,'* and the equations used in this program are no \r\n');
    fprintf(FID5,'* no longer valid.                              \r\n');
    fprintf(FID5,'*************************************************\r\n');


% einde SFN_outparmR

function SFN_outparmD(FID5, Inparm, Outparm)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_outparmD
%   Uitvoer Decomp v. 15
%   31-Mar-05

fprintf(FID5,'Program Decomp15, calculation of reflection\r\n');
%    fprintf(FID5,...
%        'test: default freq-bereik bij 3 ghm''s\r\n\r\n');
%    fprintf(FID5,' spectrale parameters\r\n\r\n');
 
fprintf(FID5,'*****************Method********************\r\n');
fprintf(FID5,'Spectra calculated as sum over frequency bands\r\n');
fprintf(FID5,'Kr from Er/Ei; m0i and m0r from Ei en Er;\r\n');
fprintf(FID5,'Hm0i and Hm0r from m0i en m0r\r\n\r\n');

fprintf(FID5,'Frequency step:     %11.5f Hz\r\n', Outparm.df);
%   fprintf(FID5,'Filter length:           %6d\r\n', Outparm.nf);
fprintf(FID5,'Threshold used to calculate TpD and spectral moments\r\n');
fprintf(FID5,'                     %10.4f x max(E)\r\n', Inparm.thresh);  
fprintf(FID5,'Frequency resolution in average spectrum\r\n');
fprintf(FID5,'                      %9.3f Hz\r\n', Outparm.fres);
if Inparm.f_max<0
    if length(Inparm.xp)<3
        fprintf(FID5,'Frequency range calculated according to distances:\r\n');
        fprintf(FID5,'                      %9.3f, %9.3f Hz\r\n', ...
            Outparm.f_min, Outparm.f_max);
    else
        fprintf(FID5,'Default frequency range defined by FN_freqs:\r\n');
        fprintf(FID5,'                      %9.3f, %9.3f Hz\r\n', ...
            Outparm.f_min, Outparm.f_max);
    end
else
    fprintf(FID5,'Frequency range asked by user:\r\n');
    fprintf(FID5,'                      %9.3f, %9.3f Hz\r\n', ...
        Outparm.f_min, Outparm.f_max);
end
    
fprintf(FID5,...
    'Frequency range according to threshold in spectrum of data file:\r\n');
fprintf(FID5,'                      %9.3f, %9.3f Hz\r\n', ...
    Outparm.fmin_s, Outparm.fmax_s);

Tpm = mean(Outparm.Tpm);
fprintf(FID5,'Frequency range of ideal Jonswap spectrum of Tp = %6.2f s',...
    Tpm(2));
fprintf(FID5,'\r\n  and thresh %10.4f x max(E):\r\n', Inparm.thresh);  
fprintf(FID5,'                      %9.3f, %9.3f Hz\r\n',...
    Outparm.fmin_js,Outparm.fmax_js);

% added, 31-Mar-05:
if Outparm.fmin_js<0.95*Outparm.f_min | Outparm.fmax_js>1.05*Outparm.f_max
fprintf(FID5,'\r\n\r\n!!!!!!!!!!!!!!!!!!! WARNING !!!!!!!!!!!!!!!!!!!!!!\r\n');
fprintf(FID5,'* Jonswap spectrum not covered by user specified freq-range\r\n');
fprintf(FID5,'!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\r\n');
end
if Outparm.fmin_js<0.95*Outparm.fmin_s | Outparm.fmax_js>1.05*Outparm.fmax_s
fprintf(FID5,'\r\n\r\n!!!!!!!!!!!!!!!!!!! WARNING !!!!!!!!!!!!!!!!!!!!!!\r\n');
fprintf(FID5,'* Freq-range of Jonswap spectrum according to threshold not covered\r\n');
fprintf(FID5,'* by freq-range in spectrum of measurements with same threshold\r\n');
fprintf(FID5,'!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\r\n');
end

fprintf(FID5,...
    '\r\n\r\n*********Values calculated fom time signal********\r\n');
fprintf(FID5,'\r\nmoments of time signal and of var. density spectrum ');
fprintf(FID5,'at wave gauges:\r\n');
teksth  = sprintf('   ch%d     ',Inparm.col);
fprintf(FID5,'                                       %s\r\n',teksth);
tekst   = sprintf('%10.4f  ',Outparm.M1); 
fprintf(FID5,'mean (m):                              %s\r\n',tekst);
tekst   = sprintf('%10.4e  ',Outparm.var); 
fprintf(FID5,'var (m^2):                             %s\r\n',tekst);
tekst   = sprintf('%10.5f  ',Outparm.Hm0t); 
fprintf(FID5,'Hm0 (m)                                %s\r\n',tekst);

% Momenten uit spectra en afgeleide parameters:
m       = Outparm.m;

fprintf(FID5,...
    '\r\n\r\n*********Values calculated fom spectra*********\r\n');
fprintf(FID5,'\r\n----moments from spectra in region '); 
fprintf(FID5,'where equations are valid\r\n');
%    fprintf(FID5,'with respect to  distances of gauges used\r\n');

fprintf(FID5,'density >= %6.4f x max(E) ---\r\n',Inparm.thresh);
fprintf(FID5,'\r\nfrequency range used in calculation of moments of ');
fprintf(FID5,'\r\nindividual wave gauges:      %8.4f - %8.4f Hz\r\n', ...
        Outparm.fmin_r, Outparm.fmax_r);
%    fprintf(FID5,'\r\n-------moments from averaged spectra-----------\r\n');
%    fprintf(FID5,'----in region where density >= %10.4f x sum(E)/N---\r\n',Inparm.thresh);
teksth  = sprintf('   ch%d     ',Inparm.col);
fprintf(FID5,'                                       %s\r\n',teksth);
tekst   = sprintf('%10.4e  ',Outparm.m(1,:)); 
fprintf(FID5,'m0 (m^2)                               %s\r\n',tekst);
tekst   = sprintf('%10.4e  ',Outparm.m(3,:)); 
fprintf(FID5,'m2 (m^2/s^2)                           %s\r\n',tekst);
tekst   = sprintf('%10.4e  ',Outparm.m(4,:)); 
fprintf(FID5,'m4 (m^2/s^4)                           %s\r\n',tekst);
%    fprintf(FID5,' \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n');
%    fprintf(FID5,'\r\n-------Peak Information from spectra-----------\r\n');
%    SFN_piek(FID5,Inparm.col,Outparm.df,Outparm.fp,Outparm.Tp,Outparm.Ep);
fprintf(FID5,'\r\n--- Peak Information from averaged spectra ---\r\n');
SFN_piek(FID5,Inparm.col,Outparm.fres,Outparm.fpm,Outparm.Tpm,Outparm.Epm);

fprintf(FID5,'\r\n-----------derivated PERIOD values------------\r\n');
%   fprintf(FID5,'\r\n----derivated PERIOD values from averaged spectra----\r\n');
teksth  = sprintf('   ch%d     ',Inparm.col);
tekst   = sprintf('%10.4f  ',Outparm.T0(1,:)); 
fprintf(FID5,'Average zerocrossing period T0,1 (s)   %s\r\n',tekst);
tekst   = sprintf('%10.4f  ',Outparm.T0(2,:)); 
fprintf(FID5,'                            T0,2 (s)   %s\r\n',tekst);
tekst   = sprintf('%10.4f  ',Outparm.T0(3,:)); 
fprintf(FID5,'Average period local maxima T2,4 (s)   %s\r\n',tekst);
tekst   = sprintf('%10.4f  ',Outparm.eps(1,:)); 
fprintf(FID5,'Narrowness Parameter Eps2              %s\r\n',tekst);
tekst   = sprintf('%10.4f  ',Outparm.eps(2,:)); 
fprintf(FID5,'Broadness Factor Eps4                  %s\r\n',tekst);
%    fprintf(FID5,'Gamma en kappa nog niet gevonden\r\n');
tekst   = sprintf('%10.4f  ',Outparm.kappa); 
fprintf(FID5,'kappa                                  %s\r\n',tekst);
tekst   = sprintf('%10.4f  ',Outparm.gamma); 
fprintf(FID5,'gamma                                  %s\r\n',tekst);
tekst   = sprintf('%10.5f  ',Outparm.Hm0); 
fprintf(FID5,'Hm0                                    %s\r\n',tekst);

fprintf(FID5,'\r\n\r\n*********Calculation of reflection*********\r\n');
fprintf(FID5,'\r\nfrequency range used in calculation of reflection:');
fprintf(FID5,'\r\n                      %8.4f - %8.4f Hz\r\n', ...
    Outparm.fmin_t, Outparm.fmax_t);
%   fprintf(FID5,'\r\nPercentage of total energy:\r\n')
%    fprintf(FID5,'  in calculated spectrum part per wave gauge:\r\n');
%   teksth  = sprintf(' ch%d     ',Inparm.col);
%   fprintf(FID5,'       %s\r\n',teksth);
%   tekst   = sprintf('%10.4e  ',Outparm.E); 
%   fprintf(FID5,'E   %s\r\n',tekst);

 %   fprintf(FID5,'\r\n-------Peak Information from spectra-----------\r\n');
 %   cols = 0;
 %   SFN_piek(FID5,cols,Outparm.df,Outparm.fpi,Outparm.Tpi,Outparm.Epi);

cols = 0;
fprintf(FID5,'\r\n--- Peak Information from averaged spectra ---\r\n');
SFN_piek(FID5,cols,Outparm.fres,Outparm.fpim,Outparm.Tpim,...
    Outparm.Epim);
     
fprintf(FID5,'\r\n\r\nSum of variance densities:\r\n');
fprintf(FID5,'  over spectrum part used in graphs ');
fprintf(FID5,'(10%% more than used in calc. of moments)\r\n');
fprintf(FID5,'Incident (m^2):  %8.4e\r\n',Outparm.sumi);
fprintf(FID5,'Reflected (m^2): %8.4e\r\n',Outparm.sumr);
%   fprintf(FID5,'  in calculated filtered spectrum part          %8.4f %%\r\n',Outparm.Es_tot);
% fprintf(FID5,'  in spectrum part used to calculate reflection %8.4f %%\r\n',perc(3));

fprintf(FID5,'\r\n\r\nMoments of incident and reflected wave\r\n');
%    fprintf(FID5,'mean of Hm0 :          %8.4f m\r\n',Outparm.Hm0m);
fprintf(FID5,'\r\nm0 of incident wave:   %8.4e m^2\r\n',Outparm.m0i);
fprintf(FID5,'m0 of reflected wave:  %8.4e m^2\r\n',Outparm.m0r);
fprintf(FID5,'Hm0 of incident wave:  %8.5f m\r\n',Outparm.Hm0i);
fprintf(FID5,'Hm0 of reflected wave: %8.5f m\r\n',Outparm.Hm0r);
fprintf(FID5,'\r\nReflection coefficient: %8.4f',Outparm.Kr);

% einde FN_outD6

function SFN_piek(FID5,cols,df,fp,Tp,Ep);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% subfunctie afdruk piekperiode
% 9-10-03
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ng      = length(cols);
een     = ones(1,ng);

if ng>1
    teksth  = sprintf('   ch%d     ',cols);
    fprintf(FID5,'                                       %s\r\n',teksth);
    tekst   = sprintf('%10.4f ',fp(2,:)); 
    fprintf(FID5,'   threshold 80%% fpD (Hz):            %s\r\n',tekst);
    tekst   = sprintf('%10.4f ',Tp(2,:)); 
    fprintf(FID5,'   threshold 80%% TpD (s):             %s\r\n',tekst);
    fpmin   = fp(1,:) - df/2 * een;
    fpmax   = fp(1,:) + df/2 * een;
else
    tekst   = sprintf('%10.4f ',fp(2)); 
    fprintf(FID5,'   threshold 80%% fpD (Hz):            %s\r\n',tekst);
    tekst   = sprintf('%10.4f ',Tp(2)); 
    fprintf(FID5,'   threshold 80%% TpD (s):             %s\r\n',tekst);
    fpmin   = fp(1) - df/2;
    fpmax   = fp(1) + df/2;
end    
    
Tpmin   = 1 ./ fpmax;
Tpmax   = 1 ./ fpmin;
% percentages geven geen extra informatie: hangen ook samen met df.
% Eperc   = 100*df*Ep ./ m(1,:);
tekst   = sprintf('%10.4e ',Ep); 
fprintf(FID5,'\r\nMax spectral density (m^2/Hz):         %s\r\n',tekst);
fprintf(FID5,'within frequency range\r\n');
tekst   = sprintf('%10.4f ',fpmin);
fprintf(FID5,'                   fpmin (Hz):         %s\r\n',tekst);
tekst   = sprintf('%10.4f ',fpmax);
fprintf(FID5,'                   fpmax (Hz):         %s\r\n',tekst);
fprintf(FID5,'within periods\r\n');
tekst   = sprintf('%10.4f ',Tpmin);
fprintf(FID5,'                    Tpmin (s):         %s\r\n',tekst);
tekst   = sprintf('%10.4f ',Tpmax);
fprintf(FID5,'                    Tpmax (s):         %s\r\n',tekst);

%    fprintf(FID5,'Frequency band with maximum spectral energy:\r\n\r\n');
%    fprintf(FID5,...
%       ' chan    fpmin      fpmax     Tpmin        Tpmax  energy in %% of total\r\n');
%    fprintf(FID5,'          (Hz)       (Hz)       (s)          (s)       %%\r\n');
%    for i=1:ng
%        fprintf(FID5,'%4d %10.4f %10.4f %10.4f %10.4f %10.4f\r\n', ...
%            Inparm.col(i), fpmin(i), fpmax(i), Tpmin(i), Tpmax(i), Eperc(i));
%    end    

% einde SFN_piek
