function [Scanparm,Ts,A1,error] = FN_selectnw2(A,Fileinfo,Inparm,show)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_selectnw2
%   Select desired part from a matrix containig time registrations
%   version 2: time are asked instead of sample numbers
%   31-Jan-05, adaption Matlab 6.5, Hkl, 28-Feb-05
%
%
%
%
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% versie 1: vraagt monsternummers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   A:          te reduceren matrix
%   Fileinfo:   structure met bestandsgegevens
%	    nhead:	voor niet dasylabbestanden: aantal headerregels
%   			wordt bij dasylabbestanden genegeerd.
%	    nsamp1:	eerste in te lezen punt
%	    nsamp2:	laatste in te lezen punt, -1 tot einde file
%	    step:	stapgrootte
%
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in meetdata (niet: in bemonsterde data)
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       nh:     aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%
%   show:       figuur handmatig sluiten: 1: ja, 0: nee
%               op dit moment wordt overal 1 gebruikt, Hkl, 25-1-05
%
% uitvoer:
%   Scanparm:   structure gegevens over met gekozen samples:
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%   Ts:       kolomvector met tijden; wordt gehaald uit tijden in bestand of
%               uit (samplenummer-1)*tijdstap in bestand
%   A1:         het gekozen deel van A
%	error:	    0: doorgaan, 101: stoppen, 
%               303: geen samples gekozen, tijdstippen buiten bereik
%
% Opmerking:	
% Het is niet handig om eerst monsternummers op te vragen en vervolgens % tijden. Bij inlezen is het veiliger uit te gaan van de monster-
% nummers, omdat de monsterstap altijd integer is, in tegenstelling tot % de tijdstap. Bovendien moeten ook gegevens zonder tijd, b.v. % cordinaten worden ingelezen.
% Omdat het zelden voorkomt dat niet alle data worden ingelezen blijft % deze opzet voorlopig gehandhaafd.
% Bij opgaaf van de te verwerken gegevens is de tijd juist wel handig, % omdat die worden gekozen uit een grafiek. Het is handig als langs de % horizontale as detzelfde eenheid staat als in de resultaten. Op die % manier kan gemakkelijk een nieuw tijdgebied worden gekozen. De te % nemen stap bij de verwerking wordt nog wel als integer opgegeven.
% Als de tijd niet van toepassing is (alleen plaatsgegevens) kan i.p.v. 
% FN_selectnw1 de functie FN_selectnw worden gebruikt. Daarin worden % monsternummers gevraagd i.p.v. de tijd.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Geef parameters een beginwaarde:
start   = 0;
error   = 0;

Scanparm.tin1   = -1;
Scanparm.tin2   = -1;
Scanparm.step   = 1;
Scanparm.dt     = Inparm.dt;

A1      = A;
f_samp1 = Fileinfo.samp1;
f_samp2 = Fileinfo.samp2;
f_step  = Fileinfo.step;

[f_nsamp,f_nchan]   = size(A);
ncols     = length(Inparm.col);
if f_samp2<0
    f_samp2 = f_samp1 + f_step*(f_nsamp-1);
end

% maak tijdvector en samplegebied:
Num = f_samp1:f_step:f_samp2;
Num = Num';
e       = ones(length(Num),1);
if Inparm.colt==0
    Ts   = Inparm.dt.* (Num-e);
else
    Ts       = A1(:,1);
    A1(:,1) = [];
end    

% te selecteren kolommen uit A, inclusief de tijd:
% hoeft niet meer: Ts is er al uit, Hkl, 24-11-04
% if Inparm.colt==0
%    Cols = Inparm.col;
% else    
%     Cols = [Inparm.colt Inparm.col];
% end    
Cols = Inparm.col;

% plot de data:
h1  = figure(1);    % verplaatst op 23-12-03
subplot(2,1,1);
tekst = sprintf('channel %d',Inparm.col(1));
plot(Ts,A(:,Inparm.col(1)));
title(tekst);
if ncols>1
    subplot(2,1,2);
    tekst = sprintf('channel %d',Inparm.col(ncols));
    plot(Ts,A(:,Inparm.col(ncols)));
    title(tekst);
    xlabel('time (s)');
end    

% kies samplegebied:
Def = {num2str(Scanparm.tin1),num2str(Scanparm.tin2),num2str(f_step)};

%% Lees actuele parameterwaarden:
FID=fopen('.\Tmp\select.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      lijn=fgetl(FID);
      Def{i}=char(lijn);
      i = i+1;
	end
	fclose(FID);
end   

if f_step==1
    tekst = 'stepsize in samples (integer value)';
else
    tekst = 'extra stepsize with respect to already sampled data (integer value)';
end    
Prompt = {'time at first data sample to be analysed (-1 for first sample)', ... 
            'time at last data sample to be analysed (-1 for last sample)', tekst};
Title = 'Select time series to be analysed';

% te gebuiken instellingen voor dialoogschermen;
V = version;
v1=str2num(V(1:1));
if v1<6.9
% versie 6.5 (evt. 6?):
    Options = 'on'; % alternatief, werkt goed in Matlab 6.5 (Rel.13)
else    
% versie 7: WindowStyle op normal om dialoogscherm klein te kunnen
%           maken en Help te vragen
    Options.WindowStyle='normal';  
    Options.Resizable='on';
end    
Scanparms1 = inputdlg(Prompt,Title,1,Def,Options);


%doorgaan:
if length(Scanparms1)>0
	start   =1;
   	ts1     = str2num(Scanparms1{1});
    ts2     = str2num(Scanparms1{2});
    s_step  = str2num(Scanparms1{3});
    
    % zoek indices in Ts:
    i=1;
    maxsamp = length(Ts);
    if ts1>0
        while Ts(i)<ts1 & i<maxsamp
            i=i+1;
        end
        s_samp1 = i;
    else
        s_samp1 = 1;
    end    
    if ts2>0
       i=1;
       tmax = ts2 - 0.99*Fileinfo.step*Inparm.dt;
       while Ts(i)<=tmax & i<maxsamp
            i=i+1;
       end     
       s_samp2 = i;     
    else
        s_samp2 = maxsamp;
    end

    %% schrijf nieuwe waarden in hulpbestand: 
    FID=fopen('.\Tmp\select.txt','w');
    fprintf(FID,'%g\r\n',ts1);
    fprintf(FID,'%g\r\n',ts2);
    fprintf(FID,'%g\r\n',s_step);
    fclose(FID);
    
    if s_samp1<s_samp2
        % maak nieuwe matrix met geselecteerde rijen en kolommen van A,
        % en van de tijd Ts
        % monsternummers te kiezen uit matrix A:
        Samps       = [s_samp1 s_samp2 s_step];   % f_step al genomen in A
        A1          = FN_red(A,Samps,Cols);
        ColsTs(1)    = 1;
        Ts1          = FN_red(Ts,Samps,ColsTs);
        clear Ts;
        Ts = Ts1;
        
        % nieuwe scanparameters:
        Scanparm.tin1     = ts1;
        Scanparm.tin2     = ts2;
        Scanparm.step   = s_step;
        Scanparm.dt     = s_step*f_step*Inparm.dt;
  
        [s_nsamp,s_nchan] = size(A1);
        
        % laat resultaat zien:
        %if show==1
            figure(1);     % toegevoegd, 23-12-03
            subplot(2,1,1);
            tekst = sprintf('channel %d',Inparm.col(1));
            plot(Ts,A1(:,1));
            title(tekst);
            if ncols>1
                subplot(2,1,2);
                tekst = sprintf('channel %d',Inparm.col(ncols));
                plot(Ts,A1(:,s_nchan));
                title(tekst);
                xlabel('time (s)');
            end    
        %end
        if show==1
            uiwait(h1);
            % close(h1); % werkt niet
            % delete(h1);   % werkt niet
            % moet buiten lus: fig.1 bestond al, hkl, 30-11-04
        end
    
    % geen monsternummers binnen gevraagd tijdinterval:
    else
        error=304;
    end    

% gebruiker heeft bij vraag samples op Cancel gedrukt:
else
   		error=101;
end

% zet uiteindelijk gekozen tijden in Scanparm (Ts heeft altijd een waarde):
Scanparm.tuit1 = Ts(1);
Scanparm.tuit2 = Ts(length(Ts));

% Einde FN_selectnw2