function varargout = Refreg19(varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Refreg19
%	Calculate reflection of regular wave at velocity 0, 
%   input via GUI
%   usage: Refreg19
%
%   version 19: moving average substracted, changes in k neglected
%   5-Apr-05
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   version 19: moving average substracted
% Note: if the waterdepth has a trend, the wave number k is a
%   function of t, so the equations used to caculate the reflection
%   must be changed. In this version, changes in k are neglected;
%   check the change in k caused by the change in waterdepth before
%   using the results.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% REFREG19 Application M-file for REFREG19.fig
%    FIG = REFREG18 launch Refreg15 GUI.
%    Refreg('callback_name', ...) invoke the named callback.

% Last Modified by GUIDE v2.0 17-Jun-2002 16:29:25

%   version 19: moving average substracted
%   version 18: some functions replaced by new (general) functions
% versie 17: nuldoorgangen aangepast, nummers in plot aangepast,
%           controle op beschikbare harmonischen.
% versie 16: pad onthouden
% versie 15: vanuit Guide om te zorgen dat de schermpjes
% worden afgemaakt

% Lvmview generates a menu to open an ASCII file of 
% measurements or a .fig-file. 
% In case of an ASCII file, the program askes for the type
% of plot (1 or more chanels per graph), the sample  
% numbers and the chanels to be plotted. One ore more
% figures will be opened, which can be printed or stored
% to disk as a .fig-file. The plot parameters can be changed
% by minimising or closing the figure, and click on Samples
% in the pull down menu Plot. The new figures overwrite
% the old ones.
% If a .fig-file is opened, the figure will be displayed
% and can be printed.
% If no file is opened, the workspace is inspected for
% data of an earlier call of Lvmview10.
% Last version: 2-12-04

addpath('.\Functions');
%addpath('E:\Hetty\Matlab\Lab_process\Functions');

if nargin == 0  % LAUNCH GUI

	fig = openfig(mfilename,'reuse');
	% Generate a structure of handles to pass to callbacks, and store it. 
	handles = guihandles(fig);
	guidata(fig, handles);
    
	if nargout > 0
		varargout{1} = fig;
	end
    
elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

	try
		if (nargout)
			[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
		else
			feval(varargin{:}); % FEVAL switchyard
		end
	catch
		disp(lasterr);
	end

end


%| ABOUT CALLBACKS:
%| GUIDE automatically appends subfunction prototypes to this file, and 
%| sets objects' callback properties to call them through the FEVAL 
%| switchyard above. This comment describes that mechanism.
%|
%| Each callback subfunction declaration has the following form:
%| <SUBFUNCTION_NAME>(H, EVENTDATA, HANDLES, VARARGIN)
%|
%| The subfunction name is composed using the object's Tag and the 
%| callback type separated by '_', e.g. 'slider2_Callback',
%| 'figure1_CloseRequestFcn', 'axis1_ButtondownFcn'.
%|
%| H is the callback object's handle (obtained using GCBO).
%|
%| EVENTDATA is empty, but reserved for future use.
%|
%| HANDLES is a structure containing handles of components in GUI using
%| tags as fieldnames, e.g. handles.figure1, handles.slider2. This
%| structure is created at GUI startup using GUIHANDLES and stored in
%| the figure's application data using GUIDATA. A copy of the structure
%| is passed to each callback.  You can store additional information in
%| this structure at GUI startup, and you can change the structure
%| during callbacks.  Call guidata(h, handles) after changing your
%| copy to replace the stored original so that subsequent callbacks see
%| the updates. Type "help guihandles" and "help guidata" for more
%| information.
%|
%| VARARGIN contains any extra arguments you have passed to the
%| callback. Specify the extra arguments by editing the callback
%| property in the inspector. By default, GUIDE sets the property to:
%| <MFILENAME>('<SUBFUNCTION_NAME>', gcbo, [], guidata(gcbo))
%| Add any extra arguments after the last argument, before the final
%| closing parenthesis.



% --------------------------------------------------------------------
function varargout = File_1_Callback(h, eventdata, handles, varargin)

%filemenufcn(gcf,'Fpost');  % werkt niet



% --------------------------------------------------------------------
function varargout = Open_1_Callback(h, eventdata, handles, varargin)
% Callback File, Open       3-6-02

% --------------------------------------------------------------------
function varargout = Exit_1_Callback(h, eventdata, handles, varargin)
% Callback File, Close      28-5-02

close;


% --------------------------------------------------------------------
function varargout = datafile_1_Callback(h, eventdata, handles, varargin)
% Callback File, Datafile   5-Apr-05

err1 = 0;
%[in_naam, Fileinfo, head, A, start] = FN_infiles5(first);
first = 1;  % wordt gebruikt in FN_zoekdata, i.v.m. Lvmview
[in_naam, pad_naam, Fileinfo, A, type, err1] = FN_infile8;
if err1==0
    % voeg gegevens toe aan handle
    handles.in_naam     = in_naam;
    handles.Fileinfo    = Fileinfo;
    handles.A           = A;
    handles.type        = type;
    handles.first       = first;
    guidata(h,handles);
    % zet ingelezen gegevens in de workspace:
    assignin('base','A',A);
    assignin('base','Fileinfo',Fileinfo);
    assignin('base','in_naam',in_naam);
    assignin('base','type',type);

    if in_naam~=0 & type==1
        % input parameters of Refreg: (changed: 2-12-04)
        scr_num = 5;
        [nsamp,nchan] = size(A);        
        [Inparm,err1] = FN_inparm2(scr_num,nchan);
        handles.Inparm  = Inparm;
        guidata(h,handles);
         
        % om het prosec achteraf te kunnen controleren worden zoveel
        % mogelijk gegevens in de workspace geplaatst;
        % zet deze regels uit om het proces te versnellen
        assignin('base','Inparm',Inparm);
 
        if err1==0
            % ask range of data to be processed (an integer number of
            % periods will be selected in the "calculate" part)
            show = 1;
            [Scanparm,Ts,A1,err1] = FN_selectnw2(A,Fileinfo,Inparm,show);
            handles.Ts       = Ts;
            handles.A1      = A1;
            guidata(h,handles);
                
            % workspace; evt. uitzetten
            assignin('base','Scanparm',Scanparm);
            assignin('base','Ts',Ts);
            assignin('base','A1',A1);

            if err1==0
                % calculate:
                % FN_refreg6 replaced by FN_refreg7 (new functions of read 
                % parameters and select samples), Hkl, 2-12-04
                [Outparm, err1] = ...
                    FN_refreg8(in_naam, Inparm, Scanparm, Ts, A1);
                handles.Outparm = Outparm;
                guidata(h,handles);
                % put parameters in workspace
                if err1<200
                    assignin('base','Outparm',Outparm);
                    % put results in output file (replaced by FN_outparm,
                    % 9-12-04)
                    FN_outparmr19(scr_num,in_naam,Inparm,Scanparm,Outparm,err1);

     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     %               uitfile = ...
     %           FN_uit13(in_naam,Inparm,Scanparm,Fan,fn,nanal,Refparm,err1);
     %               if uitfile~=0
     %                   open(uitfile);
     %               end
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                   
                end   % test calculation 
            end    % test select data
        end    % test reading input parameters
    end % test file type
end   % test open inputfile

% foutafhandeling:
FN_error(err1);


% --------------------------------------------------------------------
function varargout = results_1_Callback(h, eventdata, handles, varargin)
% Call-back open resultsfile, 9-12-04
FN_openuitfile;
type = 3;
handles.type = 3;
guidata(h,handles);
assignin('base','type',type);



% --------------------------------------------------------------------
function varargout = Calc_1_Callback(h, eventdata, handles, varargin)
% Call-back Refreg, calculate, 5-Apr-05

err1 = 0;

% haal gegevens binnen:
callnum=2;
[Ts,A1,Inparm,Scanparm,in_naam,err1] = ...
    SFN_zoekdatar(h,eventdata,handles,callnum);

handles.Ts      = Ts;
handles.A1      = A1;
handles.Inparm  = Inparm;
handles.in_naam = in_naam;
guidata(h,handles);
% zet binnengehaalde gegevens in de workspace:

% gebruiker wil doorgaan:
if err1==0
    % calculate:
    [Outparm, err1] = FN_refreg8(in_naam, Inparm, Scanparm, Ts, A1);
    % zet ingelezen gegevens in de workspace:
    if err1==0
        assignin('base','Inparm',Inparm);
        assignin('base','Outparm',Outparm);

        % zet gegevens in uitvoerbestand:
        scr_num = 5;
        FN_outparmr19(scr_num,in_naam,Inparm,Scanparm,Outparm,err1);
    end    
end    

% foutafhandeling:
FN_error(err1);


% --------------------------------------------------------------------
function [Ts,A1,Inparm,Scanparm,in_naam,err1] = ...
    SFN_zoekdatar(h, eventdata, handles, callnum)
% Haal gegevens binnen, versie Refreg: 1-2-05
% callnum:
% 1: samplenummers gevraagd (FN_selectnw2)
% 2: kanalen gevraagd (FN_inparm2)
% 3: plot gevraagd (als gegevens er al zijn: geen select of inparm nodig)
%
err1 = 0;

% File-menu geopend:
if isfield(handles,'A')
    A           = handles.A;
    Fileinfo    = handles.Fileinfo;
    in_naam     = handles.in_naam;
    first       = handles.first;
    
    [nsamp,nchan] = size(A);
    if nsamp<0.5
        err1 = 302;    % geen data gevonden
    end
% workspace
else
    % probeer of al data zijn ingelezen:
    try
        A           = evalin('base','A');
        Fileinfo    = evalin('base','Fileinfo');
        in_naam     = evalin('base','in_naam');
        type        = evalin('base','type');
        first       = 1;
    catch
        c   = lasterr;
        % geen data ingelezen:
        if length(c)>0
        %    hc = msgbox(c);
        %    uiwait(hc);
            err1 = 301;
        % data ingelezen:
        else
            % inhoud workspace in handle
            handles.A       = A;
            handles.Fileinfo= Fileinfo;
            handles.in_naam = in_naam;
            handles.type    = type;
            first           = 0;
        end    
    end
       
end    

% er zijn data, en de naam van het bestand is bekend:
if err1==0
    if in_naam~=0

        % er zijn al invoerparameters:
        if isfield(handles,'Inparm') & callnum~=2
            Inparm = handles.Inparm;
        % nog geen invoerparameters:    
        else    
            scr_num = 5;
            [nsamp,nchan] = size(A);        
            [Inparm,err1] = FN_inparm2(scr_num,nchan);
            if err1==0
                handles.Inparm  = Inparm;
                guidata(h,handles);
            end    

            % workspace; evt. uitzetten
            assignin('base','Inparm',Inparm);
       end    

        % gebruiker wil doorgaan:
        if err1==0
            % er zijn al samples gekozen:
            if isfield(handles,'Ts') & callnum==3
                Ts   = handles.Ts;
                A1  = handles.A1;
            % nog geen samples gekozen:
            % dit moet ook bij callnum=2, kanalen kiezen, omdat A1 nog
            % de kanalen van de vorige keuze bevat.
            else
                show = 1;
                [Scanparm,Ts,A1,err1] = FN_selectnw2(A,Fileinfo,Inparm,show);
                handles.Ts       = Ts;
                handles.A1      = A1;
                guidata(h,handles);

                % workspace; evt. uitzetten
                assignin('base','Scanparm',Scanparm);
                assignin('base','Ts',Ts);
                assignin('base','A1',A1);
           end    
        else
            % maak een verstekwaarde voor A1 en Ts:
            A1 = A;
            [nsamp,nchan] = size(A1);
            Ts = (0:nsamp-1).*(Inparm.dt*Fileinfo.step);
            Ts = Ts';
            Scanparm.dt = Inparm.dt*Fileinfo.step;
        end    
    end    
        
% er is geen databestand ingelezen of de naam van het bestand is niet bekend:
else
        err1       = 301;
        Ts          = [];
        A1          = [];
        Inparm.dt   = 1;
        Scanparm.dt = 1;
        in_naam     = 0;
        first       = 0;
end 

% einde SFN_zoekdata
