function k = disper(w, h, g);

% DISPER   Linear dispersion relation
%                               (c) Albatros Flow Research, 1999
% usage:   k  = disper(w,h,g)     or
%
%          k  = wave number             (2 * pi / wave length)
%          w  = wave angular frequency  (2 * pi / wave period)
%          h  = water depth
%          g  = gravitational acceleration constant, optional (DEFAULT 9.81)
%
%          relative error in k*h < 2.5e-16 for all k*h
%

%          (c) Albatros Flow Research, 1999

if nargin < 3,
  g = 9.81;
end;

w2 = (w.^2) .* h ./ g;
Q0 = w2;
R1 = Q0 + 0.176*Q0.^2 + 0.0088*Q0.^3;
q  = Q0 ./ sqrt(1 - exp(-R1));
for m=1:1,
  Q1 = q;
  T1 = tanh(Q1);
  C1 = cosh(Q1);
  X  = Q1 .* T1 - Q0;
  Y  = T1 + Q1 ./ C1.^2;
  Z  = 2 * (1 - Q1.*T1) ./ C1.^2;
  F  = X .* Z ./ Y.^2;
  Q2 = Q1 - X ./ Y .* (1 - 1.1 * F) ./ (1 - 1.6 * F);
  q  = Q2;
end;

k = sign(w) .* q ./ h;

ik    = isnan (k);
k(ik) = zeros(size(k(ik)));

%
