function [f_min,f_max] = FN_freqs(xp,x,h)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_freqs
%   calculates minimum and maximum frequency between which reflection
%   can be detected with 2 wave gauges.
%   For all different numbers of gauges: default 0 - 2.5 Hz used.
%   version 2: 2 gauges, rest default
%   24-Dec-03
%
%
%												H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% versies 3 en 4, toevoeging 3 ghm's, vervallen; defaults aangepast
%   voor gebruik 3 ghm's, Hkl, 20-4-04
% invoer:
%   xp: vector met X-coord. golfhoogtemeters
%   x:  vector met x-coord
%   h:  vector met waterdieptes op de in x gegeven plaatsen
%
% Goda (1985), p. 302:
%   delta_l/Lmax = 0.05,  delta_l/Lmin = 0.45
%	dispersierelatie: w^2 = g*k tanh(k*h)
%   Voor h wordt de ge-interpoleerde waterdiepte tussen de
%   golfhoogtemeters gebruikt

% Verstekwaarden:
f_min = 0;
f_max = 2.5;

% 2 golfhoogtemeters: Goda en Suzuki (Goda, p. 302)
if length(xp)==2

    delta_l = xp(2) - xp(1);
    xm      = (x(1)+x(2))/2;
    hm      = interp1(x,h,xm);
    L(1)    = delta_l/0.45;
    L(2)    = delta_l/0.05;
    g       = 9.81;
    k       = 2*pi./L;
    gk      = g*k;
    wsq     = gk.*tanh(hm*k);
    f       = (wsq.^0.5)./(2*pi);
    f_min   = f(2);
    f_max   = f(1);
end    

% Einde FN_freqs