function[exist, A] = FN_indatb5(infile,nread,Inparm)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_indatb5
%   read data fom binary file with integer 16 numbers.
%   version 5: adapted to general setup (selection after
%       read instead of before)
%   23-Nov-04
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 4: waarde elektromechanisch golfschot gecorrigeerd
%       (=[-20000,+2000])
%   versie 3: aangepast voor elektromechanisch golfschot
%   versie 2: met offset en keuze V of m
% In de praktijk is de conversiefactor vaak het bereik
% van de te berekenen waarde gedeeld door het waardebereik
% Bij het hydraulisch golfschot: [-32767,+32768] -> [-10V,+10V]
%   of [-0.3 m,+0.3 m]
% Elektronisch golfschot: [-20000,+20000] -> [-1 m,+1 m]
% Algemene vergelijking voor een rechte lijn door (x1,y1) en (x2,y2):
% y = (x2y1-x1y2)/(x2-x1) + (y2-y1)/(x2-x1)*x
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	infile:	naam invoerbestand
%   nread:  aantal in te lezen samples
%	Inparm:	structure met invoerparameters
%       colt:   kanaal met de tijd (0 voor geen)
%       wavb:   type golfschot (h hydraulisch, 
%               e elektronisch)
%       units:   te berekenen eenheid (val voor waarde, 
%               n voor genormeerde waarde,
%               V voor stuurspanning,
%               m voor benaderde uitwijking in m).
%
% Uitvoer:
%	exist:	1: bestand gevonden, 0: bestand niet gevonden
%	A:			array met meetdata
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% beginwaarde uitvoerparameters:
exist=0;
%A=[];	% nodig omdat het anders bij niet-dasylabbestanden 
			% fout gaat

% waardebereik:
if Inparm.wavb=='e'
    wmin = -20000;
    wmax = 20000;
else
    wmin = -32767;
    wmax = 32768;   % asymmetrisch
end

% conversiefactor:
if Inparm.units=='val'
    fact = 1;
else    
    fact = 2./(wmax-wmin);
end    

% omrekenen in m of V (dit is alleen verschillend van de genormeerde waarde
% bij het hydraulisch golfschot):
if Inparm.wavb=='h'
    if Inparm.units=='m'
        fact = 0.3*fact;    % slag 0.6 m i.p.v. 2 m
    elseif Inparm.units=='V'
        fact = 10.*fact;    % [-10 V, +10 V] = 20 V = 10*2
    end
end     
    
%%%% open invoerfile:
FID=fopen(infile,'r');
if (FID<0)
   fprintf('input file not found\n');
   
else
   exist=1;

	%%%% Lees hele invoerbestand in:
	A = fread(FID,'int16');
	fclose(FID);
    % verschuiving i.v.m. asymmetrie [wmin,wmax] (niet bij 'val'):
    if Inparm.units~='val'
        A = A-(wmin+wmax)/2;    % als onderste regels meedoen moet A A1 worden
                                % Hkl, 24-11-04
    end                
	A = fact * A;
    
	% Als dit meedoet: maak A boven weer A1, 24-11-04
    %%%% reduceer de ingelezen matrix tot de 
	%%%% opgegeven samples:
    % Dit is verplaatst naar FN_selectnw2, Hkl, 23-11-04
%	if nread>-0.5
%		[nsamp, nchan] = size(A1);
%		samps(1) = max(Inparm.samp1,1);
%		samps(2) = min(Inparm.samp2,nread);
%		cols = 1:nchan;
%		A  = SFN_red(A1,samps,cols);    % wordt FN_red
%    else
%        A = A1;
%    end
  end		%invoerbestand gevonden   

% Einde FN_indatb5
			


