function m = FN_mom6(f,E,fmin_s,fmax_s);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_mom6
%   Calculates moments from variance spectrum 
%   version 6: range E>=thresh, matrix
%   16-Oct-03
%
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 5: met grenzen gebied E>=drempel, vector
%   versie 4: aanpassing voor matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   f:  kolomvector met frequenties
%   E:  matrix met spectra E(i,j)=spectrale term i bij kanaal j,
%       met enkelzijdig variantiespectrum met constante 
%       term 0, E(1,:)=E(f(1)), f(1)=df.
%   fmin_s-fmax_s: gebied waarbinnen E >= een opgegeven drempel * max(E)
%
% uitvoer:
%   m:  matrix met 0-de, 1e, 2-e en 4-e moment van het variantie-
%       spectrum, m(1,j) is het 0-de moment van kanaal j.
%
% Momenten: mn = integr(0:f(N)) E(f)*f^n df, N aantal spectrale termen
% Voor integratie wordt de trapeziumregel gebruikt. E(1) en E(N) zijn
% klein.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% bepaal gebied f:
df          = f(2)-f(1);
ithresh(1)   = ceil(fmin_s/df);   % f = i*df, i=1,2,...
ithresh(2)   = floor(fmax_s/df);
ft          = f(ithresh(1):ithresh(2));
Et          = E(ithresh(1):ithresh(2),:);
[nf,ng] = size(Et);

f1 = zeros(nf,ng);
f2 = zeros(nf,ng);
f3 = zeros(nf,ng);


for pp=1:ng
    E_temp      = Et(:,pp);
    f1(:,pp)    = ft .* E_temp;
    f2(:,pp)    = (ft.^2) .* E_temp;
    f4(:,pp)    = (ft.^4) .* E_temp;
end    


% momenten
% moment n = integraal (E*f^n), bepaald met trap.regel:
m(1,:)  = trapz(ft,Et);    % m0
m(2,:)  = trapz(ft,f1);   % m1    
m(3,:)  = trapz(ft,f2);   % m2
m(4,:)  = trapz(ft,f4);   % m4

% test: numerieke integratie met simpsonregel:
% bezwaar: resultaat hangt af van ligging piek in spectrum;
% Beter: trapregel.
% m(1)  = FN_simp(f,E);    % m0
% m(2)  = FN_simp(f,f1);   % m1    
% m(3)  = FN_simp(f,f2);   % m2
% m(4)  = FN_simp(f,f4);   % m4

% einde FN_mom6