function [A2,Outparmts] = FN_momts(A1,Inparm,Scanparm);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_momts
%   Scale values and calculate statistic moments of time signal
%   version 1
%   11-Jan-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   input:
%   A1: matrix of time signals per channel
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: als bij Decomp, zie 
%                                            onder col)
%       dt:     tijdstap
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het 
%               spectrum
%       nh:     aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten (xp: xpos, n.a.v. Decomp v.14 en ouder)
%       hxp:    dieptes op plaatsen van de golfhoogtemeters (wordt berekend
%               uit overige invoerparameters, alleen Decomp)
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%       x:      rijvector met x-coordinaten waarvoor het diepteprofiel is
%               gegeven (nu: alleen Decomp)
%       h:      dieptes in diepteprofiel (nu: alleen Decomp)
%   Scanparm:   structure gegevens over met gekozen samples:
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%
% output:
%   A2: scaled values with substraction of mean value
%   Outparmts:  structure with output parameters of time signal
%       M1:     mean value is 1st moment 
%       var:    variance of time signal
%       Hm0t:   4. * (Outparmts.var .^0.5); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            
% multiply by scale factor:
[nsamp,nchan]   = size(A1);
e               = ones(nsamp,1);
fact            = e*Inparm.sc;
A1              = fact.*A1;
                    
% calculate moments
Outparmts.M1     = mean(A1); % mean value is 1st moment of time signal
Outparmts.var    = var(A1);   % variance of time signal
% hm0 = 4 srqt(m0), var=m0 of spectrum of total signal
Outparmts.Hm0t   = 4. * (Outparmts.var .^0.5); 
               
% substract mean of A1:
A2 	= A1 - e*Outparmts.M1;

% end FN_momts