function FN_outdata2(out_num,in_naam,Inparm,Scanparm,Outparm,Tf,Ae)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_outdata2
%   General function to write results to an output file
%   version 1
%   9-Dec-04
%
%
%
%
%   H. Kaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% let op: bij inv. en teruggekaatste golf moeten a_i, a_r resp. E_i, E_r
% in een 2D-matrix worden gezet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%   out_num:    nummer dat aangeeft wat de functie uitvoert (1: meetdata,
%               2: spectra)
%   in_naam:    naam invoerbestand
%
%   Inparm:     structure met invoerparameters (uitvoer van FN_inparm)
%       h:      gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in invoerbestand
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       nh:     aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       x:      rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%
%   Scanparm:   structure gegevens over met gekozen samples: (uitv. v.
%               FN_selectnw2)
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%
%   Outparm:    structure met uitvoerparameters; hier gebruikt:
%       df:     frequentiestap
%
%   Tf:         vector met tijden of frequenties
%   Ae1:        matrix met meetwaarden of spectra

% bepaal gebruikte kanalen:
[nsamp,nchan] = size(Ae);
col = 1:nchan;
if isfield(Inparm,'col')
    nch = length(Inparm.col);
    if nch==nchan
        col = Inparm.col';
    end
end    

% uitvoerbestand:
if out_num==2
    tekst = 'file to write spectra';
else
    tekst = 'file to write output data';
end    
[uitnaam, uitpad] = FN_chsoutf4('.asc',tekst);
if uitnaam~=0
    uitfile = [uitpad uitnaam];
    FID6    = fopen(uitfile,'w');
    
    fprintf(FID6,'Input file: %s\r\n',in_naam);
    fprintf(FID6,'time interval used: %10.4f - %10.4f s\r\n',...
        Scanparm.tuit1,Scanparm.tuit2);
    fprintf(FID6,'time step used:     %10.4f s\r\n',Scanparm.dt);
    if isfield(Outparm,'df')
        fprintf(FID6,'frequecy step:  %10.4f Hz\r\n',Outparm.fres);
    end
    fprintf(FID6,'\r\n\r\ncols:         ');
    fprintf(FID6,'%8d',Inparm.col);
    if isfield(Inparm,'x')
        fprintf(FID6,'\r\npos (m):      ');
        fprintf(FID6,'%8.3f',Inparm.x);
    end    
    if isfield(Inparm,'h')
        h = Inparm.h;
        if length(h)==1
            fprintf(FID6,'\r\n\r\naverage waterdepth:     %10.4f',Inparm.h);
        else    
            fprintf(FID6,'\r\nwaterdepth (m): ');
            fprintf(FID6,'%8.3f',Inparm.h);
        end    
    end
    
    nt = length(Tf);
    if out_num==1
        fprintf(FID6,'\r\n\r\n time_(s)    ');
        fprintf(FID6,'chan%2d        ',col);
        for i=1:nt
            fprintf(FID6,'\r\n%10.4f  ',Tf(i));
            fprintf(FID6,'%12.4f  ',Ae(i,:));
        end    
    else
        fprintf(FID6,'\r\n\r\n freq (1/s)  ');
        fprintf(FID6,'E%2d (m^2s)    ',col);
        for i=1:nt
%            if fs(i)>=fmin_sp & fs(i)<=fmax_sp
            fprintf(FID6,'\r\n%10.4f  ',Tf(i));
            fprintf(FID6,'%12.4e  ',Ae(i,:));
            %        end
        end    
   end    

    
    fclose(FID6);
end

% einde FN_outDsp
