function FN_outdata3(out_num,in_naam,Inparm,Scanparm,Outparm,Tf,Ae_i,Ae_r)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_outdata3
%   General function to write results of a calculatin of reflection
%   to an output file.
%   version 1
%   12-Jan-05
%
%
%
%   H. Kaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%   out_num:    nummer dat aangeeft wat de functie uitvoert (1: meetdata,
%               2: spectra)
%   in_naam:    naam invoerbestand
%
%   Inparm:     structure met invoerparameters (uitvoer van FN_inparm)
%       h:      gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in invoerbestand
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       nh:     aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       wavb:   voor Bekijkb: type golfschot (h hydraulisch, 
%                   e elektronisch)
%       units:  voor Bekijkb: te berekenen eenheid (val voor waarde,
%                   n voor genormeerde waarde,
%                   V voor stuurspanning,
%                   m voor benaderde uitwijking in m).
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       x:      rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%       unit:   rijvector met gewenste eenheid
%
%   Scanparm:   structure gegevens over met gekozen samples: (uitv. v.
%               FN_selectnw2)
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%
%   Outparm:    structure met uitvoerparameters; hier gebruikt:
%       df:     frequentiestap
%       fmin_t, fmax_t: voor berekening gebruikte deel van het spectrum
%
%   Tf:         vector met tijden of frequenties
%   Ae_i:       vector met spectrum of tijdsig. invallende golf
%   Ae_r:       vector met spectrum of tijdsig. teruggekaatste golf

% uitvoerbestand:
if out_num==2
    tekst = 'file to write spectra';
else
    tekst = 'file to write output data';
end    
[uitnaam, uitpad] = FN_chsoutf4('.asc',tekst);
if uitnaam~=0
    uitfile = [uitpad uitnaam];
    FID6    = fopen(uitfile,'w');
    
    fprintf(FID6,'Input file: %s\r\n',in_naam);
    fprintf(FID6,'time interval used: %10.4f - %10.4f s\r\n',...
        Scanparm.tuit1,Scanparm.tuit2);
    fprintf(FID6,'time step used:     %10.4f s\r\n',Scanparm.dt);
    if out_num==2
        fprintf(FID6,'frequecy step:  %10.4f Hz\r\n',Outparm.fres);
    end
    fmin_t = Outparm.fmin_t;
    fmax_t = Outparm.fmax_t;
    fprintf(FID6,'freq-range  %8.4f - %8.4f Hz\r\n',fmin_t,fmax_t);

    x   = Inparm.x;
    h   = Inparm.h;
    xp  = Inparm.xp;
    fprintf(FID6,'\r\nWaterdepth:\r\n');
    fprintf(FID6,'pos        (m)');
    fprintf(FID6,'%8.4f',x);
    fprintf(FID6,'\r\ndepth      (m)');
    fprintf(FID6,'%8.4f',h);
    fprintf(FID6,'\r\npos_gauges (m)');
    fprintf(FID6,'%8.4f ',xp);
 
    nt = length(Tf);
    if out_num==1
        fprintf(FID6,'\r\n\r\n    t(s)    a_in (m)     a_ref (m)\r\n');
        for i=1:nt
            fprintf(FID6,'%8.2f %12.6f  %12.6f\r\n',...
                Tf(i),Ae_i(i),Ae_r(i));
        end    
    
    else
        fprintf(FID6,...
            '\r\n\r\nf_(1/s)        E_i_(m^2s)     E_r_(m^2s)\r\n');
        for i=1:nt
            if Tf(i)>=fmin_t & Tf(i)<=fmax_t
                fprintf(FID6,'%10.4e  %12.4e  %12.4e\r\n',...
                    Tf(i),Ae_i(i),Ae_r(i));
            end    
        end
    end    

    
    fclose(FID6);
end

% einde FN_outdata3