function FN_outparmR1(in_name,path_name,Inparm,Scanparm,Outparm,error)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_outparmR1
%   Print input and output parameters of Refreg1
%   version 1
%   25-Jan-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer
%   in_naam:    naam invoerbestand
%   padnaam:    pad invoerbestand
%
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in meetdata (niet: in bemonsterde data)
%       samp1:  eerste te verwerken punt meetreeks
%       samp2:  laatste te verwerken punt meetreeks (-1 tot einde)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%
%   Scanparm:   structure gegevens over met gekozen samples: (uitv. v.
%               FN_selectnw2)
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%
%   Outparm:    structure met uitvoerparameters;
%               inhoud afhankelijk van uitgevoerde berekening
%   error:      de waarde 101 geeft een foumelding bij Refreg: 
%               te grof bemonsterd
%
%   uitvoer:
%   wordt gechreven naar bestand path_name\in_name

                       

% Uitvoerbestand met resultaat:
out_name = ['out' in_name];

Header =  'Refreg version 18, reflection of regular wave';

if out_name~=0
    outfile = [path_name '\' out_name]
    FID5    = fopen(outfile,'w');
    fprintf(FID5,'Program %s\r\n',Header);
    d = datestr(now);
    fprintf(FID5,'%s\r\n\r\n',d);
    

    fprintf(FID5,'\r\n\r\n*************Input values******************\r\n');
    fprintf(FID5,'Input file: %s\r\n',in_name);
    fprintf(FID5,'Time step in input file:     %8.4f s\r\n',Inparm.dt);
    fprintf(FID5,'\r\n\r\nSamples asked:'); 
    fprintf(FID5,'                    %10.0f, %10.0f\r\n', ...
        Inparm.samp1, Inparm.samp2);
    fprintf(FID5,'Time interval asked:');
    fprintf(FID5,'                    %10.4f, %10.4f\r\n', ...
        Scanparm.tin1, Scanparm.tin2);
    fprintf(FID5,'Time interval used: ');
    fprintf(FID5,'                    %10.4f, %10.4f\r\n', ...
       Scanparm.tuit1, Scanparm.tuit2);
    fprintf(FID5,'Time step used:     ');
    fprintf(FID5,'                    %10.4f s', Scanparm.dt);
    fprintf(FID5,'\r\n\r\nNumber of samples used:');
    fprintf(FID5,'                   %6d\r\n', Outparm.N);
    
    fprintf(FID5,'\r\n\r\nChannels used:\r\n');
    fprintf(FID5,'\r\ncols:         ');
    fprintf(FID5,'%10d',Inparm.col);
    if isfield(Inparm,'xp')
        fprintf(FID5,'\r\npos (m):      ');
        fprintf(FID5,'%10.2f',Inparm.xp);
    end    
    if isfield(Inparm,'sc')
        fprintf(FID5,'\r\nscale to m:   ');
        fprintf(FID5,'%10.4f',Inparm.sc);
    end    
    if isfield(Inparm,'hm')
        fprintf(FID5,'\r\n\r\naverage waterdepth (m):   %10.4f',Inparm.hm);
    end
    if isfield(Inparm,'hxp')
        fprintf(FID5,'\r\nwaterdepth (m): ');
        fprintf(FID5,'%10.2f\r\n',Inparm.hxp);
    end

    if isfield(Inparm,'x')
        fprintf(FID5,'\r\n\r\nDepth profile:\r\n');
        fprintf(FID5,'\r\nx_pos (m):      ');
        fprintf(FID5,'%10.2f',Inparm.x);
    end
    if isfield(Inparm,'h')
        fprintf(FID5,'\r\nwaterdepth (m): ');
        fprintf(FID5,'%10.2f',Inparm.h);
    end

    SFN_outparmR(FID5,Inparm,Outparm,error);
    
end % uitvoerbestand gevraagd    

% einde FN_outparmR1


function SFN_outparmR(FID5,Inparm,Outparm,error);
% uitvoer Refreg, 8-12-04

if error==101;
    fprintf(FID5,'\r\n********************************************************\r\n');
  	fprintf(FID5,'* Warning:                                             *\r\n');
    fprintf(FID5,'*  If the number of samples per period is less than 20 *\r\n');
    fprintf(FID5,'*  the phase may be inaccurate                         *\r\n');
    fprintf(FID5,'********************************************************\r\n');
end    

% afdruk harmonischen:
fn  = Outparm.fn;
Fan = Outparm.Fan;
N   = Outparm.N;

[nharm,nchana] = size(Fan);
fprintf(FID5,'\r\nResults of SFN_harm9:\r\n');
fprintf(FID5,'\r\nnumber of samples: %d\r\n', N);
if nharm<Inparm.nharm
        fprintf(FID5,'\r\n**************************************\r\n');
    	fprintf(FID5,'* Warning:                           *\r\n');
        fprintf(FID5,'*  Only %d harmonic components found *\r\n',nharm);
        fprintf(FID5,'**************************************\r\n');
end    
amp = abs(Fan);
a   = real(Fan);
b   =-imag(Fan);	% algemeen voor FT: c(i) = a(i) - i*b(i)		
phi = angle(Fan);	
for i=1:2
    fprintf(FID5,'\r\nposition %d\r\n',i);
    fprintf(FID5,'  i         f            a            b            c            phi\r\n');
    for j=1:nharm
        fprintf(FID5,'%4.0f %12.6f %12.6f %12.6f %12.6f %12.6f\r\n',...
          j,fn(j,i),a(j,i),b(j,i),amp(j,i),phi(j,i));
    end
end    

fprintf(FID5,'\r\nreflection coefficient calculated with velocity 0:\r\n');
dx = Inparm.xp(2)-Inparm.xp(1);
fprintf(FID5,'distance of wave gauges      : %9.3f m\r\n', dx);
for i=1:2
    fprintf(FID5,'\r\nposition %d\r\n',i);
    fprintf(FID5,'\r\nPosition                 :  %9.3f m\r\n', Inparm.xp(i));
    fprintf(FID5,'period of 1st harmonic       : %10.4f s\r\n', Outparm.T);
    fprintf(FID5,'wave length                  : %10.4f m\r\n', Outparm.L);
    fprintf(FID5,'A-component of harmonic      : %10.4f\r\n', Outparm.a(1,i));
	fprintf(FID5,'B-component of harmonic      : %10.4f\r\n', Outparm.b(1,i));
    fprintf(FID5,'amplitude of harmonic        : %10.4f m\r\n', Outparm.c(1,i));
end   

fprintf(FID5,'\r\namplitude of incoming wave   : %10.4f m\r\n', Outparm.ai);
fprintf(FID5,'amplitude of reflected wave  : %10.4f m\r\n', Outparm.ar);
fprintf(FID5,'reflection coefficient       : %10.4f\r\n', Outparm.fr);
fprintf(FID5,'\r\nphase of incoming wave       : %8.2f deg\r\n', Outparm.phi_i);
fprintf(FID5,'phase of reflected wave      : %8.2f deg\r\n', Outparm.phi_r);
fprintf(FID5,'\r\ndeterminant                 : %10.4f\r\n', Outparm.det);
fprintf(FID5,'\r\nPhases have been calculated with respect to a position ');
fprintf(FID5,'halfway the two wave gauges;');
fprintf(FID5,'\r\nt=0 at the first sample of the measurements');
if Outparm.det < 1
    afst = Outparm.L/4;
    tekst1 = sprintf('Warning: det<1\n'); 
    tekst2 = sprintf('distance of wave gauges recommended: %6.2g m',afst);
    tekst    = [tekst1 tekst2];
    h        = msgbox(tekst);
    uiwait(h);
    fprintf(FID5,'\r\n************************************************\r\n');
    fprintf(FID5,'* Warning: det<1                                   \r\n'); 
    fprintf(FID5,'* distance of wave gauges recommended: %6.2g m        \r\n',afst);
    fprintf(FID5,'*************************************************\r\n');
end    

fclose(FID5);
% einde SFN_outparmR
