function [Tp,fp,Ep,fmin_s,fmax_s]=FN_piekper4(f,E,thresh);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_piekper4
%   Calculate peak period, peak frequency, and range where
%   variance density >= thresh*peakvalue from a variance 
%   spectrum E.
%   version 4: frequency range where E>=thresh*max(E)
%   21-Oct-03
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 4: met frequentiegebied waarbinnen E>=thresh*max(E)
%   versie 3: E als matrix (alleen Decomp2)
%   versie 2: variantiespectrum
%   versie 1: FFT.
% invoer:
%   f:      vector met frequenties
%   E:      vector met variantiespectrum voor f=df:df:length(A)*df
%   thresh:  drempel: E>=thresh*sum(E)/N
%
% uitvoer:
%   Tp(1):  1/fp, met fp de frequentie bij de hoogste E.
%   Tp(2):  1/fpD, met fpD de frequentie in het midden van de band
%           van frequenties waarin E>=0.8*max(E)
%   fp(1):  frequentie bij de hoogste E.
%   fp(2):  frequentie in het midden van de band waarin 
%           E>=0.8*max(E)
%   Ep:     maximale spectrale dichtheid
%   fmin_s-fmax_s: gebied waarbinnen E>=thresh*max(E)

nf  = length(f);

% bepaal piekfrequentie:
[Ep,ip] = max(E);
fp(1)   = f(ip);
Tp(1)   = 1/fp(1);

% bepaal gebied waarin E>=0.8Ep:
drempel = 0.8*Ep;
i = 1;
while E(i)<drempel & i<ip
    i = i+1;
end
iond = i;

i = nf;
while E(i)<drempel & i>ip
    i = i-1;
end
ibov = i;

f1  = f .* E;
fp(2) = sum(f1(iond:ibov)) / sum(E(iond:ibov));
Tp(2) = 1/fp(2); 

% bepaal gebied waarin E>=thresh*max(E):
%drempel = thresh*sum(E)/nf;
drempel = thresh*max(E);
i = ip;
while E(i)>=drempel & i<nf
    i = i+1;
end
fmax_s = f(i);

i = ip;
while E(i)>=drempel & i>1
    i = i-1;
end
fmin_s = f(i);

% einde FN_piekper4