function [Tp,fp,Ep]=FN_piekper8(fmin_t,fmax_t,f,E,thresh);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_piekper8
%   Calculates peak period and peak frequency from a 
%   variance spectrum E.
%   version 8: frequency range from version 4 as input
%   14-Sep-04
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   version 8: frequency range from version 4 as input
%   version 5: thresh used in calculation of TpD (80%)=thresh used 
%             in calc. of freq. range  
%   version 4: frequency range where E>=thresh*max(E) in output
%   version 3, 6, 7: versions where E is a matrix (different version of
%   Decomp)
%   version 2: variance spectrum
%   version 1: FFT.
% input:
%   f:  vector with frequencies
%   E:  vector with variance spectrum
%
% output:
%   Tp(1):  1/fp, where fp is the frequency where E has its maximum
%   Tp(2):  1/fpD, where fpD is the frequency at the centre of the 
%           freq.band were E>=0.8*Emax
%   fp(1):  frequency at the maximum E
%   fp(2):  frequency at the centre of the band where
%           E>=0.8*Emax
%   Ep:     maximum spectral density

%nf  = length(f);
df      = f(2)-f(1);
j_ond   = round(fmin_t/df);
j_ond   = max(j_ond,1);
j_bov   = round(fmax_t/df);
j_bov   = min(j_bov,length(E));
nfs     = j_bov-j_ond+1;

% bepaal piekfrequentie:
% grenzen E aangepast, 14-9-01
[Ep,ip] = max(E(j_ond:j_bov));  
ip      = j_ond + ip-1;   % uitvoer max begint bij 1, 14-9-01
fp(1)   = f(ip);
Tp(1)   = 1/fp(1);

% bepaal gebied waarin E>=0.8Ep:
drempel = 0.8*Ep;
i = j_ond;
while E(i)<drempel & i<ip
    i = i+1;
end
iond = i;

i = j_bov;
while E(i)<drempel & i>ip
    i = i-1;
end
ibov = i;

if iond==ibov
    fp(2) = fp(1);
    Tp(2) = Tp(1);
else    
    f1  = f .* E;
    fp(2) = sum(f1(iond:ibov)) / sum(E(iond:ibov));
    Tp(2) = 1/fp(2); 
end    

% einde FN_piekper8