function FN_plot25(Ts,A1,Inparm,in_naam,first)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_plot25
%   plot data with maximum and minimum, 3 chanels per fig.
%   version 25: Ts in separate vector, tijd selected
%       instead of sample numbers
%   8-Dec-04, 13-Dec-04: axis set off, line 68
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% versie 25: Ts al in aparte vector, tijd geselecteerd
%       i..v. samplenummers
% versie 21: uiwait aan eind uitgeschakeld, lus uit aanroepend
%            prog FN_lvmplot2 verwijderd.
% versie 18: met close oudere figuren en extra msg bij 1e aanroep
% versie 14: met plotstap, om ook een stap te kunnen nemen als
%           het bestand niet opnieuw wordt ingelezen
% versie 12: terug naar aanroepend prog. FN_lvmplot1 als alle figuren 
%            gesloten
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Invoer
%   Ts       vector met tijden
%   A1		matrix met te plotten deel van de ingelezen data
%   Inparm:	structure met invoerparameters
%       dt:         tijdstap
%       plotstep:   stapgrootte bij plotten ingelezen punten
%       colt:       kanaal met de tijd (0 voor geen)
%	    col:	    vector met kolomnummers 
%   in_naam:    naam invoerbestand
%%   first:      0 voor eerste aanroep van een plotfunctie,
%               1 na eerste aanroep
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% bepaal aantal samples en monsternummer/tijden:
[nsamp, nchan1]=size(A1);
nchan2 = length(Inparm.col);

if nchan1~=nchan2
    tekst   = 'No samples selected, chanels reset to default';
    h1      = msgbox(tekst);
    uiwait(h1);
    Inparm.col = 1:nchan1;
end    

    %else

    %%%% maak plots per kanaal:
    n=ceil(nchan1/3);
    m=ceil(nchan1/n);
    ichan = 1;
    for i=1:n
       close(figure(i));
       h1(i)=figure(i);
       for j=1:m
           if ichan<=nchan1     % nchan->nchan1, 20-8-03
                pos = 1-0.33*(j-1);
                subplot(m,1,j);
                h=plot(Ts,A1(:,ichan),'-');  % met marker: '.-'
                                            % kan in plotmenu wdn 
    %            h = stairs(Ts,A1(:,ichan)); % gebruikt voor test monsterpunten
                % bepaal schaal:
                ymin = min(A1(:,ichan));
                ymax = max(A1(:,ichan));
                ymin = ymin - 0.1*(ymax-ymin);
                ymax = ymax + 0.1*(ymax-ymin);
                xmin = Ts(1);
                xmax = Ts(nsamp);
%                axis([xmin xmax ymin ymax]);   % handmatig instellen van
%                de as kan fout gaan, Hkl, 13-12-04
                grid on;
                % zoom: werkt niet
                %zoom off;
                %zoom xon;
                xlabel('time (s)');
                set(gca,'Fontsize',8,'Gridlinestyle',':');
                tekst = ['channel ' num2str(Inparm.col(ichan))];
                x=get(h,'XData');
                y=get(h,'YData');
                imin=find(min(y)==y);
                imax=find(max(y)==y);
                if j==1
                    title(in_naam,'Fontsize',8);
                end    
                text(x(imin(1)),y(imin(1)),['min ',num2str(y(imin(1)))],'FontSize',8);
                text(x(imax(1)),y(imax(1)),['max ',num2str(y(imax(1)))],'FontSize',8);
                xlims	= get(gca,'Xlim');
                ylims	= get(gca,'Ylim');
                range   = ylims(2) - ylims(1);
                posx = nsamp/2;
    %           text(posx,ylims(1)-0.2*range,tekst,'FontSize',8);
    %           gewijzigd, 7-11-02
                if nchan1==1
                    posy = ylims(1)-0.1*range;
                else    
                    posy = ylims(1)-0.2*range;
                end     
                text(xlims(1),posy,tekst,'FontSize',8);
                ichan = ichan+1;
            end       
        end   
    end
    %end    

% eerste aanroep:
if first==0
    tekst1 = sprintf('To change plot parameters:\n');
    tekst2 = sprintf('Close or minimize all figures,\n');
    tekst3 = 'Choose pull down menu Plot, option Samples'; 
    h3 = msgbox([tekst1 tekst2 tekst3]);
    uiwait(h3);
%   first = 1; % werkt niet ivm uiwait
end    

% wacht tot alle figuren gesloten
%for i=n:-1:1
%    if ishandle(h1(i))
%        uiwait(h1(i));
%    end    
%end    
% Einde FN_plot25
			


