function FN_plotD16(nfig,in_naam,Inparm,Outparm,Fs,Es_i,Es_r,...
    interp,method,outs);
% FN_plotD16
%   Make graph variance spectra of incoming and reflected wave, 
%   either sum over freq. bands or avaraged over spectra of parts 
%   of the time series
%   version 16: some parameters stored in Inparm en Outparm
%   11-Jan-05
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 16: sommige parameters worden gehaald uit Inparm en Outparm
%   versie 15: keuze of refl. coeff wel of niet geplot moet worden
%   versie 14: met foutmelding verkeerde afstand (vervallen)
%   versie 13: met opgaaf methode van middelen
%   FN_plotD12: plotten variantiespectrum van 1 kanaal
%   versie 7a:  oudere versie voor gemiddelde over deelreeksen
%   versie 7 t/m 11: bij Decomp5
%   versie 6: met opgaaf drempel (thresh) en wel of niet interpoleren
%   versie 5, aanduiding grenzen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   nfig:       figuurnummer (nodig bij meer aanroepen van deze functie)
%   in_naam:    string met naam meetbestand
%	Inparm:	structure met invoerparameters
%       dt:     tijdstap
%       fres:   gewenste frequentieresolutie in variantiespectrum
%       f_max:  bovengrens te berekenen freq.gebied
%       thresh: voor Spect: drempel voor het te plotten deel van het spectrum
%       colt:   kanaal met de tijd (0 voor geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten (xp: xpos, n.a.v. Decomp v.14 en ouder)
%       hxp:    dieptes op plaatsen van de golfhoogtemeters (wordt berekend
%               uit overige invoerparameters, alleen Decomp)
%       x:      rijvector met x-coordinaten waarvoor het diepteprofiel is
%               gegeven
%       h:      dieptes in diepteprofiel
%   Outparm:    structure met uitvoerparameters, gedefinieerd in FN_spD
%               en FN_decomp
%   Fs:         vector met frequenties van het gesommeerde spectrum
%   Es_i:       gesommeerde energiepercentages inkomende golf
%   Es_r:       gesommeerde energiepercentages teruggekaatste golf
%   interp:     1: interpoleren met spline, 0: niet interpoleren
%   method:     gebruikte methode: 1 gem. spectrum over freq-bandjes,
%                                  2 gem spectrum over deelreeksen 
%   outs:       outs(3)=1: spectra plotten, outs(4)=1: refl. coef.
%               plotten

nf      = length(Fs);
e       = ones(3,1);
fmin_sp = Outparm.fmin_t;
fmax_sp = Outparm.fmax_t;
fres    = Outparm.fres;
thresh  = Inparm.thresh;

% interpolatie met spline gem. spectrum over gebied waar gem>drempel:
% bepaal gebied f:
df           = Fs(2)-Fs(1);

ithresh(1)   = ceil(fmin_sp/df);   % f = i*df, i=1,2,...
ithresh(2)   = floor(fmax_sp/df);
ithresh(2)   = min(ithresh(2),length(Fs));

if interp==1
    fb      = Fs(1:ithresh(1));
    fe      = Fs(ithresh(2):nf);
    fm      = Fs(ithresh(1))+df/4:df/4:Fs(ithresh(2))-df/4;
    fn      = [fb fm fe];
    Esf_i   = spline(Fs,Es_i,fn);
    Esf_r   = spline(Fs,Es_r,fn);
else
    Esf_i   = Es_i;
    Esf_r   = Es_r;
    fn      = Fs;
end    

f1      = fmin_sp*e;
f2      = fmax_sp*e;
Emax    = max(Esf_i);
dE      = Emax/3;
y       = 0:dE:2*dE;
%f1      = [fmin_sp,fmin_sp];
%f2      = [fmax_sp,fmax_sp];
%y       = [0,Emax];
if outs(3)==1
    set(0,'DefaultLineColor','k');
    h4 = figure(nfig);
    plot(fn,Esf_i,fn,Esf_r,'.-',f1,y,'->k',f2,y,'-<k');
%    plot(fn,Esf_i,fn,Esf_r,'.-');
    % set(gca,'YScale','log','Fontsize',8,'Gridlinestyle',':');
    set(gca,'Fontsize',8,'Gridlinestyle',':');
    if interp==1
        tekst1 = 'Spline interpol. variance spect of inc and refl wave';
    else
        tekst1  = 'variance spect of inc and refl wave'; 
    end
    tekst2  = [' of file ' in_naam];
    % tekst2 = sprintf(' of file %s',in_naam); 
    if method==2
        tekst3 = sprintf('\naveraged over subseries of resol %7.3f Hz',...
            fres);
    else    
        tekst3  = sprintf('\nsummed over f-bands of width %7.3f Hz', fres);
    end
    tekst4 = sprintf(', thresh in spect. %8.4f*E_{max}',thresh);
    % tekst4 = sprintf('\ntest: in time signal Hanning window of width N/10 used');
    tekst   = [tekst1 tekst2 tekst3 tekst4];
    title(tekst,'Fontsize',8);
    xlabel('f (Hz)');
    df = Fs(2) - Fs(1);
    tekst4 = 'm^2/Hz';
    %tekst4 = sprintf('%% of energy in freq.band of %7.3f Hz',df);
    ylabel(tekst4);
    leg = {'incom','refl','freqs of valid decomp'};
    legend(leg);
    % uiwait(h4);     % toegevoegd, 23-12-03
end %outs(3)==1
if outs(4)==1
    Kr = zeros(nf,1);
    for i=ithresh(1):ithresh(2)
        Kr(i) = (Es_r(i)/Es_i(i))^0.5;
    end    
    Krmax   = max(Kr);
    dKr     = Krmax/3;
    y       = 0:dKr:2*dKr;

    h5 = figure(nfig+1);
    plot(Fs,Kr,f1,y,'->k',f2,y,'-<k');
%    plot(Fs,Kr);
    titel = sprintf('File %s, Coeff of reflection',in_naam);
    title(titel);
    xlabel('f (Hz)');
    % uiwait(h5);     % toegevoegd, 23-12-03, later weer uitgeschakeld
end    

% figure(2);
% h4  = plot(f_LF,p_out);
% set(gca,'Fontsize',8,'Gridlinestyle',':');
% tekst = ... 
% sprintf('Averaged PDS of outgoing wave\nfilterlength %d',nf);
% title(tekst,'Fontsize',8);
% xlabel('f (Hz)');
% ylabel('PD (m^2/Hz)');
   
% einde FN_plotD15