function FN_plotb2(Ts,A,Inparm,in_naam)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_plotb2 
%   plot binary data with maximum and minimum, 3 chanels per fig.
%   version 2: changed to general setup
%   used by Bekijkb
%   7-Dec-04
%
%
%
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Invoer
%   Ts:      tijdvector
%   A		meetdata
%	Inparm:	structure met invoerparameters
%       colt:   kanaal met de tijd,
%       wavb:   type golfschot (h hydraulisch, 
%               e elektronisch)
%       units:  te berekenen eenheid (V voor stuurspanning,
%               m voor benaderde uitwijking in m).
%   in_naam:    naam invoerbestand
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%% bepaal aantal samples:
[nsamp, nchan]=size(A);

%%%% maak plots per kanaal:
% Opm.: bij een .dat-bestand is er eigenlijk maar 1 kanaal
% maar om deze functie later voor andere roepassingen te kunnen
% gebruiken is er niets veranderd
n=ceil(nchan/3);
m=ceil(nchan/n);
ichan = 1;

for i=1:n
   figure(i);
   for j=1:m
       if ichan<=nchan
           pos = 1-0.33*(j-1);
            subplot(m,1,j);
            h=plot(Ts,A(:,ichan),'-');
            grid on;
            set(gca,'Fontsize',8,'Gridlinestyle',':');
            tekst = ['channel ' num2str(ichan)];
            xlabel('time (s)');
%   De tijd is in de mieuwe versie al uit A gehaald;
%   de volgende regels vervallen:
%            if Inparm.colt==0
%                xlabel('sample number');
%            else
%                xlabel('time (s)');
%            end
            if Inparm.units=='m'
                ylabel('approximated board position in m');
            elseif Inparm.units=='V' & Inparm.wavb=='h'    
                ylabel('voltage in V');
            elseif Inparm.units=='val'    
                ylabel('digital value');
            else    
                ylabel('normed value');
            end    
            x=get(h,'XData');
            y=get(h,'YData');
            imin=find(min(y)==y);
            imax=find(max(y)==y);
            titel = [in_naam ', waveboard: ' Inparm.wavb];
            if j==1
                title(titel,'Fontsize',8);
            end
            ymint = sprintf('min %10.4g',y(imin(1)));
            ymaxt = sprintf('max %10.4g',y(imax(1)));
            text(x(imin(1)),y(imin(1)),ymint,'FontSize',8);
            text(x(imax(1)),y(imax(1)),ymaxt,'FontSize',8);
%           vervangen, 16-12-03
%            text(x(imin(1)),y(imin(1)),['min ',num2str(y(imin(1)))],'FontSize',8);
%            text(x(imax(1)),y(imax(1)),['max ',num2str(y(imax(1)))],'FontSize',8);
            ylims	= get(gca,'Ylim');
            range   = ylims(2) - ylims(1);
            x1 = nsamp/2;
            text(x1,ylims(1)-0.2*range,tekst,'FontSize',8);
            ichan = ichan+1;
            if ichan==Inparm.colt
                ichan = ichan+1;
            end    
        end   
    end   
end   

% Einde FN_plotb2
			


