function FN_plotspect1(in_naam,Inparm,Scanparm,f,c)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_plotspect1
%   Plot a spectrum of a matrix.
%   version 1
%   24-1-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% older version FN_spect: plot spectrum of row vector
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input:
%   in_naam:    name of input file
%   Inparm: parameters asked by user
%       dt:     time step in measurements s (used before: tijdstap)
%       thresh     threshold: part of spectrum lower than thresh*cmax
%                       will not be printed or plotted
%       ncols:  number of chanels to be processed (here:2)
%	    col:	rowvector with column numbers channels
%               (used before: col1 (col one), col2)
%       unit:   vector of char.strings containing units of the mearured value
%       sc:     rowvector with scale factor measurement values to m
%               (used before: sch1, sch2)
%   Scanparm:   structure with information about samples asked by user:
%       t1:     begin time asked (begin time used: Ts(1))
%       t2:     end time asked (end time used: Ts(length(Ts)))
%       step:   sample step with respect to the measurements
%       dt:     time step in the sampled data (vector Ts)
%   f:  frequency vector
%   c:  matrix of amplitudes
%				        H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dt      = Scanparm.dt;

% bepaal gebied waar amplitude > drempel:
[N1,nchan] = size(c);
ampmin  = Inparm.thresh.*max(c);
imax    = N1;

% lus kanalen:
for j=1:nchan
    
    % zoek bovengrens plot:
    for i=1:N1
        if abs(c(i,j))>ampmin
            imax = i;
        end    
    end


    f1 = f(1:imax);
    c1 = c(1:imax,j);
    % variance: higher harmonics are low with respect to first
    % c1 = c1.^2;
    figure(j);
    plot(f1,c1);
    grid on;
    tekst1  = sprintf('file %s, ampl. spect. of chan %d',in_naam,Inparm.col(j));
    tekst2  = sprintf('\nthreshold %6.4f * amp(max)',Inparm.thresh);
    titel   = [tekst1 tekst2];
    title(titel);
    % eenheid: in Var.sp: [eenheid]^2 s; 
    % daar wordt voor de schaal vermenigvuldigd met N*dt; 
    % hier is dus de eenheid: wortel (([eenheid]^2 s)/s) = [eenheid]
    tekst = ['[' Inparm.unit(j) ']']; 
    ylabel(tekst); 
    xlabel('freq (Hz)');
end    

% einde FN_plotspect1