function [y_inc,y_rfL] = FN_reconst(a_inc,a_rfL,f_LF,fmin_t,fmax_t,N);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_reconst
%   Reconstruction of spectra of incident and reflected waves
%   to time signals.
%   version 1
%   28-Apr-04, names adapted to general setup: 13-Jan-05
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Input:
%   a_inc:  FFT of incident wave
%   a_rfL:  FFT of reflected wave
%   f_LF:   frequency vector
%   fmin_t, fmax_t: range where a_inc and a_out are reliable.
%   N:      dimension of the time vector of the original time signal;
%           to be used for scaling
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% find the valid part of the spectrum, and make the rest zero:
% reconstruction of two-sided spectra:
i = 1;
while f_LF(i)<fmin_t
    i = i+1;
end
imin = i;
i = length(f_LF);
while f_LF(i)>fmax_t
    i = i-1;
end
imax    = i;
nf      = length(a_inc);
a_inc(1:imin-1) = 0;
a_rfL(1:imin-1) = 0;
a_inc(imax+1:nf)= 0;
a_rfL(imax+1:nf)= 0;

% two-sided spectra:
a_inc = N/2 * [0 ; a_inc ; zeros(N-2*length(a_inc)-1,1) ; flipud(conj(a_inc))];
a_rfL = N/2 * [0 ; a_rfL ; zeros(N-2*length(a_rfL)-1,1) ; flipud(conj(a_rfL))];

% reconstruction of incident and reflected wave:
y_inc = real(ifft(a_inc));
y_rfL = real(ifft(a_rfL));
              
% end FN_reconst