function Outref = FN_reflec3(f_min, f_max, df, E_i, E_r);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_reflec3
%   Calculate coeff. of reflection and significant wave heights
%   from var. spectra of incoming and reflected wave
%   version 3: from scaled spectra
%   14-Oct-03, changed 11-Jan-05: _o (outgoing) -> _r (reflected)
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% versie 2: uit kwadr. amplitudes
% In deze versie worden Hm0i en Hm0r direct uit de momenten van
% de spectra van invallende en teruggekaatste golf berekend. 
% Volgens Goda mag dit niet.
% invoer:
%   f_min, f_max: frequentiebereik waarbinnen E_i en E_r geldig
%   df:     frequentiestap in spectrum
% Opm. beter: trapz in combinatie met E? (schaal: df).
%   E_i:    vector met variantiespectrum invallende golf
%   E_r:    vector met variantiespectrum teruggekaatste golf
%
% uitvoer:
%   Outref.Kr:    terugkaatsingscoef. over gebied [f_min,f_max]
%   Outrefm.m0i:  mo invallende golf  
%   Outrefm.m0o:  mo teruggekaatste golf  
%       niet meer in uitvoer:
%       -----------------------------------------------------
%       Outref.Hm0:   vector met significante golfhoogtes per 
%                 golfhoogtemeter
%       Outref.Hm0m:  significante golfhoogte, gemiddeld over
%                 golfhoogtemeters
%       -----------------------------------------------------
%   Outref.Hm0i:  significante golfhoogte invallende golf
%   Outref.Hm0o:  significante golfhoogte teruggekaatste golf
              

j_ond   = round(f_min/df);
j_ond   = max(j_ond,1);
j_bov   = round(f_max/df);
j_bov   = min(j_bov,length(E_i));
nfs     = j_bov-j_ond+1;

% terugkaatsingscoefficient: Kr = (sum(E_r)/sum(E_i)).^0.5
% let op: voor f<f_min en f>f_max is al E_i=0 en E_r = 0
% Kr moet volgens Goda worden berekend uit de
% gemiddelde m0 over de golfhoogtemeters en de
% terugkaatsingscoef sum(E_i)/sum(E_r).
% m0 volgt daaruit via de m0 van het hele spectrum.
               
% Schatting van refl. coef. Kr volgens Goda en Suzuki, 
% uit som energieen in geldig freq-gebied:
fact        = df;
Outref.m0i  = fact*sum(E_i(j_ond:j_bov));
Outref.m0r  = fact*sum(E_r(j_ond:j_bov));
if abs(Outref.m0r)>1e-6
    Outref.Kr = (Outref.m0r/Outref.m0i)^0.5;
else
    Outref.Kr = 1000;
end    
                   
% schatting van Hm0 uit m0,  Hi, Hr uit m0i en m0r:
% significante golfhoogte H_1/3 wordt in Auke/pc aangeduid met Hm0
% Outref.Hm0      = 4.*(m0.^0.5);     
% Outref.Hm0m     = mean(Outref.Hm0);
Outref.Hm0i     = 4*(Outref.m0i^0.5);
Outref.Hm0r     = 4*(Outref.m0r^0.5);




% einde FN_Reflec3