function [Refparm] = FN_refparm5(t0,Fa,f,Inparm);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_refparm5
%   Calculate coef. of reflection of a regular wave
%   version 5: version 2 using time vector instead of sample numbers
%   14-Dec-04
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 5: versie 2 met tijdvector i.p.v. monsternummers
%   versie 2: complexe verg., er wordt 1 harmonische bepaald
% De functies FN_refreg1 t/m 4 zijn gebruikt to dec 04,
% vanaf versie 5 heet de functie FN_refparm.
% Deze functie gebruikt complexe verg. voor ai en ar.
% Er wordt van uitgegaan dat Fa en f maar 1 harmonische bevatten;
% voor meer harmonischen: zie FN_refreg2a.
% invoer:
%   t0:     tijdstip begin analyse
%	Fa:		array met FFT-component * 2/N * Inparm.schaal van de eertse
%			harmonische uit FN_harmo
%	f:		frequentie eerste harmonische
%	Inparm:	structure met invoerparameters:
%		dt:     tijdstap in meetdata in s (voorheen: tijdstap)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Let op: werkelijke tijdstapin Scanparm; wordt hier nergens gebruikt
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       nharm:  aantal te printen harmonischen
%		hm:     gemiddelde waterdiepte in m (voorheen: diepte)
%               samp1: first sample to be analysed (replaced by
%                       Scanparm.t1)
%               samp2:  last sample to be analysed (replaced by
%                       Scanparm.t2)
%       ncols:  aantal te verwerken kanalen (hier:2)
%	    col:	rijvector met kolomnummers kanalen
%               (voorheen: col1 (col een), col2)
%       xp:     rijvector met X-coordinaten (voorheen: pos1, pos2)
%       sc:     rijvector met schaalfactor meetwaarden naar meter
%               (voorheen: sch1, sch2)
%
% uitvoer:
%	Refparm:	structure met reflectieparameters
%				.T:		periode 1e harmonische
%				.L:		golflengte 1e harmonische
%				.a:		a-componenten uit Fa
%				.b:		b-componenten uit Fa
%				.c:		ampl. uit Fa
%				.det	abs(determinant) verg. La * Inparm.pos = Fa(1)'
%				.ai:	ampl. invallende golf 1e harmonische
%				.ar:	ampl. teruggekaatste golf 1e harmonische
%				.fr:	terugkaatsingscoefficient 1e harmonische
%				.phi_i	fase invallende golf 1e harmonische
%				.phi_r	fase teruggekaatste golf 1e harmonische
% basisvergelijkingen:
%	[exp(j*ki*pos1)  exp(j*kr*pos1); exp(j*ki*pos2) exp(j*ki*pos2)] * 
%		[ai*exp(j*phi_i); ar*exp(-j*phi_r)] =(Fa.)'
% of: La*ac = (Fa.)'
%	Opm.: voor het bepalen van de terugkaatsingscoefficient voor meer
%			harmonischen zijn ten minste drie golfhoogtemeters nodig
%
%												H. Klaasman
% 13-6-02: FID1 verwijderd als invoerparameter, was niet meer in gebruik.

%fprintf(FID1,'\nFunctie FN_refreg2\n');
%fprintf('Complexe vergelijkingen, 1 harmonische\n');
% bepaal de amplitudes bij de positieve frequenties
% de vermenigvuldigingsfactor is 2/N * Inparm.schaal
 % Als x(t) = A cos(2pi*f*t) + B sin(2pi*f*t)
% kan worden aangetoond dat:
% A = 1/N som_n(x(n*dt) cos(2pi*f*n*dt))
% B = 1/N som_n(x(n*dt) sin(2pi*f*n*dt))
% A - jB = 1/N som_n(x(n*dt) exp(-j*2pi *f*n*ft)
% Uitgaande van de FFT volgt dan dat A = real(FFT(f)) en B = -imag(FFT(f))
[nharm,nc] = size(Fa);
Fb  = Fa';		% de vergelijking voor terugkaatsing werkt met pos1 en pos2
%					in kolommen; i.v.m. het minteken voor b geen Fa.'
a   = real(Fa);
b   =-imag(Fa);
c   = abs(Fa);
phi =-angle(Fa);	% minteken omdat b=-imag(Fa)

% tijdelijk: de waarden van HARMO (Auke/pc) om te zien
% of dit programma met die waarden dezelde uitkomst
% geeft als HREBOF.
%a =[ 2.12459500 4.90434400];
%b =[-5.44432600 2.77955800];
%c =[sqrt(a(1)^2 + b(1)^2) sqrt(a(2)^2 + b(2)^2)]; 
%phi = atan(b/a);
Refparm.a  = a;
Refparm.b  = b;
Refparm.c  = c;


% constanten:
h = Inparm.hm;
delta_x = Inparm.xp(2) - Inparm.xp(1);

% bepaal de golflengte:
T1 = 1/f(1);
% Disper
w  = 2*pi*f(1);
k  = DISPER(w,h);
L  = 2*pi/k;
% Disper replaced by FN_wavel, H. Klaasman, 6-6-02
%L = FN_wavel(h,T1);
%k = 2*pi/L;
Refparm.T = T1;
Refparm.L = L;

% bepaal amplitudes invallende en teruggekaatste golf voor de
% 1e harmonische
% basisvergelijkingen:
%	[exp(j*ki*x1)  exp(j*kr*x1); exp(j*ki*x2) exp(j*ki*x2)] * [ai; ar] =
%   Fb
% of: La*ac = Fb
% x1 = -delta_x/2;  x2 = delta_x/2;  x=0 tussen de golfhoogtemeters
j   = sqrt(-1);
x1  = -delta_x/2;
x2  =  delta_x/2;
La  = [exp(j*k*x1) exp(-j*k*x1); exp(j*k*x2) exp(-j*k*x2)];
ac = [0; 0];
Refparm.det = abs(det(La));
ac = La\Fb;
Refparm.ai    = abs(ac(1));
Refparm.ar    = abs(ac(2));

% bepaal de faseverschuiving t.o.v. t=0:
tshift   = mod(t0,Refparm.T);
phishift = 360*tshift/Refparm.T;

% bepaal de fase:
phi_i = 360/(2*pi) * angle(ac(1)) + phishift;
phi_r =-360/(2*pi) * angle(ac(2)) - phishift;
Refparm.phi_i = mod(phi_i,360);
Refparm.phi_r = mod(phi_r,360);

% fase tussen -180 en +180:
if Refparm.phi_i > 180
   Refparm.phi_i = Refparm.phi_i - 360;
end   

if Refparm.phi_r > 180
   Refparm.phi_r = Refparm.phi_r - 360;
end   

Refparm.fr    = Refparm.ar/Refparm.ai;

% einde FN_refreg