function [Outparm,error] = FN_refreg7(in_naam, Inparm, Scanparm, Ts, A1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_Refreg7
%   Calculation of reflection coefficient of a regular wave at 
%   velocity 0.
%   version 7: adapted to gereral functions reading inparms
%           and data and writing outparms
%   9-Dec-04
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   version 7: adapted to gereral functions reading inparms
%           and data and writing outparms
%   version 6: zero crossings changed, numbers in plot corrected,
%           available harmonics checked.
%   version 5: setup using handles, not working !!!!!
% all earlier versions are older versions of the new named function
%   FN_refparms (renamed to avoid throing away the function
%   FN_refreg(n), because there is also a FN_refreg(n+1)).
%   version 4: input spectrum with more harmonic components,
%       only first harmonics used
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Programmabeschrijving:
% Het programma gebruikt de gegevens uit een met FN_infile4 ingelezen
% invoerbestand. 
% Het invoerbestand moet 2 kolommen bevatten met meetwaarden van
% 2 golfhoogtemeters op afstaand ~L/4.
% Er mogen evt. meer kolommen in staan (de gebruiker geeft de
% nummers van de te verwerken kolommen op).
%
% input:
%   in_naam:  name of input file
%   Fileinfo: structure of read parameters
%	    nhead:	non-Dasylab file: number of header lines
%   			ignored in case of Dasylab file.
%	    samp1:	first sample to be read, here 1
%	    samp2:	last sample to be read, -1 tot end of file
%	    step:	step size, here 1
%   Inparm: parameters to be typed by user
%       dt:     time step in s (used before: tijdstap)
%       nharm:  number of harmonics to be printed
%       hm:     average water depth in m (used before: diepte)
%               samp1: first sample to be analysed (replaced by
%                       Scanparm.t1)
%               samp2:  last sample to be analysed (replaced by
%                       Scanparm.t2)
%       ncols:  number of chanels to be processed (here:2)
%	    col:	rowvector with column numbers channels
%               (used before: col1 (col one), col2)
%       x:      rowvector with X-coordinates (used before: pos1, pos2)
%       sc:     rowvector with scale factor measurement values to m
%               (used before: sch1, sch2)
%   Scanparm:   structure with time region chosen:
%       t1:     begin time
%       t2:     end time
%       step:   sample step in selection
%       dt:     time step after sampling
%   Ts:      time vector
%   A1:      data matrix 
%
%   Outparm:    Structure with output parameters
%	    Fan:	Fan(i,j) is the i-th harmonics of the j-th chanel to be 
%               analysed, j=1,2
%   	fn:		matrix of frequencies for Fan(i,j)
%       N:      number of datapoints used in harmonic analyses
%		T:		period 1st harmonic
%		L:		wavelength 1st harmonic
%		a:		a-components from Fa
%		b:		b-components from Fa
%		c:		ampl. from Fa
%		det:    abs(determinant) eq. La * Inparm.pos = Fa(1)'
%		ai:     ampl. incident wave 1st harmonic
%		ar:     ampl. reflected wave 1st harmonic
%		fr:     coefficient of reflection 1st harmonic
%		phi_i	phase incident wave 1st harmonic
%		phi_r	phase reflected wave 1st harmonic
%   error:  0: no errors, % 101: sampling too low,
%           201: user pressed 'cancel't, 
%           301: non existing channel
%
% De basisfrequentie van de golf wordt geschat uit de nuldoorgangen
% aan het begin en het eind van de meetreeks met dezelfde 
% tekenwisseling. Hiertoe wordt eerst het gemiddelde afgetrokken.
% Uit de basisfrequentie en de tijdstap wordt een aantal punten
% berekend zodat de basisfreqentie in het met een fft gevonden
% spectrum ligt (d.w.z. N*dt een geheel aantal perioden).
% Met de fft worden vervolgens de gevraagde harmonischen bepaald.
% Vervolgens wordt het aantal punten opgehoogd tot minimaal 20 punten
% per periode m.b.v. Matlabfunctie resamp, waarna opnieuw een FFT 
% wordt uitgevoerd. 
% Uit amplitudes en fases van de basisfrequentie kan de verhouding 
% tussen invallende en teruggekaatste golf worden berekend.
% zie o.a. Goda, Y., Random Seas and Design of Maritime Structures,
% Univ. of Tokyo Press, 1985, pp. 299-301 (incl. regelmatige golf).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Fan     = [];
fn      = [];
N       = 0;
Outparm.fr = 0;
error   = 0;

%%%% calculate the spectrum of the 2 wave heigths measured: 
[Fan,fn,N,error] = FN_harmo14(in_naam,A1,Inparm,Scanparm); 
                    % voorheen: FN_harmo13

if error<200
    Fa  = Fan(1,:);
    f   = mean(fn(1,:)');
                  
 	% calculate the reflection coefficient of the first harmonic:
    % nakijken: Fileinfo, Scanparm of Ts nodig?
    t0 = Ts(1);     % time at begin of measurements
    [Outparm]=FN_refparm5(t0,Fa,f,Inparm);  % voorheen: FN_refreg2  
end    

Outparm.Fan = Fan;
Outparm.fn  = fn;
Outparm.N   = N;
            
% END FN_refreg7
