function [Scanparm,Ts,A1,error] = FN_selectR1(A,Fileinfo,Inparm,show)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_selectR1
%   Select desired part from a matrix containig time registrations
%   version 1
%   19-Jan-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
%   A:          te reduceren matrix
%   Fileinfo:   structure met bestandsgegevens
%	    nhead:	voor niet dasylabbestanden: aantal headerregels
%   			wordt bij dasylabbestanden genegeerd.
%	    nsamp1:	eerste in te lezen punt
%	    nsamp2:	laatste in te lezen punt, -1 tot einde file
%	    step:	stapgrootte (hier: 1)
%
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in meetdata (niet: in bemonsterde data)
%       samp1:  eerste te verwerken punt meetreeks
%       samp2:  laatste te verwerken punt meetreeks (-1 tot einde)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde
%
%   show:       resultaat laten zien: 1: ja, 0: nee
%     opm (6-1-05): show=0 werd gebruikt om bij een plot als uitvoer
%           van de script het resultaat van de selectie niet te tonen
%           (v.b. Bekijkb). Dit bleek verwarrend; beter altijd show=1.
%
% uitvoer:
%   Scanparm:   structure gegevens over met gekozen samples:
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%   Ts:         kolomvector met tijden; wordt gehaald uit tijden in bestand 
%               of uit (samplenummer-1)*tijdstap in bestand
%   A1:         het gekozen deel van A
%	error:	    0: doorgaan, 101: stoppen, 
%               303: geen samples gekozen, tijdstippen buiten bereik
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Geef parameters een beginwaarde:
start   = 0;
error   = 0;

[f_nsamp,f_nchan]   = size(A);
Scanparm.tin1   = Inparm.samp1*Inparm.dt;
if Inparm.samp2>0
    Scanparm.tin2 = Inparm.samp2*Inparm.dt;
else
    Scanparm.tin2 = f_nsamp*Inparm.dt;
end    
Scanparm.step   = 1;
Scanparm.dt     = Inparm.dt;

A1      = A;
f_samp1 = Fileinfo.samp1;
f_samp2 = Fileinfo.samp2;
f_step  = Fileinfo.step;

ncols     = length(Inparm.col);
if f_samp2<0
    f_samp2 = f_samp1 + f_step*(f_nsamp-1);
end

% maak tijdvector en samplegebied:
Num = f_samp1:f_step:f_samp2;
Num = Num';
e       = ones(length(Num),1);
if Inparm.colt==0
    Ts   = Inparm.dt.* (Num-e);
else
    Ts       = A1(:,1);
    A1(:,1) = [];
end    

% te selecteren kolommen uit A, inclusief de tijd:
Cols = Inparm.col;

% plot de data:
%h1  = figure(1);    % verplaatst op 23-12-03
%subplot(2,1,1);
%tekst = sprintf('channel %d',Inparm.col(1));
%plot(Ts,A(:,Inparm.col(1)));
%title(tekst);
%if ncols>1
%    subplot(2,1,2);
%    tekst = sprintf('channel %d',Inparm.col(ncols));
%    plot(Ts,A(:,Inparm.col(ncols)));
%    title(tekst);
%    xlabel('time (s)');
%end    

% selecteer het in Inparm (en Scanparm) opgegeven gebied;
s_samp1 = Inparm.samp1;    
if Inparm.samp2>0
    s_samp2 = Inparm.samp2;    
else
    s_samp2 = f_nsamp;
end    
s_step = 1;
if s_samp1<s_samp2
    % maak nieuwe matrix met geselecteerde rijen en kolommen van A,
    % en van de tijd Ts
    % monsternummers te kiezen uit matrix A:
    Samps       = [s_samp1 s_samp2 s_step];   % f_step al genomen in A
    A1          = FN_red(A,Samps,Cols);
    ColsTs(1)   = 1;
    Ts1         = FN_red(Ts,Samps,ColsTs);
    Num1        = FN_red(Num,Samps,ColsTs); % toegevoegd voor plot,
                                            % hkl, 19-1-05
    clear Ts;
    Ts = Ts1;
        
    
    [s_nsamp,s_nchan] = size(A1);
        
    % laat resultaat zien:
    if show==1
        figure(1);     % toegevoegd, 23-12-03
        subplot(2,1,1);
        tekst = sprintf('channel %d',Inparm.col(1));
        %plot(Ts,A1(:,1));
        plot(Num1,A1(:,1));
        title(tekst);
        if ncols>1
            subplot(2,1,2);
            tekst = sprintf('channel %d',Inparm.col(ncols));
            %plot(Ts,A1(:,s_nchan));
            plot(Num1,A1(:,s_nchan));
            title(tekst);
            % xlabel('time (s)');
        end    
    end    
 %   uiwait(h1);     % h1 is uitgezet, zie boven
    
% geen monsternummers binnen gevraagd tijdinterval:
else
    error=304;
end    

% zet uiteindelijk gekozen tijden in Scanparm (Ts heeft altijd een waarde):
Scanparm.tuit1 = Ts(1);
Scanparm.tuit2 = Ts(length(Ts));

% Einde FN_selectR1