function FN_seq5(Inparm,Scanparm,nsamp,nchan,dosnaam);
%function FN_seq5(Inparm,Scannums,nsamp,nchan,dosnaam);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_seq5
%   makes a .seq-file to be used by Auke/pc
%   version 5: input parameters adapted to new setup
%   14-Nov-04
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 4: wegschrijven met DOS-naam (vergeten in 2 en 3)
%   versie 3: nsamp en nchan uit FN_bin3 als invoerparameter
%   versie 2: schalen per kanaal
%
% invoer:
%	Inparm:	structure met invoerparameters
%	    dt	    tijdstap van de metingen
%	    hm	    waterdiepte in m
%	    ncol	aantal te verwerken kolommen
%	    col:	vector met kolomnummers 
%	    xp:	    vector met x-coordinaten in m
%	    sc	    schaalfactor van de meetwaarden naar meters
%
%   Scanparm:   structure gegevens over met gekozen samples:
%       tin1:   gevraagde begintijd 
%       tin2:   gevraagde eindtijd
%       step:   gevraagde monsterstap bij selectie
%       tuit1:  begintijd na bemonsteren
%       tuit2:  eindtijd na bemonsteren
%       dt:     tijdstap na bemonsteren
%   gebruikt: alleen dt 
%
%	nsamp:  aantal weggeschreven rijen in het binaire gegevensbestand
%	nchan:  aantal weggeschreven kolommen in het binaire gegevensbestand
% 	dosnaam:dosnaam voor het uitvoerbestand
%				H. Klaasman

FID = fopen(dosnaam,'w');

%[nsamp,nchan] = size(A);
ncol = length(Inparm.col);

% gegevens over dataopslag:
fprintf(FID,'STO\r\n');
fprintf(FID,'DATATYPE,R4\r\n');
fprintf(FID,'ACCESS,DIRECT\r\n');
fprintf(FID,'FILEFORMAT,BINARY\r\n');
recl = 4*ncol;
fprintf(FID,'RECL,%d\r\n',recl);
fprintf(FID,'END:STO\r\n');

% blok GENERAL:
fprintf(FID,'GENERAL\r\n');
fprintf(FID,'SCALE,1.0\r\n');
d1 = datestr(now);
% fprintf(FID,'CREATION,DATE,%s\r\n',d1);
fprintf(FID,'SCAN,RELATIONAL,HOLES\r\n');
% dt = Scannums.dt; % bij FN_selectnw
dt = Scanparm.dt;
high    = (nsamp-1)*dt;
fprintf(FID,'EQ,SERIES,LOW=0.0,HIGH=%g,STEP=%g,NAME=NUMBER,TYPE=TIME\r\n',high,dt);
fprintf(FID,'END:GENERAL\r\n');

% SERIES-blokken per kanaal:
for i=1:ncol
    fprintf(FID,'SERIES,COL%02d\r\n',i);
    fprintf(FID,'dimension,m\r\n');
    fprintf(FID,'calibration,C2=0.0,C1=%g,c3=0.0\r\n',Inparm.sc(i));
    fprintf(FID,'x,%g,m\r\n',Inparm.xp(i));
    fprintf(FID,'END:SERIES\r\n');
end    

fclose(FID);

% einde FN_seq5