function [f,a,b,c] = FN_spect4(Inparm,Scanparm,A)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_spect4
%   calculate a spectrum of a row vector.
%   version 4, adapted to general functions, A 2D
%   24-Jan-05
%
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input:
%   A:      matrix containing input data
%   Inparm: parameters asked by user
%       dt:     time step in measurements s (used before: tijdstap)
%       thresh     threshold: part of spectrum lower than thresh*cmax
%                       will not be printed or plotted
%       ncols:  number of chanels to be processed (here:2)
%	    col:	rowvector with column numbers channels
%               (used before: col1 (col one), col2)
%       unit:   vector of char.strings containing units of the mearured value
%       sc:     rowvector with scale factor measurement values to m
%               (used before: sch1, sch2)
%   Scanparm:   structure with information about samples asked by user:
%       t1:     begin time asked (begin time used: Ts(1))
%       t2:     end time asked (end time used: Ts(length(Ts)))
%       step:   sample step with respect to the measurements
%       dt:     time step in the sampled data (vector Ts)
%
% output:
%   f:  frequency vector%
%   a:  matrix of real components
%   b:  matrix of imaginary components
%   c:  matrix of amplitudes
%				        H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% aftrek gemiddelde om de periode te kunnen bepalen:
% bij verdere ontwikkeling van FN_harmo:
% gebruik bij ruis een symmetrisch laagdoorlaatfilter (testen)
[nsamp,nchan] = size(A);
amean   = mean(A);
e		= ones(nsamp,1);
A2		= A - e*amean;

% schalen naar gevraagde eenheid:
schaal  = e*Inparm.sc;  % nsamp rijen * nchan kolommen
A2      = schaal.*A2;

% bepaal nuldoorgangen
[i1,i2] = SFN_zeros3(A2);   % SFN_zeros vervangen door SFN_zeros3, Hkl, 
                            % 24-1-05

% A2(i1) en A2(i2) hebben een verschillend teken,
% A2(i2+1) heeft het teken van A2(i1)
N    = i2 - i1 +1;

% bepaal FFT:
y       = fft(A2,N);
N1      = ceil(N/2);
Fs      = 1/(N*Scanparm.dt);
f       = (0:N1-1) * Fs;
a       = 2/N*real(y(1:N1,:));
b       = 2/N*imag(y(1:N1,:));
c       = 2/N*abs(y(1:N1,:));

% einde FN_spect4