%function [T0,eps1]=FN_wavvars(f,E,m);
function [T0,eps1,kappa,gamma]=FN_wavvars3(f,E,m,fmin_s,fmax_s);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_wavvars
%   Calculates statistical variables from variance spectrum and moments
%   version 3: range where E<=thresh, f, E, m: vectors
%   21-Oct-03, changed 26-May-05, eps->eps1
%
%
%
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 3: met grenzen waarbinnen E<=drempel, vectorvorm
%   versie 2, in- en uitvoer in matrixvorm, E(i,j) is 
%             spectrale component i bij kanaal j.
%   werkt niet !!!
%   versie 1: in vectorvorm zonder drempel
%
% invoer:
%   f:  vector met frequenties
%   E:  vector met variantiespectrum voor f=df:df:length(A)*df
%   m:  vector met momenten 0,1,2 en 4 van E.
%   fmin_s-fmax_s: gebied waarbinnen E >= een opgegeven drempel * max(E)
%
% uitvoer:
%   Auke/pc, process document, p.4-6:
%   T0:     T01 = m0/m1, T02 = (m0/m2)^0.5, T24 = (m2/m4)^0.5
%   eps1(1): Narrowness eps2 = (m0m2/m1^2 - 1)^0.5
%   eps1(2): Broadness  eps4 = (1 - m2^2/m0m4)^0.5
%   kappa:  DELFTAuke Process Document, p.4-6:
%           kappa(tau) = m0^2*kappa^2(tau) = 
%           (df*sum(E(f)*cos2pi(f-fm))^2 +(df*sum(E(f)*sin2pi(f-fm)))^2, 
%           fm=1/taum, taum=alfa*tau, alfa=1,2,3,...
%           tau willekeurig, hier: tau=T0(2).
% alternatief (Auke/pc, p.4-7)
%   kappa:  volgt uit m0^2*kappa^2(tau) = 
%           (df*sum(E(f)*cos2pi(f*tau))^2 +(df*sum(E(f)*sin2pi(f*tau)))^2, 
%           tau willekeurig, hier: tau=T0(2).
%   gamma:  vergelijking (4.14) uit DELFTAuke Process Document p.4-7

% Kappa en gamma: voorlopig niet gevonden

% Afgeleide parameters uit momenten:
T0(1)   = m(1)/m(2);
T0(2)   = (m(1)/m(3))^0.5;
T0(3)   = (m(3)/m(4))^0.5;
eps1(1) = (m(1)*m(3)/m(2)^2 - 1) .^0.5;
eps1(2) = (1 - m(3)^2/(m(1)*m(4)) ) .^0.5;
T0      = T0';
eps1    = eps1';

% Dit gedeelte van FN_wavvars kan ook buiten de pp-lus,
% maar gamma en kappa gebruiken E_temp en moeten erbinnen.

    % Momenten uit spectra en afgeleide parameters:
    % m       = Outparm.m;
    % [nm,ng] = size(m);
    % een     = ones(1,ng);
    %T01     = m(1,:) ./ m(2,:);
    %T02     = (m(1,:) ./ m(3,:)) .^0.5;
    %T24     = (m(3,:) ./ m(4,:)) .^0.5;
    %eps2    = ( m(1,:) .* m(3,:) ./ (m(2,:).^2) - een ) .^0.5;
    %eps4    = (een - m(3,:).^2 ./ (m(1,:) .* m(4,:)) ) .^0.5;

% bepaal gebied f:
df          = f(2)-f(1);
ithresh(1)   = ceil(fmin_s/df);   % f = i*df, i=1,2,...
ithresh(2)   = floor(fmax_s/df);
%fminwavvars3 = f(ithresh(1))
%fmaxwavvars3 = f(ithresh(2))
ft= f(ithresh(1):ithresh(2));
Et= E(ithresh(1):ithresh(2));

% kappa:
kappa = SFN_kappa(ft,Et,m(1),T0(2));

% gamma:
kappa1  = SFN_kappa(ft,Et,m(1),0.5*T0(2));
kappa2  = SFN_kappa(ft,Et,m(1),1.5*T0(2));
rho     = SFN_rho(kappa);
rho1    = SFN_rho(kappa1);
rho2    = SFN_rho(kappa2);
gamma   = (rho1 + 2*rho + rho2)/(2+2*rho1);

% einde FN_wavvars

function kappa_tau = SFN_kappa(f,E,m0,tau);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bepaalt correlatie kappa_tau uit variantiespectrum E met nulde 
% moment m0 bij frequenties f over verschuiving tau.
%   kappa_tau:  volgt uit m0^2*kappa^2(tau) = 
%           (df*sum(E(f)*cos2pi(f*tau))^2 +(df*sum(E(f)*sin2pi(f*tau)))^2, 
%           tau willekeurig
df      = f(2) - f(1);
f1      = tau .* f;
w1      = 2*pi*f1;
k1      = E .* cos(w1); 
k2      = E .* sin(w1);
%I1      = trapz(f,k1);
%I2      = trapz(f,k2);
% term voor f=0 ontbreekt; trapeziumregel wordt sum.
I1      = df*sum(k1);
I2      = df*sum(k2);
kappa2  = I1^2 + I2^2;
kappa_tau = (kappa2/(m0^2))^0.5;

% einde SFN_kappa

function rho = SFN_rho(kappa_t);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% lineaire correlatiecoefficient rhoHH, zie DELFTAuke Process Document p.
% 4.7
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rho = pi/(16-4*pi) * (kappa_t^2 + kappa_t^4/16 + kappa_t^6/64);