function[head, A, fout, warn] = FN_indata7(infile,Fileinfo)
% function[head, A, fout, warn] = FN_indata7(FID1,infile,Fileinfo)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_indata7 
%   reads header and data from an ASCII file, using parameters
%   from Fileinfo
%   Version 7: read blocks in subfuncties, maximum number of 
%       points specified (samples * number of channels)
%	14-May-02, adapted Matlab 7, 9-Mar-05 and 12-Apr-05
%               H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dit is een combinatie van FN_indata3 en FN_indata5:
% de header en de eerste lijn worden vanuit een subfunctie
% ingelezen, de rest direct vanuit de functie.
% Er wordt gelezen tot maximaal 500000 punten (samp*chan),
% daarna advies geven voor opsplitsen.
% Let op: in tegenstelling tot FN_indata3 is bij FN_indata5
% en FN_indata6 altijd een hulpbestand nodig, omdat
% ook bij lezen tot einde file moet worden getest op het maximum.
% FN_indata6 leest header en data uit een ascii-bestand
% met in Fileinfo opgegeven parameters voor stapgrootte.
% Toegestane delimiters: tab, spatie, komma of ';'.
% Versie 7: het maximum wordt afhankelijk van het aantal kanalen
% Versie 6: zelfde als versie 5, maar blokken binnen subfunctie
% Versie 5: lezen in subfuncties tot gespecificeerd maximum,
%           zonder middelen.
% Versie 4: leesblokken in subfuncties; middelen toegevoegd
% Versie 3: met stapgrootte
% Versie 2: controleert bestandstype
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	infile:		naam invoerbestand
%	Fileinfo:	structure met bestandsgegevens
%	nhead:	voor niet dasylabbestanden: aantal headerregels
%			wordt bij dasylabbestanden genegeerd.
%	samp1:	eerste in te lezen punt
%	samp2:	laatste in te lezen punt, -1 tot einde file
%	step:	stapgrootte
%
% Uitvoer:
%	head:		cellarray met header
%	A:			array met meetdata
%	fout:   	0: geen fouten, 1: fout in openen of lezen bestand
%	warn:   	0: geen fouten, 1: meer dan 100000 punten
%
% Methode:
%	Na het inlezen van de header wordt het scheidigsteken bepaald.
%	M.b.v. het scheidingsteken wordt ingelezen. 
%	Omdat voor het inlezen van een bestand met load de tab wel goed
%	werkt maar de ';' niet en omdat dlmread niet goed werkt wordt
%   de ';' overal vervangen door '	' (=tab).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% beginwaarde uitvoerparameters:
fout	= 0;
warn    = 0;
nhead 	= Fileinfo.nhead;
samp1 	= Fileinfo.samp1;
samp2 	= Fileinfo.samp2;
step	= Fileinfo.step;
%head={[' ',' ']};
head={};
A=[];	% nodig omdat het anders bij niet-dasylabbestanden 
		% fout gaat

%%%% open invoerfile:
FID=fopen(infile,'r');
if (FID<0)
    fout = 1;
    h=errordlg('invoerbestand niet gevonden','FN_indata');
    uiwait(h);
else
    % lees header en eerste dataregel:
    [head,lijn] = SFN_headr(FID,nhead);

    % analyseer eerste dataregel:
    [sep,nchan,fout] = SFN_data(lijn);
%   fprintf(FID1,'\r\neerste dataregel:\r\n%s\r\n',lijn);
%   fprintf(FID1,'\r\nscheidingsteken: %d\r\n',sep);
%   fprintf(FID1,'\r\naantal gevonden kanalen: %d\r\n',nchan);

    % er zijn meetdata:
    if fout==0
    
    
        % hulpvariabelen controle aantal ingelezen samples:
        maxnum  = 500000;
%       maxnum  = 3000;
%       maxnum  = 100;
        maxsamp = round(maxnum/nchan);
%       fprintf(FID1,'\r\nmaxsamp: %d\r\n',maxsamp);
        nsamp   = 0;    % aantal naar hulpbestand geschreven samples

        % testvariabele die aangeeft of samp2 al is ingelezen
        % en of eof is bereikt
        endf    = 0;
        last    = 1;   % nummer laatst ingelezen monsterpunt

                
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Opm.: in deze inleesfunctie wordt de test op het scheidingsteken buiten
        % de subfuncties uitgevoerd. Dit maakt het programma minder overzichtelijk
        % omdat voor de twee gevallen aparte subfuncties nodig zijn,
        % maar het aantal tests binnen een lus wordt hierdoor aanzienlijk kleiner.
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        % standaarscheidingsteken:
        if sep==1
                
            % bepaal inhoud van regelnr samp1 in invoerfile:
%           fprintf(FID1,'\r\nSFN_first11 wordt aangeroepen\r\n');
            lijn1 = SFN_first11(FID,samp1,samp2,lijn);
%           lijn1 = SFN_first11(FID1,FID,samp1,samp2,lijn);
%           fprintf(FID1,'lijn1 = %s\r\n', lijn1);
                    
            % lees gevraagde samples in matrix A:
            [A,warn] = SFN_next11(FID,samp1,samp2,maxsamp,step,lijn1);
            
        % geen standaardscheidingsteken:
        else

           % bepaal inhoud van regelnr samp1 in invoerfile:
%          fprintf(FID1,'\r\nSFN_first10 wordt aangeroepen\r\n');
           lijn1 = SFN_first10(FID,samp1,samp2,lijn);
%          fprintf(FID1,'lijn1 = %d\r\n', lijn1);
                       
           % lees verder:
           [A,warn] = SFN_next10(FID,samp1,samp2,maxsamp,step,lijn1);
       end    
   
       if warn==1
           SFN_warn(maxnum, maxsamp);
       end    
           
   end  % eerste dataregel bevat geen fouten

   % sluit invoerbestand:
   fclose(FID);
      
end  %invoerbestand gevonden

% einde FN_indata6

function [head,lijn] = SFN_headr(FID,nhead)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_headr leest de header uit een ASCII-bestand met id. FID
%                                               H. Klaasman
%                                               9 mrt 05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% FID:      id. invoerbestand
% nhead:    aantal headerregels (0 voor dasylabbestand, einde header wordt
%           automatisch bepaald.
%
% uitvoer:
% head:     cell array met header
% lijn:     character string met de laatst ingelezen regel (meestal de eerste
%           dataregel)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%head={[' ',' ']};
head={};
lijn = '';

%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
% open testbestand:
%FID10=fopen('test','w');
%d = datestr(now);
%fprintf(FID10, ...
%'Test: FN_indata7 in Matlab7, isletter -> isstrprop(..,''alpha'')\r\n');
%fprintf(FID10,'%s\r\n\r\n',d);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% lees eerste regel:
lijn=fgets(FID);

%%%%%%%%%%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%%%%%%
% fprintf(FID10,'%s\r\n',lijn);
% fprintf(FID10,'Aantal opgegeven headerregels %d\r\n',nhead);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ga na of er een dasylabheader is:
dasy = 0;
if length(lijn)>3
    if lijn(1:4) == 'DASY'
        dasy=1;
    end
end    

% Dasylabbestand met header:
if dasy==1
    %%%%lees header en zoek eerste dataregel:
	%fprintf(FID10,'headerregel\r\n');
    head{1} = char(lijn);
	verder=1;
    i=2;
	while(verder==1) & feof(FID)==0
        lijn=fgets(FID);
        s1=findstr(lijn,';');
	    s2=findstr(lijn,'	');

%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
%        fprintf(FID10,'%s\r\n',lijn);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
    
   	    %%%% headerregel
        if length(s1)==0 & length(s2)==0 
       	% omdat bij een dasylabbestand met header en zonder meetdata
       	% eof als extra headerregel wordt beschouwd wordt eof hier
       	% apart uitgesloten. Als dit gecombineerd wordt met de test
       	% hierboven wordt de eof tot de meetdata gerekend!!
            if feof(FID)==0
   			    head{i}=char(lijn);
          	    i=i+1;
                
%%%%%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%%%
%                fprintf(FID10,'headerregel\r\n');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
       		end
	    	
        %%%% kop boven data of dataregel      
        % dit stukje is aangepast op 9-3-05
        % isletter -> isstrprop(...,'alpha') omdat isletter verdwijnt
        % test op sum(c) i.p.v. c(1), omdat een tekstregel met een nummer
        % kan beginnen; werkt niet, terug naar c(1)
        % zet in eigen testbestanden voor de datum altijd "date"
        %
        else
            V = version;
            v1=str2num(V(1:1));
            % Matlab v.<7
            if v1<6.9
                c=isletter(lijn);   % Matlab v.<7
            % Matlab v.>=7
            else
           	    c=isstrprop(lijn,'alpha');  % Matlab 7
            end    

%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
%           fprintf(FID10,'version: %s\r\n',V);
%           fprintf(FID10,'c=');
%           fprintf(FID10,'%d',c);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%            

            %%%% kop boven data
            if c(1)==1
            % if sum(c)==0
                head{i}=char(lijn);
      		    i=i+1;

            %%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
            %   fprintf(FID10,'\r\nheaderregel\r\n');
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
   			
            %%%% data                     
            else 
       		    verder=0;
                
            %%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
            %   fprintf(FID10,'\r\ndataregel\r\n');
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
            
   			end               
        end
            
    end % lus header inlezen
    % nhead = i-1;  % voor testuitvoer
        
%%%% geen dasylabbestand of dasylabbestand zonder header:
else
    if nhead>0
        for i=1:nhead
            
            %%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
            %   fprintf(FID10,'\r\nheaderregel\r\n');
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
   			
            head{i}=char(lijn); % eerste regel was al ingelezen
	  	    lijn=fgets(FID);
            
            %%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
            % fprintf(FID10,'%s\r\n',lijn);
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
   			
        end

        %%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%
        % fprintf(FID10,'dataregel\r\n');
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
        
    end    
end
 
%%%%%%%%%%%%%%%%%%%%% TESTUITVOER %%%%%%%%%%%%%%%%%%%%%%%%%
%   fprintf(FID1,'\r\n%d headerregels gelezen\r\n',nhead);
%   fclose(FID10);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
% einde SFN_headr

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [sep,nchan,fout] = SFN_data(lijn)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_data gaat na of de laatst ingelezen regel van een bestand meetdata
% bevat. Vervolgens wordt nagegaan of het scheidingsteken een ';' is of niet.
% In dat laatste geval wordt een scheidingsteken verondersteld dat standaard is
% voor Matlab (tab, spatie of komma).
% Vanaf FN_indata7 wordt ook het aantal kanalen bepaald, omdat het maximaal
% aantal in te lezen samples af moet hangen van het aantal kanalen.
%                                               H. Klaasman
%                                               14 mei 02
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% lijn:     character string met de laatst ingelezen regel (meestal de eerste
%           dataregel)
%
% uitvoer:
% sep:      aanduiding scheidingsteken: 0 voor ';', 1 voor alle andere
% nchan:    aantal kanalen
% fout:     geen dataregel
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
fout    = 0;    % als het goed is heeft fout die waarde al bij binnengaan
                % van SFN_data
sep     = 0;            
nchan   = 0;

% eerste regel mag geen letters bevatten en mag niet leeg zijn 
% (leeg is alleen <cr> en <lf>):
c = isletter(lijn);
%l = length(lijn)
if c(1)==0 & length(lijn)>2
	     
    %%%% zoek scheidingsteken en bepaal het aantal kanalen:
	chan1       = findstr(lijn,';');
    numchan(1)  = length(chan1);
    chan2       = findstr(lijn,'	');
    numchan(2)  = length(chan2);
	chan3       = findstr(lijn,',');
    numchan(3)  = length(chan3);
    chan4       = findstr(lijn,' ');
    numchan(4)  = length(chan4);

    % er kunnen meer spaties als scheidingsteken dienen;
    % zoek de eerstvolgende niet-spatie:
    if numchan(4)>0
        nchan4  = 0;    
        for i=1:numchan(4)
            char = lijn(chan4(i)+1);
            if char~=' '
                nchan4 = nchan4+1;
            end
        end    
    else
        nchan4=0;
    end
    
    %nsp             = numchan(4)/nchan4        % aantal spaties tussen kanalen
    numchan(4)      = nchan4;

    % aantal kanalen en index scheidingsteken in numchan:
    [nchan,sepch]   = max(numchan);
    
    % als het laatste kanaal van elke sample niet wordt afgesloten door een scheidingsteken
    % moet er nog 1 kanaal bij (werkt niet bij een spatie als scheidingsteken):
    if sepch<4
        % plaats van laatste scheidingsteken
        eval(['lsp = chan',num2str(sepch),'(nchan);']);
        % plaats laatste teken = lentgh(lijn)-2 ivm lf en cr in lijn:
        lch = length(lijn)-2;
        if lch>lsp
            nchan = nchan+1;
        end
    end     
                    
	%%%% een ';' als scheidigsteken kan problemen geven. Er wordt voorlopig van
    %%%% uitgegaan dat alle andere scheidingstekens (tab, spatie, komma) het goed doen.
     if length(chan1)>0
 	    sep=0;
     else
 	    sep=1;
     end
      
% eerste regel geen dataregel: 
else
     fout=1;
     h = msgbox('wrong number of header lines in a non-Dasylab file','FN_indata7');
	 uiwait(h);
end     
       
% einde SFN_data

function lijn1 = SFN_first11(FID,samp1,samp2,lijn);                    
%function lijn1 = SFN_first11(FID1,FID,samp1,samp2,lijn);                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_first11 zoekt dataregel met volgnummer samp1 uit een ASCII-bestand met id. 
% FID en leest deze in als samp1>1. Er wordt verondersteld dat de eerste data-
% regel van FID al is ingelezen. 
%                                               H. Klaasman
%                                               10 apr 02
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% FID:      id. invoerbestand
% samp1:    nummer te zoeken regel
% samp2:    nummer laatst in te lezen regel
% lijn:     laatst uit FID ingelezen regel
%
% uitvoer:
% lijn1:    character string met de regel met volgnummer samp1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% de waarde die endf bij aanroep had wordt aangehouden
i=1;
lijn1 = '';
if samp1==1
	lijn1=lijn;
else    
    % bepaal beginpunt:
    while feof(FID)==0 & i<samp1-1
    	fgets(FID);
        i = i+1;
    end
end
if i==samp1-1
	lijn1 = fgets(FID);
    i = i+1; 
end
%fprintf(FID1,'laatst ingelezen sample %d\r\n',i);

% einde SFN_first11

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function lijn1 = SFN_first10(FID,samp1,samp2,lijn);                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_first11 zoekt dataregel met volgnummer samp1 uit een ASCII-bestand met id. 
% FID en leest deze in als samp1>1. Er wordt verondersteld dat de eerste data-
% regel van FID al is ingelezen. Een ';' als scheidingsteken wordt vervangen
% door een tab. 
%                                               H. Klaasman
%                                               10 apr 02
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% FID:      id. invoerbestand
% samp1:    nummer te zoeken regel
% samp2:    nummer laatst in te lezen regel
% lijn:     laatst uit FID ingelezen regel
%
% uitvoer:
% lijn1:    character string met de regel met volgnummer samp1, waarbij ';'
%           is vervangen door tab
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

i=1;
lijn1 = '';
if samp1==1
	lijn1=strrep(lijn,';',' ');
else    
    % bepaal beginpunt:
    while feof(FID)==0 & i<samp1-1
    	fgets(FID);
        i = i+1;
    end
end
if i==samp1-1
	lijn = fgets(FID);
	lijn1=strrep(lijn,';',' ');
    i = i+1; 
end

% einde SFN_first10

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [A,warn] = SFN_next11(FID,samp1,samp2,maxsamp,step,lijn1);                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_next11 leest gevraagde dataregels vanaf samp1+1 uit een ASCII-bestand met id. FID. 
% Deze worden weggeschreven in een hulbestand en vervolgens ingelezen in matrix A.
%                                               H. Klaasman
%                                               10 apr 02
% aanpassing feof: ingelezen lijn=-1: 12-4-05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% FID:      fileid. invoerbestand
% samp1:    nummer laatst ingelezen dataregel (er wordt verondersteld dat dit de
%           eerste in te lezen regel is).
% samp2:    nummer laatst in te lezen dataregel
% maxsamp:  bovengrens in te lezen samples 
% step:     stapgrootte
% lijn1:    laatst ingelezen regel
%
% uitvoer:
% A:    matrix met ingelezen samples
% warn: 0: alle punten ingelezen, 1: bovengrens maxsamp bereikt 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% open hulpbestand en schrijf eerste regel weg:
FID2 = fopen('hulp','w');
fprintf(FID2,'%s',lijn1);
nsamp = 1;
%V = version;
%v1=str2num(V(1:1));

warn = 0;
%%%% maximaal aantal te lezen samples:
samp3 = samp1 + step*(maxsamp-1);
if samp2>0
    samp3 = min(samp2,maxsamp);
end    

i = samp1;
%%%% lezen tot einde file of bovengrens:
while feof(FID)==0 & i<samp3
    if step>1
        for j=2:step
            fgets(FID);
        end
    end
    i = i+step-1;
    if feof(FID)==0 & i<samp3
        lijn = fgets(FID);
        if lijn~=-1
             fprintf(FID2,'%s',lijn);
    %       fprintf(FID1,'%s',lijn);
            i       = i+1;
            nsamp   = nsamp+1;
    %       printf(FID1,'laatst ingelezen punt: %d\r\n',i);
        end  
    end    
end

%fprintf('laatst ingelezen punt: %s\r\n',lijn);

if nsamp>=maxsamp
    warn    = 1;
end    

% sluit hulpbestand, lees A en ruim hulpbestand op:
fclose(FID2);
A = load('hulp');
delete('hulp');

% einde SFN_next11

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [A,warn] = SFN_next10(FID,samp1,samp2,maxsamp,step,lijn1);                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_next10 leest gevraagde dataregels vanaf samp1+1 uit een ASCII-bestand met id. FID. 
% De ;'s worden vervangen door tabs.
% De dataregels worden weggeschreven in een hulbestand en vervolgens ingelezen in matrix A.
%                                               H. Klaasman
%                                               10 apr 02
%   aangepast aan feof, 12-4-05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% invoer:
% FID:      fileid. invoerbestand
% samp1:    nummer laatst ingelezen dataregel (er wordt verondersteld dat dit de
%           eerste in te lezen regel is).
% samp2:    nummer laatst in te lezen dataregel
% maxsamp:  bovengrens in te lezen samples 
% step:     stapgrootte
% lijn1:    laats ingelezen sample
%
% uitvoer:
% A:    matrix met ingelezen samples
% warn: 0: alle punten ingelezen, 1: bovengrens maxsamp bereikt 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% open hulpbestand en schrijf eerste regel weg:
FID2 = fopen('hulp','w');
fprintf(FID2,'%s',lijn1);
nsamp = 1;
%V = version;
%v1=str2num(V(1:1));
        
warn = 0;

%%%% maximaal aantal te lezen samples:
samp3 = samp1 + step*(maxsamp-1);
if samp2>0
    samp3 = min(samp2,maxsamp);
end    

i = samp1;
%%%% lezen tot einde file of bovengrens:
while feof(FID)==0 & i<samp3
    if step>1
        for j=2:step
            fgets(FID);
        end
    end
    i = i+step-1;
    if feof(FID)==0 & i<samp3  
        lijn2   = fgets(FID);
        if lijn2~=-1
            lijn    =strrep(lijn2,';','	');
            fprintf(FID2,'%s',lijn);
    %       fprintf(FID1,'%s',lijn);
            i       = i+1;
            nsamp   = nsamp+1;
        end    
    %               fprintf(FID1,'laatst ingelezen punt: %d\r\n',i);
    end   
end
%fprintf('laatst ingelezen punt: %s\r\n',lijn);

if nsamp>=maxsamp
    warn    = 1;
end    

% sluit hulpbestand, lees A en ruim hulpbestand op:
fclose(FID2);
A = load('hulp');
delete('hulp');

% einde SFN_next10

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function SFN_warn(maxnum,maxsamp);                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SFN_warn geeft een waarschuwing dat het maximale aantal punten is bereikt.
% Ook wordt het bebehorende aantal samples afgedrukt.
%                                               H. Klaasman
%                                               10 apr 02
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

regel1  = sprintf('More than %d datapoints (%d samples) found\n',maxnum, maxsamp);
regel2  = sprintf('Choose a higher step or start a new session at sample point %d\n',maxsamp+1);
tekst   = [regel1 regel2];
h       = msgbox(tekst);
uiwait(h);

% einde SFN_warn