function K = phase_int(x_g,f,x_h,h)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function K = phase_int(x_g,f,x_h,h)
% this scipts numerically integrates the wave number which results in 
% the phase for a wave gauge
%
% author: Henk Jan Bakkenes
% 6 February 2002, TU Delft
% changes: Tuan Thieu Quang, 3-6-04
%       Hetty Klaasman, 1-2-05 waitbar
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Output:
%		K : complex factor representing phase and amplitude changes for gauges at x_g [-]
%           phase and amplitude relative to x_g(1) !!
%				results per wave gauge in column of K
%
% Input:
%		x_g  : wave gauge locations [m]
%		f	 : frequency vector, only frequencies of interest [Hz]
%		x_h  : locations for known water depths [m]
%		h	 : water depth at locations x_h [m]
% 
% NOTE: positive direction is propagation direction of incoming waves 
%
% Function uses Simpson method, for methods see e.g. CALCULUS

g = 9.81; %[m/s2]
% toegevoegd, Hkl 3-10-02; f en x_g verwisseld, 13-8-03 (stonden verkeerd,
% waardoor size(K)=[lentgh(f) lenth(f)] werd).
K = zeros(length(f),length(x_g));

% ==================== CALCULATION PHASE ==================================
% =========================================================================
% ==================== Method SIMPSON =====================================
% 
% SIMPSON's rule is equivalent to Runge Kutta 4 when dc/dx is independent of c
% c_n+1 = c_n + (1/6*f_n + 4/6*f_n+1/2 + 1/6*f_n+1) * dx

x_h_orig = x_h;%original water depth profile

%dx = x_h(2) - x_h(1);
% changed by TTQ, 3-6-04 (for other changes: compare versions)
dx=0.2; % here a increment is 0.2m as a minimum distance between two gauges
Nphi=ceil((x_h(end)-x_h(1))/dx);
x_h = [min(x_h):dx:Nphi*dx+min(x_h)]';  
% following assures an odd number of points in depth profile
if mod(length(x_h),2) == 0    % if length(x) is even
	x_h = x_h(1:length(x_h)-1);
else                         % if length(x) is odd
   	x_h = x_h;
end
h = interp1(x_h_orig,h,x_h); % match x_h and h
if h(length(h)) <= 0
    h = h(1:length(h)-2); % remove last two values if dry part
    x_h = x_h(1:length(x_h)-2); % remove last two values
end
%x_s = [min(x_h):2*dx:(length(x_h)-1)*dx+min(x_h)]'; % dx in method is 2*dx, number of locations must be odd
								                    % if length(x) = 20 --> length(x_s) = 9
x_s = [min(x_h):2*dx:(Nphi-1)*dx+min(x_h)]';     
hw1     = waitbar(0,'calculating phases ...');
Lf      = length(f); 
hulp    = round(0.2*Lf);
for jj = 1:length(f)
    if mod(jj,hulp)==0
        waitbar(jj/Lf);
    end    
    % if mod(jj,round(0.05*length(f))) == 0
    %    disp(['phase_int ' num2str(jj/length(f)*100,'%2.0f') ' pct'])
    %end
    
    k = dispers(f(jj),h,g);
	phi_s = zeros(length(x_s),1);
    %phi_s = zeros(Nphi,1);
	for ii = 2:length(x_s)
    	%phi_s(ii) = phi_s(ii-1) - (1/6*k(2*ii-3)+4/6*k(2*ii-2)+1/6*k(2*ii-1)) * 2*dx;
        phi_s(ii) = phi_s(ii-1) - (1/6*k(2*ii-3)+4/6*k(2*ii-2)+1/6*k(2*ii-1)) *2*dx;
	end
    
    %h_g = interp1(x_h,h,x_g','linear','extrap');
    %k_g = interp1(x_h,k,x_g','linear','extrap');
    %phi_g = interp1(x_s,phi_s,x_g','linear','extrap');
    h_g = interp1(x_h,h,x_g','linear'); %water depth at gage locations
    k_g = interp1(x_h,k,x_g','linear'); %wave number k at gage locations
    phi_g = interp1(x_s,phi_s,x_g','linear'); % phase at gage locations
    
    th = tanh(k_g.*h_g);
    nn = 0.5 + (k_g.*h_g)./sinh(2*k_g.*h_g);
    Ks = sqrt( (nn(1)*th(1)) ./ (nn.*th) );% Shoaling Ks = sqrt(c(1)/c(pp))
    test = Ks.*exp(i*phi_g);
    for ii=1:length(test);
        K(jj,ii) = test(ii); %complex vector shoaling & phase for each freq and gage
    end    
%    K(jj,:) = Ks .* exp(i*phi_g);  % werkt alleen nog in lus, hkl, 3-10-02
end
close(hw1);
