% Jonswap1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Jonswap1  
%   Calculate ideal Jonswap spectrum
%   usage: Jonswap1
%   asked from screen: 
%   Tp: peakperiode
%   thresh: threshold/E_max
%   screen output: f_min, f_max, Hm0, Hm0(f_min:f_max)
%   13-Apr-05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% Jonswap1
%   calculate and print region where the variance density of a Jonswap
%   spectrum is below thresh*Emax.
%   version 2: testversie, met uitvoer Hm0 en Hm0deel (evt. grafieken)
%   5-Dec-05
%
%   a part of this script is copied from bctriton.m created 
%   by Ap van Dongeren and Jonswap.m by Henk Jan Bakkenes, 
%   WL|Delft Hydraulics
%
%   adapted to Decomp by: H. Klaasman
%
% fm : peak frequency [Hz]
% N : number of wave components (not found here, Hkl, 21-12-04) 
% dt : time step (not found here, Hkl, 21-12-04) 

clear all;

%JONSWAP parameters
Tp      = input('Peak period in seconds ');
thresh  = input('Threshold to calculate f-range where E>thresh*Emax ');
df=0.01;
f=df:df:4/Tp;  % bovengrens f-gebied was 4 Hz, aangepast, afh. v. Tp
                % Hkl, 5-1-05
            % voor zeer lage drempel kan f_max hoger liggen, maar
            % waarschijnlijk is er bij hoge frequenties alleen ruis
Hm0gew  = 1; % alleen gebruikt voor normering, Hkl, 21-12-04
fm      = 1/Tp; % dit aanpassen
%lower   = floor(0.5423/df); % dit aanpassen
%upper   = floor(1.5303/df); % dit aanpassen


% jonswap maken 
% (waarschijnlijk is dit deel van Ap, Hkl, 21-12-04)
alpha= 0.0081 ;
gamma0 = 3.3;
g=9.81;
siga=0.07;
sigb=0.09;
ifm = floor(fm/df);
gamma1(1:ifm) = gamma0.^(exp(-.5*((f(1:ifm)-fm)./(siga*fm)).^2));
gamma1(ifm+1:length(f)) = ...
   gamma0.^(exp(-.5*((f(ifm+1:length(f))-fm)./(sigb*fm)).^2));
E = alpha*(g^2)*((2*pi)^(-4))*f.^(-5).* ...
   exp(-1.25*(f/fm).^(-4)).*gamma1;
Hm0temp = 4*sqrt(sum(E)*df);

E = E*(Hm0gew/Hm0temp)^2;

% calculate region of interest (part of Hkl)
% bepaal gebied waarin E>=thresh*max(E):
%drempel = thresh*sum(E)/nf;

% calculate index of peak in E:
[Ep,ip] = max(E);

% calculate threshold:
drempel = thresh*max(E);

i   = ip;
nf  = length(f);
while E(i)>=drempel & i<nf
    i = i+1;
end
f_max = f(i);
imax = i;

i = ip;
while E(i)>=drempel & i>1
    i = i-1;
end
f_min = f(i);
imin = i;

Hm0 = 4*sqrt(sum(E)*df);

figure
clf
plot(f,E)


Hm0deel = 4*sqrt(sum(E(imin:imax))*df);
fprintf('\nf_min (Hz)  f_max (Hz)  Hm0     Hm0deel\n');
fprintf('%7.4f    %7.4f   %7.4f   %7.4f\n\n',f_min, f_max, Hm0, Hm0deel); 
%Hm0deel = 4*sqrt(sum(E(lower:upper))*df)

% end Jnswap1