% function Pwspect
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pwspect
%   Calculate powerspectrum per wave gauge.
%   usage: Pwspect
%   parameters asked from screen
%
%   version 3, adapted to general design
%   1-Feb-05
%
%   H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   versie 3, aanpassing aan algemene opzet
%   versie 2, aanpassing fres als fres<2*df; aanpassing 
%       sommatie over freq.bandjes (geen bandjes van 
%       lengte 0 mogelijk).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
%addpath('D:\Hetty\Matlab\Lab_process\Functions');
addpath('.\Functions');

% =========================================================================
% ========= INPUT =========================================================
% =========================================================================

% lees Ascii-bestand (b.v. Dasylab-bestand)
% bestandsnaam en overige gegevens worden via het scherm opgevraagd
[in_naam, pad_naam, Fileinfo, A, type, err1] = FN_infile8;

if err1==0

    % lees gegevens over kolommen invoerbestand 
    scr_num = 4;
    [nsamp,nchan] = size(A);
    [Inparm,err1] = FN_inparm2(scr_num,nchan);

    if err1==0
        col    = Inparm.col; % col: column numbers
        
        % bandbreedte bij middelen variantiespectra:
        fres    = Inparm.fres;  % gewenste frequentieresolutie
        
        % selecteer de gevraagde rijen en kolommen uit A en sla dit op
        % in wavesig
        show = 1;
        [Scanparm,Ts,A1,err1] = FN_selectnw2(A,Fileinfo,Inparm,show);
        clear A;
            
        % geen fouten in opgegeven kolommen:
        if err1==0
    
%                wavsig  = wavsig1;
%                t       = t1;
%                clear wavsig1,t1;

            % tijdstap (na evt. bemonsteren):
            dt = Scanparm.dt;
                    
            % vermenigvuldig met schaalfactor:
            [nsamp,nchan]   = size(A1);
            e               = ones(nsamp,1);
            fact            = e*Inparm.sc;
            A1              = fact.*A1;
                    
            % bepaal momenten
            Outparm.M1      = mean(A1); % gem. is 1e moment tijdsignaal
            % 0-de moment var-dichtheidsspectrum=variantie tijdsignaal
            Outparm.var     = var(A1);
            Outparm.Hm0t    = 4. * (Outparm.var .^0.5); 
               
            % aftrek gemiddelde:
            e		= ones(nsamp,1);
            tmp 	= A1 - e*Outparm.M1;
            A1      = tmp;
            clear tmp;

                    
            % constantem voor spectrum:
            N           = length(Ts);     % N	 : number of data points [-]
            T           = N*dt;          	% T  : total measurement duration [s]    
            df          = 1/T;				% df : frequency step [Hz]
            
            % correct resolution if needed:
            if fres<2*df
                fres    = df;
                sp_sum  = 0;    % the spectra will not be summed
            else
                sp_sum  = 1;
            end

% =================================================================================
% ========== FFT of wavsig ========================================================
% =================================================================================
                          
            Efact   = 0.5*N*dt; % schaalfactor voor spectrum
            ncols   = length(Inparm.col);

            % amplitude- en variantiespectra golfhoogtemeters:
            for pp = 1:ncols
                A_temp = 2/N*fft(A1(:,pp));  	% Fourier transform wave signal for 
                                                % all stations
                A_temp(1) = [];	           % Delete average value in FFT

                % variantiespectrum:
                nf      = round(length(A_temp)/2);
                f       = [df:df:(nf*df)]';
                E_temp  = Efact .* (abs(A_temp(1:nf)) .^ 2);
                        
                % average variance spectum over frequncy bands:
                if sp_sum==0
                    fs      = f;
                    Espp    = E_temp;
                    method  = 0;
                else
                    [fs,Espp] = FN_sum7(f, E_temp, fres);
                    method = 1;
                end    
                    
                if pp==1
                    nfs = length(fs);
                    Es  = zeros(nfs,ncols);
                end    
                        
                % plot spectrum:
                nfig    = pp;
                ch      = Inparm.col(pp);
                thresh   = 0;
                f_max   = Inparm.f_max;
                FN_plotD12(nfig,in_naam,ch,fs,Espp,f_max,fres,thresh,method);
                    
                Es(:,pp) = Espp;
           end           
           % schrijf spectra naar uitvoerbestand:
           % tijdelijk vereenvoudigde methode zonder extra gegevens
           % voor extra gegevens: zie FN_outDsp
           % uitvoerbestanden:
           Outparm.N       = N;
           Outparm.df      = df;
           Outparm.fs      = fs;
           Outparm.fres    = fres;
           FN_outparm(scr_num,in_naam,Inparm,Scanparm,Outparm,err1);
           out_num = 2; % uitvoer spectra
           FN_outdata2(out_num,in_naam,Inparm,Scanparm,Outparm,fs,Es);

       end  % geen fouten in selectie
   end  % geen fouten in invoerparameters
end   % invoerbestand geopend

FN_error(err1);

% einde Pwspect