%function Refreg1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Refreg1
%   Calculate reflection coefficient of regular wave, 
%   velocity 0, input via file inparms.m
%
%   Refreg version 18
%   24-Jan-05
%
%
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Programmabeschrijving:
% Het programma leest de gegevens uit een door de gebruiker aan te
% wijzen invoerbestand. 
% Het invoerbestand moet 2 kolommen bevatten met meetwaarden van
%  2 golfhoogtemeters op afstaand ~L/4.
% Er mogen evt. meer kolommen in staan (de gebruiker geeft de
% nummers van de te verwerken kolommen op).
%
% input by user:
%   time step
%   number of harmonics to be printed
%   water depth in m
%   first sample to be analysed
%   last sample to be analysed
%   colomn number of first wave gauge
%   x-coord. position first wave gauge in m
%   schale factor measurement values 1st GHM to m
%   colomn number of second wave gauge
%   x-coord. position second wave gauge in m
%   schale factor measurement values 2nd GHM to m
%
% De basisfrequentie van de golf wordt geschat uit de nuldoorgangen
% aan het begin en het eind van de meetreeks met dezelfde 
% tekenwisseling. Hiertoe wordt eerst het gemiddelde afgetrokken.
% Uit de basisfrequentie en de tijdstap wordt een aantal punten
% berekend zodat de basisfreqentie in het met een fft gevonden
% spectrum ligt (d.w.z. N*dt een geheel aantal perioden).
% Met de fft worden vervolgens de gevraagde harmonischen bepaald.
% Vervolgens wordt het aantal punten opgehoogd tot minimaal 20 punten
% per periode m.b.v. Matlabfunctie resamp, waarna opnieuw een FFT 
% wordt uitgevoerd. 
% Uit amplitudes en fases van de basisfrequentie kan de verhouding 
% tussen invallende en teruggekaatste golf worden berekend.
% zie o.a. Goda, Y., Random Seas and Design of Maritime Structures,
% Univ. of Tokyo Press, 1985, pp. 299-301 (incl. regelmatige golf).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% HOOFDPROGRAMMA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

%%%% add functions to path (added 30-10-01)
addpath('.\Functions');

%%%% get parameter values:
[in_name, path_name, Fileinfo, Inparm] = inparms;
   
%%%% open output file:
%uitfile=[path_name '\uit' in_name];
%FID1=fopen(uitfile,'w');
%FN_headrr13(FID1);
      
      
%%%% Read header and data:
infile  = [path_name '\' in_name];
%nread   = Inparm.samp2;
%%%% lees header en data in:
[head,A,fout1,warn]=FN_indata7(infile,Fileinfo);	
%[head,A,fout]=FN_indata2(infile,nhead,nread);		
                
% no errors:
if fout1==0
    
    % select the part of A to be processed and the time vector:
    show = 1;
    [Scanparm,Ts,A1,err1] = FN_selectR1(A,Fileinfo,Inparm,show);
    if err1==0
        %%%% calculate reflection:
        [Outparm, err1] = FN_refreg7(in_name, Inparm, Scanparm, Ts, A1);
            
        % write results to output file:
        if err1<200
            FN_outparmR1(in_name,path_name,Inparm,Scanparm,Outparm,err1);
        end    
    end     % FN_selectR1
else
    err1 = 301;
end    

FN_error(err1);
% END Refreg1a
