function A = FN_indatb5(infile)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_indatb5
%   leest data uit binair bestand met int16 getallen.
%   10-9-03
%
%
%
%   versie 3: aangepast voor elektronisch golfschot
%   versie 2: met offset en keuze V of m
% In de praktijk is de conversiefactor vaak het bereik
% van de te berekenen waarde gedeeld door het waardebereik
% Bij het hydraulisch golfschot: [-32767,+32768] -> [-10V,+10V]
%   of [-0.3 m,+0.3 m]
% Elektronisch golfschot: [-20000,+20000] -> [-1 m,+1 m]
% Algemene vergelijking voor een rechte lijn door (x1,y1) en (x2,y2):
% y = (x2y1-x1y2)/(x2-x1) + (y2-y1)/(x2-x1)*x
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	infile:	naam invoerbestand
%   nread:  aantal in te lezen samples
%	Inparm:	structure met invoerparameters
%       samp1:  eerste te plotten punt
%       samp2:  laatste te plotten punt (-1 voor laatste)
%       col1 (col een):   kanaal met de tijd (0 voor geen)
%       wavb:   type golfschot (h hydraulisch, 
%               e elektronisch)
%       units:   te berekenen eenheid (val voor waarde, 
%               n voor genormeerde waarde,
%               V voor stuurspanning,
%               m voor benaderde uitwijking in m).
%
% Uitvoer:
%	exist:	1: bestand gevonden, 0: bestand niet gevonden
%	A:			array met meetdata
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% beginwaarde uitvoerparameters:
exist=0;
%A=[];	% nodig omdat het anders bij niet-dasylabbestanden 
			% fout gaat

% waardebereik:
if Inparm.wavb=='e'
    wmin = -20000;
    wmax = 20000;
else
    wmin = -32767;
    wmax = 32768;   % asymmetrisch
end

% conversiefactor:
if Inparm.units=='val'
    fact = 1;
else    
    fact = 2./(wmax-wmin);
end    

% omrekenen in m of V (dit is alleen verschillend van de genormeerde waarde
% bij het hydraulisch golfschot):
if Inparm.wavb=='h'
    if Inparm.units=='m'
        fact = 0.3*fact;    % slag 0.6 m i.p.v. 2 m
    elseif Inparm.units=='V'
        fact = 10.*fact;    % [-10 V, +10 V] = 20 V = 10*2
    end
end     
fact    
%%%% open invoerfile:
FID=fopen(infile,'r');
if (FID<0)
   fprintf('invoerbestand niet gevonden\n');
   
else
   exist=1;

	%%%% Lees hele invoerbestand in:
	A1 = fread(FID,'int16');
	fclose(FID);
    % verschuiving i.v.m. asymmetrie [wmin,wmax] (niet bij 'val'):
    if Inparm.units~='val'
        A1 = A1-(wmin+wmax)/2; 
    end                
	A1 = fact * A1;
    
      
	%%%% reduceer de ingelezen matrix tot de 
	%%%% opgegeven samples:
	if nread>-0.5
		[nsamp, nchan] = size(A1);
		samps(1) = max(Inparm.samp1,1);
		samps(2) = min(Inparm.samp2,nread);
		cols = 1:nchan;
		A  = SFN_red(A1,samps,cols);
    else
        A = A1;
    end
  end		%invoerbestand gevonden   

% Einde FN_indata 
			


