function [padnaam,Inparms] = FN_inparm_t3
% FN_inparm_t3 leest invoerparameters voor prog. testsig3 uit een per menu op te
% vragen invoerbestand (*.txt), in dezelfde map als de uit te voeren testbestanden.
% invoerbestand: op de eerste regel verklarende tekst:
%	naam  tijdstap  golper (s) diepte(m)  afst (m)   fr  phi_i  phi_r  aruis
%	en daar onder de bestandsnaam, gevolgd door bovenstaande parameters
%	gescheiden door komma's. De parameters worden hieronder beschreven.
% uitvoer:
%	padnaam:pad van de map waarin de uitvoerbestanden moeten komen
%	Inparm:	structure met invoerparameters per bestand:
%			.naam		naam invoerbestand
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afstand golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden
%			.aruis		amplitude normaal verdeelde witte ruis
%
%												H. Klaasman, 7 mrt 01

%% Geef parameters een beginwaarde:
Inparms(1).nper		= 100;
Inparms(1).tijdstap	= 0.01;
Inparms(1).golfper		= 1;
Inparms(1).diepte		= 0.6;
Inparms(1).dx			= 0.42;
Inparms(1).fr			= 0.1;
Inparms(1).phi_i		= 0;
Inparms(1).phi_r		= 0;
Inparms(1).aruis		= 0;

%% open invoerbestand:
[filenaam, padnaam] = uigetfile('*.*','Invoerbestand');
infile = [padnaam filenaam];
FID = fopen(infile,'r');

%% lees eerste regel:
lijn = fgets(FID);

%%%%lees parameters:
i=1;
while feof(FID)==0
   	lijn	= fgets(FID);
    br 		= findstr(lijn,',');
    l		= length(lijn);  
   	Inparms(i).naam = lijn(1:br(1)-1);
   	for k=1:8
      parm(k) = str2num(lijn(br(k)+1:br(k+1)-1));
   	end;   
   	parm(9) = str2num(lijn(br(9)+1:l));
   	Inparms(i).nper		= parm(1);
	Inparms(i).tijdstap	= parm(2);
	Inparms(i).golfper		= parm(3);
	Inparms(i).diepte		= parm(4);
    Inparms(i).dx			= parm(5);
    Inparms(i).fr			= parm(6);
	Inparms(i).phi_i		= parm(7);
	Inparms(i).phi_r		= parm(8);
    Inparms(i).aruis		= parm(9);
    i = i+1;
end    
      

% Einde FN_inparm_t3