function [Inparm,start] = FN_inparm_t6
% FN_inparm_t6 vraagt invoerparameters voor testsig aan de gebruiker.
% versie 6
% i.p.v. ruis hoogfrequente storing
%   15-5-03
%   aanpassing aan algemene opzet: 26-4-05
%
%
%
%
% hulpbestand:
% 	inparm_t.txt
% uitvoer:
%	Inparm:	structure met invoerparameters:
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afstand golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden
%			.aruis		amplitude hoogfr. storing
%	start:	1: doorgaan, 0: stoppen
%												H. Klaasman
      
%% Geef parameters een beginwaarde:
start  =    0;
%padnaam			 = 'Indata';
%Inparm.naam		 = 'test';
Inparm.nper	     = 100;
Inparm.tijdstap = 0.01;
Inparm.golfper  = 1;
Inparm.diepte   = 0.6;
Inparm.fr       = 0.1;
Inparm.phi_i    = 0;
Inparm.phi_r    = 180;
Inparm.aruis    = 0;
w     			 = 2*pi/Inparm.golfper;
h				 = Inparm.diepte;
k     			 = DISPER(w,h);
L     			 = 2*pi/k;
Inparm.dx       = L/4;
%Inparm.dx	= round(Inparm.dx,2);	% added to simplify the inputparms
					% of Refreg
tekst           = num2str(Inparm.dx);
Def1   = {'100','0.01','1','0.6',tekst};
Def2   = {'0.1','0','180','0'};

%% Check folder of parameterfiles:
if exist('.\Tmp')==0
	mkdir('.\Tmp');
end

%% Lees actuele parameterwaarden:
FID=fopen('.\Tmp\inparm_t6.txt','r');
if FID>=0
	i=1;
	while feof(FID)==0
      	lijn=fgetl(FID);
      	if i<6
      		Def1{i}=char(lijn);
      	else
         Def2{i-5}=char(lijn);
    	end   
		i = i+1;
	end
	fclose(FID);
end   

Prompt1 = {'number of periods','time step','wave period', ...
      'water depth in m','distance of wave gauges in m'};
Prompt2 = {'reflection coefficient', ...
      'phase of inc. wave between gauges-s in degees', ...
      'phase of refl. wave between gauges-s in degees', ...
   	'amplitude of high freq. disturbance'};
Title = 'Parameters';
Inparm1 = inputdlg(Prompt1,Title,1,Def1,'off');
Inparm2 = inputdlg(Prompt2,Title,1,Def2,'off');

if length(Inparm2)>0
		start=1;
	    %padnaam			 = [Inparm1{1}];
      	%Inparm.naam		 = Inparm1{2};
      	Inparm.nper 	 = str2num(Inparm1{1});
	   	Inparm.tijdstap = str2num(Inparm1{2});
	   	Inparm.golfper  = str2num(Inparm1{3});
		Inparm.diepte   = str2num(Inparm1{4});
		Inparm.dx       = str2num(Inparm1{5});
      	Inparm.fr       = str2num(Inparm2{1});
      	Inparm.phi_i    = str2num(Inparm2{2});
		Inparm.phi_r    = str2num(Inparm2{3});
		Inparm.aruis    = str2num(Inparm2{4});

		%% schrijf nieuwe waarden in hulpbestand: 
		FID=fopen('.\Tmp\inparm_t6.txt','w');
		%fprintf(FID,'%s\n',padnaam);
		%fprintf(FID,'%s\n',Inparm.naam);
		fprintf(FID,'%g\n',Inparm.nper);
		fprintf(FID,'%g\n',Inparm.tijdstap);
		fprintf(FID,'%g\n',Inparm.golfper);
		fprintf(FID,'%g\n',Inparm.diepte);
		fprintf(FID,'%g\n',Inparm.dx);
		fprintf(FID,'%g\n',Inparm.fr);
		fprintf(FID,'%g\n',Inparm.phi_i);
		fprintf(FID,'%g\n',Inparm.phi_r);
		fprintf(FID,'%g\n',Inparm.aruis);
      	fclose(FID);
      
        % pad van het uitvoerbestand
       % padnaam = [padnaam '\'];
        
else
   		start=0;
end
% Einde FN_inparm_t6