function [Inparm,error] = FN_inparmt7
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_inparmt7
%   leest gegevens over invoerbestand en te genereren testsignaal
%   voor testsig7 (Jonswapspectrum).
%   versie 2: test of laatste regel invoer niet leeg
%   7-6-04
%
% invoerbestand: 
%   regel 1:    piekperiode (als tekst)
%   regel 2:    piekperiode van bijbehoren .dat-bestand in s
%   regel 3:    Hm0 (als tekst)
%   regel 4:    Hm0 van bijbehorend .dat-bestand
%   regel 5:    tijdstappen (als tekst)
%   regel 6:    tijdstap in .dat-bestand in s
%   regel 7:    waterdiepte (als tekst)
%   regel 8:    waterdiepte in m van bijbehorend .dat-bestand
%   regel 9:    veronderstelde terugkaatingscoefficient (als tekst)
%   regel 10:   veronderstelde terugkaatsingscoefficient 
%   regel 11:   veronderstelde posities golfhoogtemeters
%	volgende regels voor elke golfhoogtemeter:
%               positie in m (golfschot op 0m)
%
% uitvoerparameters:
%   Inparm: structure met parameters:
%       Tp	    piekperiode
%       Hm0     parmameter voor Multilin, ~ significate golfhoogte
%       dt	    tijdstap
%       h		waterdiepte
%       Kr	    veronderstelde terugkaatsingscoefficient
%       x	    vector met veronderstelde posities golfhoogtemeters
%   error:  foutaanduiding: 0: geen fouten, 101: gebruiker heeft op Cancel gedrukt,
%           301: fout in invoerbestand
%
%												H. Klaasman

%% Geef parameters een beginwaarde:
error       = 0;
Inparm.Tp   = 2;            % piekperiode
Inparm.Hm0  = 0.1;          % significante golfhoogte
Inparm.dt   = 0.02;         % tijdstap
Inparm.h    = 0.6;          % waterdiepte
Inparm.x    = [8  8.25];          % posities golfhoogtemeters
Inparm.Kr   = 0.3;          % terugkaatsingscoefficient  

%% open invoerbestand:
filetext    = 'File containing parameters of data file';
filt        = '*.*';
[filenaam, padnaam] = FN_chsf4(filt,filetext);

% gebruiker wil doorgaan:
if filenaam~=0
    infile = [padnaam filenaam];
    FID = fopen(infile,'r');

    % lees eerste 11 regels:
    i=1;
    while feof(FID)==0 & i<=11
        lijn{i} = fgets(FID);
        i = i+1;
    end    

    if i<11
        error = 301;
        h = msgbox('Error in file containing parameters datafile','Decomp');
        uiwait(h);
    else
        Inparm.Tp   = str2num(lijn{2});
        Inparm.Hm0  = str2num(lijn{4});
        Inparm.dt   = str2num(lijn{6});
        Inparm.h    = str2num(lijn{8});
        Inparm.Kr   = str2num(lijn{10});

        %%%%lees parameters:
        i=1;
        lijn1 = fgets(FID);
        while feof(FID)==0
            if length(lijn1)>0
                Inparm.x(i) = str2num(lijn1);
   	            lijn1	    = fgets(FID);
                i = i+1;
            end    
        end    
    end
    fclose(FID);
% gebruiker heeft op Cancel gedrukt:    
else
    error = 101;
end    

% Einde FN_inparmt7