function[A,L,N] = FN_testsig3(Inparm)
% FN_testsig3 maakt een sinusvormig testsignaal voor het bepalen
%	van de terugkaatsingscoefficient
%   aangepast: 27-4-05
%
%
%
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 														H. Klaasman
%														22 feb 01
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	Inparm:	structure met invoerparameters:
%			.naam		naam uitvoerbestand
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afst. golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden
%			.aruis		amplitude normaal verdeelde witte ruis
% Uitvoer:
%	A(i,1) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r)
%	A(i,2) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r)
%	, i=1,1,N
%	L:  golflengte
%   N:  aantal punten
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath('..\Functions');
Nper  = Inparm.nper
dt    = Inparm.tijdstap;
per   = Inparm.golfper
T     = Nper*per
N     = floor(T/dt)
A     = zeros(N,2);
w     = 2*pi/per;
h     = Inparm.diepte;
k     = DISPER(w,h);
L     = 2*pi/k;
x1    =-Inparm.dx/2;
x2    = Inparm.dx/2;
fr    = Inparm.fr;
phi_i = 2*pi/360 * Inparm.phi_i;
phi_r = 2*pi/360 * Inparm.phi_r;

arg1(1) = k*x1 + phi_i;
arg1(2) = k*x2 + phi_i;
arg2(1) = k*x1 + phi_r;
arg2(2) = k*x2 + phi_r;
e1   = ones(N,1);

tstep	 = w*dt;
t  = 0:tstep:(N-1)*tstep;
e  = [1 1];
t2 = t'*e;
A  = cos(-t2 + e1*arg1) + fr * cos(t2 + e1*arg2);

% voeg ruis toe
A = A + Inparm.aruis * randn(size(A));
