function[A,L,N] = FN_testsig32(Inparm)
% FN_testsig3 maakt een sinusvormig testsignaal voor het bepalen
%	van de terugkaatsingscoefficient, met helling
%   tijd toegevoegd, 16-9-04, gaat fout
% 															H. Klaasman
%															6 apr 05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	Inparm:	structure met invoerparameters:
%			.naam		naam uitvoerbestand
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afst. golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden
%			.aruis		amplitude normaal verdeelde witte ruis
% Uitvoer:
%	A(i,1) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r) + hellimg
%	A(i,2) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r) + helling
%	, i=1,1,N
%	L:  golflengte
%   N:  aantal punten
%   toegevoegde helling: -5/N*( (t-x/c)+fr*(t-x/c-dphi/w) 
%                       t=i*dt, x = x1, x2
%   in dit model heeft de tweede ghm het laagste niveau
%   dat kan b.v. bij golfoverslag
%   met wijziging in h t.g.v. de helling is (nog) geen 
%   rekening gehouden; k=k(t), kx dus tijdafhankelijk
%   poging in FN_testsig33 gestaakt !!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath('..\Functions');
Nper  = Inparm.nper
dt    = Inparm.tijdstap;
per   = Inparm.golfper
T     = Nper*per
N     = floor(T/dt)
A     = zeros(N,2);
w     = 2*pi/per;
h     = Inparm.diepte;
k     = DISPER(w,h);
c     = k/w;
L     = 2*pi/k;
x1    =-Inparm.dx/2;
x2    = Inparm.dx/2;
fr    = Inparm.fr;
phi_i = 2*pi/360 * Inparm.phi_i;
phi_r = 2*pi/360 * Inparm.phi_r;

arg1(1) = k*x1 + phi_i;
arg1(2) = k*x2 + phi_i;
arg2(1) = k*x1 + phi_r;
arg2(2) = k*x2 + phi_r;
e1   = ones(N,1);

tstep	 = w*dt;
% aanpassing, 26-4-05
t   = 0:dt:(N-1)*dt;
% t1  = 0:tstep:(N-1)*tstep;
t1  = w*t;
e  = [1 1];
t2 = t1'*e;
fact = -5/N;
A  = cos(-t2 + e1*arg1) + fr * cos(t2 + e1*arg2);

% voeg helling toe:
ts1(1)  = x1*c;
ts1(2)  = x2*c;
dphi    = phi_i-phi_r;
ts2(1)  = ts1(1) + dphi/w;
ts2(2)  = ts1(2) + dphi/w;
A = A + fact*(t2 - e1*ts1) + fr*fact*(t2- e1*ts2); 

% voeg ruis toe
A = A + Inparm.aruis * randn(size(A));

% toevoegen tijd
A(:,3) = A(:,2);
A(:,2) = A(:,1);
for i=1:N;
    A(i,1) = t(i);
end    