function[A,L,N] = FN_testsig33(Inparm)
% FN_testsig33 maakt een sinusvormig testsignaal voor het bepalen
%	van de terugkaatsingscoefficient, met helling en h=h(t)
%   gestaakt: moet volgen uit integraal
% 															H. Klaasman
%															6 apr 05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	Inparm:	structure met invoerparameters:
%			.naam		naam uitvoerbestand
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afst. golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden (niet gebruikt)
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden (niet gebruikt)
%			.aruis		amplitude normaal verdeelde witte ruis
% Uitvoer:
%   A(0) = h(t) + a*cos(wt)
%   A(x) = A(t-kx) + fr*A(t-k*(x+(len-x)/2))
%   toegevoegde helling: h = h(t)= h0-5/N*dt
%
%   gestaakt: in dit geval is k = k(t), dus t-kx kan niet
%   zonder meer, maar moet volgen uit x*integraal(k(t)dt)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath('..\Functions');
Nper  = Inparm.nper
dt    = Inparm.tijdstap;
per   = Inparm.golfper
T     = Nper*per
N     = floor(T/dt);
w     = 2*pi/per;
h0    = Inparm.diepte;

% tijdvector:
t   = 0:dt:(N-1)*dt;
t   = t';
e1  = ones(1,N);

% diepte:
fact    = 5/N;
h       = e1*h0 + fact*t;

% tijdsignaal:
a = 0.1;
A = h + a*cos(w*t);

% golfgetal:
k     = Disper(w,h);    % golfperiode opgelegd, dus constant

% bereken A op de gegeven plaatsen:
x   = [-Inparm.dx/2 Inparmdx/2];
fr  = Inparm.fr;

for i=1:N
    t1 = t(i)*[1 1] - k(i)*x;   % fout: k wordt een integraal,
                                % verandert als fie vd tijd
        
        
% fout, aanpassen
tstep	 = w*dt;
t  = 0:tstep:(N-1)*tstep;
e  = [1 1];
t2 = t'*e;
A  = h + cos(-t2 + e1*arg1) + fr * cos(t2 + e1*arg2);

% voeg ruis toe
A = A + Inparm.aruis * randn(size(A));

% toevoegen tijd
A(:,3) = A(:,2);
A(:,2) = A(:,1);
for i=1:N;
    A(i,1) = t(i);
end    