function[A,L,N] = FN_testsig6(Inparm)
% FN_testsig6 maakt een sinusvormig testsignaal voor het bepalen
%	van de terugkaatsingscoefficient
%   versie 6
%   sinusvormige storing
%   15-5-03, aanpassing: 26-4-05
% 															H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%	Inparm:	structure met invoerparameters:
%			.naam		naam uitvoerbestand
%			.nper		aantal perioden
%			.tijdstap	tijdstap
%			.golfper	golfperiode
%			.diepte 	waterdiepte in m
%			.dx			afst. golfhoogtemeters in m
%			.fr			terugkaatsingscoefficient
%			.phi_i		fase invallende golf op plaats tussen
%						golfhoogtemeters in graden
%			.phi_r		fase teruggekaatste golf op plaats tussen
%						golfhoogtemeters in graden
%			.aruis		amplitude sinusvormige stiring
% Uitvoer:
%	A(i,1) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r)
%	A(i,2) = cos(k*dx/2 - 2*pi*((i-1)*dt + phi_i) 
%	  		+ fr*cos(k*dx/2 + 2*pi*((i-1)*dt + phi_r)
%	, i=1,1,N
%	L:  golflengte
%   N:  aantal punten
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Nper  = Inparm.nper
dt    = Inparm.tijdstap;
per   = Inparm.golfper
T     = Nper*per
N     = floor(T/dt)
A     = zeros(N,2);
w     = 2*pi/per;
h     = Inparm.diepte;
k     = DISPER(w,h);
L     = 2*pi/k;
x1    =-Inparm.dx/2;
x2    = Inparm.dx/2;
fr    = Inparm.fr;
phi_i = 2*pi/360 * Inparm.phi_i;
phi_r = 2*pi/360 * Inparm.phi_r;
aruis   = Inparm.aruis

arg1(1) = k*x1 + phi_i;
arg1(2) = k*x2 + phi_i;
arg2(1) = k*x1 + phi_r;
arg2(2) = k*x2 + phi_r;
e1   = ones(N,1);

% tstep	 = w*dt;
% aanpassing, 26-4-05
t   = 0:dt:(N-1)*dt;
% t1  = 0:tstep:(N-1)*tstep;
t1  = w*t;
e  = [1 1];
t2 = t1'*e;
A  = cos(-t2 + e1*arg1) + aruis*cos(-18.5*t2) + fr * cos(t2 + e1*arg2);

% toevoegen tijd
A(:,3) = A(:,2);
A(:,2) = A(:,1);
for i=1:N;
    A(i,1) = t(i);
end    

% einde FN_testsig6