function A = FN_testsig7(Ag,Inparm)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_testsig7 
% maakt een testsignaal met een Jonswapspectrum uit een
% stuursignaal gemaakt door Multilin voor het bepalen van de
% terugkaatsingscoefficient van een onregelmatige golf
%   versie 1
%   2-11-03
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dit is fout: er is gerekend met een constante voortplantings-
% snelheid, terwijl deze in werkelijkheid afhangt van de frequentie.
%   4-11-03
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dit werkt nog niet. Het werkt beter als de signalen van achter
% naar voor worden gegenereerd (nsamp1-j+1 i.p.v. j), maar het
% geeft ook dan een foute uitkomst.
% Beter: een bestaand signaal vergelijken met Reflec(mf).
% 						
%                                       H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%   Ag:    golfvector
%	Inparm:	structure met invoerparameters:
%       Tp	    piekperiode
%       Hm0     parmameter voor Multilin, ~ significate golfhoogte
%       dt	    tijdstap
%       h		waterdiepte
%       Kr	    veronderstelde terugkaatsingscoefficient
%       x	    vector met veronderstelde posities golfhoogtemeters
%
% Uitvoer:
%	A(i) = a(i-is1) + Kr*a(i-is2) 
% met   is1 = (x(i)-x(1))*Tp/(L*dt)
%       is2 = (2(len-x(1))-x(i))*Tp/(L*dt) 
%   L:  golflengte bij opgegeven piekperiode en Hm0,
%   len:lengte goot = 40 m
% let op:
%   a=Ag, a(1) is het oudste; golfhoogtemeters verder weg (grotere x
%   bevatten een ouder gedeelte van de golf (kleinere i); de terug-
%   gekaatste golf bevat een ouder gedeelte dan de invallende. 
%   De tijdverschuiving als functie van de plaats is:
%   a(x,t) = a(0,t-ts), ts = x/c = x*Tp/Lp voor de piekperiode;
%   voor alle andere periodes in het Jonswapspectrum geldt een
%   andere voortplantingssnelheid c, en dus een andere T/L. 
%   Voorlopig wordt c constant verondersteld.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Tp    = Inparm.Tp;
dt    = Inparm.dt;
h     = Inparm.h;  
Kr    = Inparm.Kr;
x     = Inparm.x;

nx = length(x);
w  = 2*pi/Tp;
k  = Disper(w,h);
L  = 2*pi/k;    % let op: als h niet constant is wordt L een vector
                % er zijn veel w's, dus ook verschillende k's

nsamp   = length(Ag);
len     = 40-x(1);
const   = Tp/(L*dt);

e       = ones(1,nx);
tshift1 = x-x(1)*e;
tshift2 = tshift1 + 2*(len*e-x);
is1     = round(const * tshift1);
is2     = round(const * tshift2);
shift1  = max(is1);
shift2  = max(is2);
%shift   = shift1+shift2;
nsamp1  = nsamp-shift1-shift2;
A   = zeros(nsamp1,nx);
%size(A)

for i=1:nx
    ind1    = shift1 +1 -is1(i);
    ind2    = nsamp1+ind1-1;
    ind3    = shift2 +1 -is2(i);
    ind4    = nsamp1+ind3-1;
    A1      = Ag(ind1:ind2);
    A2      = Kr*Ag(ind3:ind4);
    figure(i);
%    subplot(2,1,1);
%    plot(A1(1:200));
%    subplot(2,1,2);
%    plot(A2(1:200));
    A(:,i)  = Ag(ind1:ind2) + Kr*Ag(ind3:ind4);
end    

% A in volts (als in Dlab-bestand): *10/32768
% uitw. hydr. golfschot -> ampl. in m: neem voorlopig 2
% A = (20/32768) .* A;    

% einde FN_testsig7