function A = FN_testsig7(Ain,Inparm)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FN_testsig7 
% maakt een testsignaal met een Jonswapspectrum uit een
% stuursignaal gemaakt door Multilin voor het bepalen van de
% terugkaatsingscoefficient van een onregelmatige golf
%   versie 1
%   10-9-03
% 						
%                                       H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Invoer:
%   Ain:    vector met stuursignaal
%	Inparm:	structure met invoerparameters:
%       Tp	    piekperiode
%       Hm0     parmameter voor Multilin, ~ significate golfhoogte
%       dt	    tijdstap
%       h		waterdiepte
%       Kr	    veronderstelde terugkaatsingscoefficient
%       x	    vector met veronderstelde posities golfhoogtemeters
%
% Uitvoer:
%	A(i) = .25/32768 * (a(i-is1) + Kr*a(i-is2)) 
% met   is1 = (x(i)-x(1))/(L*dt)
%       is2 = 2(len-x(1)-x(i))/(L*dt)
%   L:  golflengte bij opgegeven piekperiode en Hm0,
%   len:lengte goot = 40 m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Tp    = Inparm.Tp;
dt    = Inparm.dt;
h     = Inparm.h;  
Kr    = Inparm.Kr;
x     = Inparm.x;

nx = length(x);
w  = 2*pi/Tp;
k  = Disper(w,h);
L  = 2*pi/k;

nsamp   = length(Ain);
len     = 40;
const   = 1/(L*dt);

x
e       = ones(1,nx)
is1     = round(const .* (x-x(1).*e));
is2     = round( (2*const) .* ( (len-x(1)).*e - x ) );
shift   = max(is2)+1;

for i=shift:nsamp
    for j=1:nx
        i1 = i-is1(j);
        i2 = i-is2(j);
        A(i,j) = Ain(i-is1(j)) + Kr*Ain(i-is2(j));
    end
end

A = (0.25/32768) .* A;

% einde FN_testsig7