function Wavper2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Wavper2
%   Calculate wave period for specified waterdepth h,
%   wave height H, and wave steepness s (more cases)
%   usage: input in .m-file, name of outputfile asked from screen
%   version 1
%	8-March-05	
%
%
%   Used equations:
%   wavelength: L=H/s
%   wavenumber: k=2pi/L
%   sqared angular frequency: w^2=gk tanh(kh)   
%               g: gravitational acceleration constant
%               g = 9.81 m/s^2
%   waveperiod: T=2pi/(w^2)^0.5
%				H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% voeg algemene functies toe aan pad:
addpath('.\Functions');

% waterdieptes:
h   = [0.45  0.5  0.55  0.6  0.65];
nh  = length(h);

% golfhoogtes:
nwh = 20;
H0  = 0.08;
for i=1:nwh
    H(i) = H0 + 0.01*i;
end

% golfsteilheden:
ns = 5;
for i=1:ns
    s(i) = 0.01*i;
end

% open uitvoerbestand:
[uitnaam, uitpad] = FN_chsoutf4('.txt','uitvoerbestand');
if uitnaam~=0
    uitfile = [uitpad uitnaam];
    FID5    = fopen(uitfile,'w');
    d = datestr(now);
    fprintf(FID5,'Program Wavper2: wave length and wave period\r\n\r\n')
    fprintf(FID5,'%s\r\n',d);
    for i=1:nh
        for j=1:ns
            fprintf(FID5,' \r\n');
            fprintf(FID5,'      h        s       H       L       T\r\n');
            fprintf(FID5,'     (m)     (0-1)    (m)     (m)     (s)\r\n');
            [L1,T1] = FN_wavper(h(i),H,s(j));
            for k=1:nwh
                fprintf(FID5,'%8.2f %8.2f %8.2f %8.4f %8.4f\r\n',...
                    h(i), s(j), H(k), L1(k), T1(k));
            end
        end
    end
end    
            

function [L,T] = FN_wavper(h,H,s);
%if nargin<3
%    fprintf('usage: [L,T] = Wavper(h,H,s)');
%    L = 0; T = 0;
%else    
    L   = H/s;
    k   = 2*pi./L;
    g   = 9.81;
    w2  = (g.*k).*tanh(k*h);
    T   = 2*pi./((w2).^0.5);
    %end
% end FN_wavper

