function [in_name,path_name,Fileinfo,Inparm] = inparms2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% inparms2 
%	initialize input parameters of Refreg1a.
%   usage: type parameter values in .m-file
%
%	version 2
%	19-Jan-04
%
%
%					H. Klaasman
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% versie 2: toevoegen FileInfo t.b.v. FN_indata7
% output:
%   in_name:    name of input file
%   path_name:  path of inputfile
%   nhead:      number header lines in the input file
%	Fileinfo:	structure met bestandsgegevens
%       nhead:	voor niet dasylabbestanden: aantal headerregels
%           	wordt bij dasylabbestanden genegeerd.
%       samp1:	eerste in te lezen punt
%       samp2:	laatste in te lezen punt, -1 tot einde file
%       step:	stapgrootte
%	Inparm:	structure met invoerparameters
%       hm:     gemiddelde waterdiepte in m (later: opgeven per kanaal)
%       dt:     tijdstap in meetdata (niet: in bemonsterde data)
%       nharm:  aantal gewenste harmonischen bij spectrum reg. 
%               golf
%       samp1:  eerste te verwerken punt meetreeks (-1 voor begin)
%       samp2:  laatste te verwerken punt meetreeks (-1 tot einde)
%       colt:   kolom met tijden (0: geen)
%       ncols:  aantal te verwerken kanalen
%	    col:	rijvector met kolomnummers kanalen
%       xp:     rijvector met X-coordinaten
%       sc:     rijvector met schaalfactor meetwaarde -> gewenste waarde


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% replace the parameter values by your own:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
in_name     = 'Refreg.asc';  % replace by name of inputfile 
path_name   = '.\Indata';   % replace by path of folder with inputfile 
nhead       = 0;        % number of header lines in input file,
			% D-lab: 0 
time_step   = 0.02;     % time step in seconds
nharm       = 5;        % number of harmonic components to be printed in the
                        % output file
depth       = 0.5;      % water depth in m
samp1       = 2000;     % first sample of measurements to be analysed
samp2       = -1;       % last sample of measurements to be analysed (-1 for all)
colt        = 0;        % column containing time (0: none)
col1        = 6;        % column of chanel with first wave gauge to be analysed
pos1        = 0;        % x-coordinate of first wave gauge in m(if 0, pos2 is the 
                        % distance of the wave gauges)
scale1      = 0.0243;   % scale factor measurement values to meters
                        % in this example: measurements in volts, 10 volt = 0.244 m
col2        = 5;        % column of channel with secong wave gauge to be analysed;
                        % in this example, the 2nd wave gauge is registrated
                        % after the first 
pos2        = 0.6;      % position of second wave gauge in m (distance if pos1=0)
scale2      = 0.0243;   % scale factor measurement values to meters

%% set parameters:
Fileinfo.nhead  = nhead;
Fileinfo.samp1  = 1;
Fileinfo.samp2  = -1;
Fileinfo.step   = 1;

Inparm.hm       = depth;
Inparm.dt       = time_step;
Inparm.nharm    = nharm;
Inparm.samp1    = samp1;
Inparm.samp2    = samp2;
Inparm.colt     = 0;
Inparm.col      = [col1 col2];
Inparm.xp       = [pos1 pos2];
Inparm.sc       = [scale1 scale2];

% End of inparms